/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

(function($) {

    /**
     * Validation du choix du pseudo
     */
    $.formUtils.addValidator({
        name : 'pseudo',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la présence du pseudo
             */
            if ($.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-name-required');
                return false;                                                            
            }
            //

            /**
             * Test des caractères du pseudo
             */
            if (/[^-a-z0-9_]/gi.test(value)) {
                this.errorMessage = $el.attr('data-validation-error-msg-chars-not-valid');
                return false;                                                            
            }
            //
                        
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation du choix du mot de passe
     */
    $.formUtils.addValidator({
        name : 'password',
        validatorFunction : function(value, $el, config, language, $form) {

            if ($('input[name=writerid]').val() != 0) { // Mode édition du rédacteur (pas de test sur mot de passe)
                return true;
            }
            
            /**
             * Test de la présence du mot de passe
             */
            if ($.trim(value) === '') {
                this.errorMessage = $el.attr('data-validation-error-msg-password-required');
                return false;                                                            
            }
            //

            /**
             * Test de la longueur du mot de passe
             */
            if (value.length < 6) {
                this.errorMessage = $el.attr('data-validation-error-msg-password-length');
                return false;                                                            
            }
            //
                        
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation de la confirmation du mot de passe
     */
    $.formUtils.addValidator({
        name : 'password-confirmation',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de la confirmation du mot de passe
             */
            if (value !== $('#params_pass').val()) {
                this.errorMessage = $el.attr('data-validation-error-msg-password-confirmation');
                return false;                                                            
            }
            //
                        
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
	// --------------------------------------------------------------------

    /**
     * Validation de l'email'
     */
    $.formUtils.addValidator({
        name : 'my_email',
        validatorFunction : function(value, $el, config, language, $form) {

            /**
             * Test de l'email si renseigné
             */
            if ($.trim(value) !== '' && !$.formUtils.validators.validate_email.validatorFunction(value)) {
                this.errorMessage = $el.attr('data-validation-error-msg-email');
                return false;                                                            
            }
            //
                        
            return true;
        },
        errorMessage : '',
        errorMessageKey: ''
    });
    
})(jQuery);