/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

jQuery(function($) {
    
	// --------------------------------------------------------------------
    
    /**
     * Ajoute l'évenement click pour afficher les options de recherche via Ajax
     *
     * @access public
     * @return void
     */     
    function add_even_click_for_display_options_search()
    {
        $('li.search_docs a').on('click', function()
        {
            if ($('#search_contents').length > 0) {
                $('#search_contents').toggle();
            } else {
                $('hr.menu').after('<div id="search_contents"></div>');
                                
                $('#search_contents').ajaxStart(function(){ // Evènement Ajax commencé
                    $(this).addClass('ajax_loading');
                });                              

                $('#search_contents').ajaxComplete(function(){ // Evènement Ajax terminé
                    $(this).removeClass('ajax_loading');
                    if (!!$.fn.add_action_after_loading_options_search) {
                        $(this).add_action_after_loading_options_search(); // Permet d'ajouter des actions après le chargement (optionnel)   
                    }                    
                });                              
                
                $('#search_contents').load($(this).attr('href') + ' .search_by_filters', function(data) {
                    add_selected_attribute_for_search_options();    
                }, 'html');  // Chargement du contenu via ajax

            }
            
            return false;
        });
    }
   
	// --------------------------------------------------------------------
    
    /**
     * Sélectionne les options de recherche choisies
     *
     * @access public
     * @return void
     */     
    function add_selected_attribute_for_search_options()
    {
        $('#filter_0').prop('checked', true);
        
        $('#search_contents input[id^="filter"]').each(function() {
            add_selected_attribute_for_search_options_by_filter($(this).attr('id'));           
        });
    }
   
	// --------------------------------------------------------------------
    
    /**
     * Sélectionne les options de recherche choisies selon le filtre sélectionné
     *
     * @access public
     * @param string Identifiant du filtre sélectionné
     * @return void
     */
    function add_selected_attribute_for_search_options_by_filter(filter_id)
    {
        var select_id = $('#' + filter_id).siblings('select').attr('id');
        var doc_ids = $.fn.get_url_param(select_id);

        if (doc_ids) {
            var docs_selected_ids = doc_ids.split('-');
            var nb_docs_selected = docs_selected_ids.length;
            
            $('#' + filter_id).prop('checked', true);
            
            for(var i = 0; i < nb_docs_selected; i++) {   
                $('#' + select_id + ' option[value="' + docs_selected_ids[i] + '"]').prop('selected', true);   
            }    
        }
    }

    // --------------------------------------------------------------------

    /**
     * Récupère la valeur d'un paramètre passé dans l'url
     */
    $.fn.get_url_param = function (paramName)
    {
      var reParam = new RegExp('(?:[\?&]|&amp;)' + paramName + '=([^&]+)', 'i') ;
      var match = window.location.search.match(reParam) ;
     
      return (match && match.length > 1) ? match[1] : null ;
    };
        
	// --------------------------------------------------------------------

    /**
     * fonctions à exécuter lors du chargement du script
     *
     * @return void
     */
    function init()
	{
        add_even_click_for_display_options_search();       
    }
    //
    
    init(); // initialisation  
});