<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

if (stristr($_SERVER['SCRIPT_NAME'], 'box.inc')) {
    header('location:../index.php');
    die();
}

include_once 'plugin.inc'; // Nécessaire lorsque l'icone dans le menu n'est pas affichée

/**
 * Affiche la boite latérale
 * 
 * @param string positions de la boite
 * @param string arguments
 * @return string
 */
function fbox_adm_redacteurs($pos, $args)
{
    global $lng, $tconfig;

    include ADMR_LANGUAGES_PATH.'/'.ADMR_LNG.'.php';
   
    $writers = ADMR_get_all_writers();
    $writers_online = ADMR_get_writers_online($writers);
    $nb_writers = count($writers);
    $nb_writers_online = count($writers_online);
    $writer_rights = ADMR_get_writer_rights($_COOKIE['admr']);

    if (empty($_COOKIE['admr'])) { // Rédacteur déconnecté
        $out = '
            <p class="box"><a href="'.ADMR_PUBLIC_ROOT_PATH.'/writer.php?lng='.$lng.'&ctrl=connect/login"><button type="button">'.ucfirst($ADMR_lang['connect']).'</button></a></p>
            <hr />
        ';       
    } else {
        $out = '
            <p class="box"><a href="'.ADMR_PUBLIC_ROOT_PATH.'/writer.php?lng='.$lng.'&ctrl=connect/logout"><button type="button">'.ucfirst($ADMR_lang['disconnect']).'</button></a></p>
            <p class="box"><a href="'.ADMR_PUBLIC_ROOT_PATH.'/writer.php?lng=fr"><button type="button">'.ucfirst($ADMR_lang['access_to_administration']).'</button></a></p>
            <hr />
        ';        
    }

    $out .= '
        <p class="box"><img src="'.ADMR_IMG_GROUP.'" alt="'.ucfirst($ADMR_lang['number_of_writers']).'" title="'.ucfirst($ADMR_lang['number_of_writers']).'" style="vertical-align:middle;border:none">&nbsp;'.$nb_writers.'&nbsp;'.($nb_writers > 1 ? $ADMR_lang['writers'] : $ADMR_lang['writers']).'</p>
        <hr />
        <p class="box">'.($nb_writers_online > 1 ? ucfirst($ADMR_lang['writers_online']) : ucfirst($ADMR_lang['writer_online'])).'&nbsp;:&nbsp;'.$nb_writers_online.'&nbsp;</p>
    ';
    
    if (!empty($writers_online)) {
        $out .= '<ul>';
        foreach($writers_online as $writer) {            
            if (empty($_COOKIE['admr']) || $writer['id'] != $_COOKIE['admr']) {
                $out .= '<li>'.$writer['name'];
                if (!empty($_COOKIE['admr']) && ADMR_addon_exists('messages') && !empty($writer_rights['messages_manage']) && !empty($writer_rights['messages_add'])) {
                    $out .= '&nbsp;<a href="'.ADMR_PUBLIC_ROOT_PATH.'/'.ADMR_BASE_HREF_PLUGIN.'&ctrl=addons/messages/add_messages&to='.$writer['id'].'"><img src="'.ADMR_IMG_MSG.'" alt="'.ucfirst(sprintf($ADMR_lang['send_message_to_%s'], $writer['name'])).'" title="'.ucfirst(sprintf($ADMR_lang['send_message_to_%s'], $writer['name'])).'" style="vertical-align:middle;border:none" /></a>';                    
                }               
                $out .= '</li>';
            } else {
                $out .= '<li>';
                if (ADMR_addon_exists('messages') && !empty($writer_rights['messages_manage'])) {                   
                    $writer_msg_not_read = ADMR_get_writer_messages_not_read($_COOKIE['admr']);                 
                    $img_name = empty($writer_msg_not_read) ? 'message.gif' : 'new_message.gif';
                    $img_alt = empty($writer_msg_not_read)? $ADMR_lang['manage_messages'] : $ADMR_lang['you_have_messages_not_read'];
                                        
                    $out .= '<a href="'.ADMR_PUBLIC_ROOT_PATH.'/'.ADMR_BASE_HREF_PLUGIN.'&ctrl=addons/messages/manage_messages"><img src="'.ADMR_IMG_PATH.'/'.$img_name.'" alt="'.ucfirst($img_alt).'" title="'.ucfirst($img_alt).'" style="vertical-align:middle;border:none" /></a>&nbsp;';
                }
                $out .= '<strong>'.$writer['name'].'</strong></li>';
            
            }              
        }
        $out .= '</ul>';      
    }

    return boxthin($pos, ucfirst($ADMR_lang['writers']), $out, ' ADMR_box');
}

// --------------------------------------------------------------------

/**
 * récupère la liste de tous les rédacteurs
 * 
 * @return array Tableau contenant la liste de tous les rédacteurs
 */
function ADMR_get_all_writers()
{
    require_once ADMR_CORE_PATH.'/model.php';
    require_once ADMR_MODELS_PATH.'/writer_model.php';
    
    $writer_model = new Writer_model;

    return $writer_model -> get();   
}

// --------------------------------------------------------------------

/**
 * récupère les droits du rédacteur
 * 
 * @param integer Identifiant du rédacteur
 * @return array Tableau contenant les droits du rédacteur
 */
function ADMR_get_writer_rights($writer_id)
{
    require_once ADMR_CORE_PATH.'/model.php';
    require_once ADMR_MODELS_PATH.'/rights_model.php';
    
    settype($writer_id, 'integer');
    
    $writer_rights_model = new Rights_model('writer');

    return $writer_rights_model -> read($writer_id);   
}

// --------------------------------------------------------------------

/**
 * récupère les messages non lus du rédacteur s'il y en a
 * 
 * @param integer Identifiant du rédacteur
 * @return array Tableau contenant les messages non lus du rédacteur
 */
function ADMR_get_writer_messages_not_read($writer_id)
{
    require_once ADMR_ADDONS_PATH.'/messages/configs/messages_constants.php';   // Chargement des constantes de l'addon
    require_once ADMR_CORE_PATH.'/model.php';
    require_once MESSAGES_MODELS_PATH.'/writer_messages_model.php';
    
    settype($writer_id, 'integer');
    
    $writer_messages_model = new Writer_messages_model(array('id' => $writer_id));

    $messages_not_read = $writer_messages_model -> get(array('receiver_id' => $writer_id, 'mode' => 1));
    
    return $messages_not_read;   
}

// --------------------------------------------------------------------

/**
 * récupère la liste de tous les rédacteurs en ligne
 * 
 * @param array Liste des rédacteurs enregistrés dans la base de donnée
 * @return array Tableau contenant la liste de tous les rédacteurs en ligne
 */
function ADMR_get_writers_online($writers)
{
    settype($writers, 'array');
    $writers_online = array();
    
    require_once ADMR_CORE_PATH.'/model.php';
    require_once ADMR_MODELS_PATH.'/writers_online_model.php';
    
    $writers_online_model = new Writers_online_model;
        
    foreach($writers_online_model -> get() as $writer_id) {
        if (isset($writers[$writer_id])) {
            $writers_online[$writer_id] = $writers[$writer_id];    
        } else {
            $writers_online_model -> delete($writer_id); 
        }  
    }
   
    $writers_online = ADMR_sort_writers_online_by_name($writers_online); // Tri selon le nom du rédacteur
        
    return $writers_online;     
}

// --------------------------------------------------------------------

/**
 * Tri selon le nom des rédacteurs en ligne et renvoie la liste
 *
 * @param array Tableau contenant la liste des rédacteurs en ligne
 * @param string Option de tri (optionnel et par défaut le tri se fait dans l'ordre alphabétique croissant) 
 * @return array Tableau contenant la liste de tous les rédacteurs en ligne triés par leur nom
 */
function ADMR_sort_writers_online_by_name($writers_online, $sort_option = 'asc')
{
    if(empty($writers_online)) {
        return $writers_online;
    }

    // Tableau en colonne
    foreach ($writers_online as $key => $row) {
        $name[$key] = strtolower($row['name']);
    }
    //

    if ($sort_option == 'asc') {
        array_multisort($name,SORT_ASC, $writers_online);    
    } else {
        array_multisort($name, SORT_DESC, $writers_online);        
    }

	return $writers_online;
}

// --------------------------------------------------------------------

/**
 * Vérifie si un addon est installé ou non
 * 
 * @param string Nom de l'addon
 * @return boolean Addon installé (true) ou non (false)
 */
function ADMR_addon_exists($addon_name)
{
    return is_dir(ADMR_ADDONS_PATH.'/'.$addon_name);   
}
