<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');


/***********************************************************************************************************************************
 * Initialisation des variables de configuration
 */
/* 
$userprefs[3] = 'L';	// Boites latérales toutes à gauche
$widepage = 'on';	    // Pas de boites latérales
*/

$ADMR_config = array(
    'nb_records_per_page' => 15,                   // Nombre d'enregistrements affichés par page dans le tableau de données
    'sort_option_by_default' => 'ch_asc',        // Option de tri des enregistrements par défaut
    'controller_by_default' => array(
        'admin' => 'manage_writers', // Controller par défaut coté admin
        'public' => 'dashboard', // Controller par défaut coté public
    ),
    'writer_status_by_default' => 'a',        // Status par défaut du rédacteur lors de son enregistrement (a : activé ou i : inactivé)
    'doc_status_by_default' => 'i',           // Status par défaut du document lors de son enregistrement (a : activé ou i : inactivé)
    
    'token_time_expire' => 300, // Temps d'expiration du jeton dans un formulaire (en seconde)
    
    'file_manager' => array(
        'dirs' => array('img', 'photo', 'file', 'pages', 'flash'),
        'confirm_delete' => FALSE, // Activer ou non la demande de confirmation de la suppression d'un fichier ou d'un répertoire       
       
        'upload' => array(
            'allowed_ext' => array(),   // Interdire tout sauf les extensions déclarées (si vide tout est autorisé)
            'denied_ext' => array(),    // Autoriser tout sauf les extensions déclarées (si vide tout est autorisé)
            'max_size' => 2 * 1024 * 1024, // Poids maximal du fichier en octet (mettre à FALSE pour ne pas avoir de poids maximal pour les fichiers)       
        ),
        
        'access' => array(
/*            'default' => array(
                'dirs' => array('img', 'photo', 'file', 'pages', 'flash'),
                'allowed_ext' => array(),      // Interdire tout sauf les extensions déclarées (si vide tout est autorisé)
                'denied_ext' => array(),       // Autoriser tout sauf les extensions déclarées (si vide tout est autorisé)
                'max_size' => 2 * 1024 * 1024, // Poids maximal du fichier en octet (mettre à FALSE pour ne pas avoir de poids maximal pour les fichiers)       
            ),*/
            'image' => array(
                'dirs' => array('img', 'photo'),
                'allowed_ext' => array('.jpg', '.gif', '.png', '.bmp', '.jpeg')
            ),
            'icon' => array(
                'dirs' => array('img'), // Attention, guppy n'accepte que des fichiers provenant du répertoire img pour les icones
                'allowed_ext' => array('.jpg', '.gif', '.png', '.bmp', '.jpeg')
            ),
            'link' => array(
                'dirs' => array('file', 'img', 'photo', 'pages', 'flash'),
                'denied_ext' => array()
            ),
            'flash' => array(
                'dirs' => array('flash'),
                'allowed_ext' => array('.swf','.fla','.flv')
            ),
            'media' => array(
                'dirs' => array('flash'),
                'allowed_ext' => array('.avi','.mp3')
            ),
            'video' => array(
                'dirs' => array('file'),
                'allowed_ext' => array('.mp4', '.webm', '.ogv')
            ),  
            'download' => array(
                'dirs' => array('file'),
                'allowed_ext' => array('.zip')
            ),
            'photo' => array(
                'dirs' => array('photo'),
                'allowed_ext' => array('.jpg', '.gif', '.png', '.bmp', '.jpeg'),
            ),
        ),
    ),

    /**
     * Mode d'affichage des barres latérales dans une page
     * 'S' : les deux colonnes latérales sont affichées
     * 'W' : aucune des deux colonnes latérales sont affichées
     * 'L' : seule la colonne latérale à gauche est affichée
     * 'R' : seule la colonne latérale à droite est affichée
     */
    'sidebars_display_options' => array('S', 'W', 'L', 'R'),

    /**
     * Tableau définissant les emplacements accessibles des boites
     * 
     * E : éditorial
     * T : entête
     * L : colonne latérale gauche
     * A : colonne centrale au dessus
     * U : colonne centrale au dessous
     * R : colonne latérale droite
     * B : pied de page
     */ 
    'box_positions' => array('L', 'R', 'T', 'E', 'U', 'A', 'B'),
    //

    /**
     * Tableau définissant les différents types d'affichage des boites de menu
     * 
     * off : boite non dynamique ouverte par défaut
     * open : boite dynamique ouverte par défaut
     * close : boite dynamique fermée par défaut
     */ 
    'box_views' => array('off', 'open', 'close'),
    //

    /**
     * Tableau définissant les différents types de boites de menu
     *
     * 0 : boite de menu en liste
     * 1 : boite de menu dynamique
     * 2 : boite de menu en liste dynamique n°1
     * 3 : boite de menu en liste dynamique n°2
     * 4 : boite de menu dunamique compact
     */ 
    'box_types' => array(0, 1, 2, 3, 4),
    //
    
    'update_moddate' => FALSE, // Option par défaut de mise à jour (1) ou non (0) de la date de modification du document lors de l'enregistrement
);