<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require ADMR_CORE_PATH.'/admin_controller.php';

class Admin_check_data_integrity_controller extends Admin_controller
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();         // Données de langue
    protected $_config = array();       // Données de configuration
//    protected $_params = array();       // Données récupérés par post ou get
//    protected $_sort_options = array();	// Options de tri    
  
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct()
    {
        parent :: __construct();        
        
        $this -> load_helper('url_helper');
        $this -> load_helper('var_helper');
        $this -> load_helper('security_helper');
        $this -> load_helper('file_helper');
        
        $this -> load_model('writer_model');
        $this -> load_model('group_model');
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    public function index()
    {        
        $this -> check_integrity();
    }

	// --------------------------------------------------------------------

    public function check_integrity()
    {
        set_time_limit(0);
        
        /**
         * Maintenance des données
         */
        $action = Var_helper :: import('action', 'post', 0, array(), array(array('Var_helper', 'is_alpha_num_dash')));
        $ids = Var_helper :: import('ids', 'post', array(), array(), array(array('Var_helper', 'is_digit')));
        $choice = Var_helper :: import('choice', 'post', 0, array(), array(array('Var_helper', 'is_digit')));
        
        $token_name = 'ADMR_check_data_integrity';
        $token_time_expire = $this -> _config['token_time_expire'];
        $referer = ADMR_SITE_URL.'admin/'.ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER;
        $message = '';
        
        if (!empty($_POST) && Security_helper :: check_token($token_time_expire, $referer, $token_name) ) {            
 
            if ($action == 'group') {  // Maintenance des données des groupes            
                if ($choice == 1) {
                    $this -> _check_users_integrity('group');
                } elseif ($choice == 2 && !empty($ids)) {
                    $this -> _check_users_integrity('group', $ids);    
                }                
                $message = ucfirst(sprintf($this -> _lang['the(m)_%s_succeeded'], $this -> _lang['control_of_integrity_of_groups_data']));
            }
            else if ($action == 'writer') { // Maintenance des données des rédacteurs
                if ($choice == 1) {
                    $this -> _check_users_integrity('writer');
                } elseif ($choice == 2 && !empty($ids)) {
                    $this -> _check_users_integrity('writer', $ids);    
                }
                $message = ucfirst(sprintf($this -> _lang['the(m)_%s_succeeded'], $this -> _lang['control_of_integrity_of_writers_data']));
            }
            else if ($action == 'writer_docs') { // Maintenance des données des documents des rédacteurs
                if ($choice == 1) {
                    $this -> _check_writers_docs_integrity();
                } elseif ($choice == 2 && !empty($ids)) {
                    $this -> _check_writers_docs_integrity($ids);    
                }
                $message = ucfirst(sprintf($this -> _lang['the(m)_%s_succeeded'], $this -> _lang['control_of_integrity_of_writers_docs_data']));
            }
        }     
        //

        $data = array(
            'message' => $message,
            'lang' => $this -> _lang,
            'form_uri' => ADMR_BASE_HREF_PLUGIN.'&amp;ctrl='.ADMR_CONTROLLER,
            'token' => Security_helper :: create_token($token_name),
            'writers' => $this -> _get_writers(),
            'groups' => $this -> _get_groups(),
            'action' => $action,
            'ids' => $ids,
            'choice' => $choice
        );

        parent :: render_page('check_data_integrity', $data);
    }
        
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité les données des utilisateurs (rédacteurs ou groupes)
     * 
     * @access private
     * @param Type d'utilisateurs (writer or group)
     * @param array Tableau contenant les identifiants des utilisateurs à contrôler (tous par défaut)
	 * @return void
	 */
    private function _check_users_integrity($user_type, $users_ids = array())
    {
        $this -> load_model('rights_model', $user_type);

        if (empty($users_ids)) {
            $users_ids = $this -> _get_users_ids($user_type);    
        }
        
        foreach($users_ids as $user_id) {
            $user_data = $this -> rights_model -> read($user_id);
            
            $this -> rights_model -> write($user_id, $user_data);     
        }
        
        return TRUE;
    }
            
	// --------------------------------------------------------------------

	/**
	 * renvoie les chemins des fichiers des rédacteurs et/ou des groupes enregistrés
     * 
     * @access private
     * @param string Type d'utilisateurs (writer ou group)
	 * @return array
	 */	
    private function _get_users_ids($user_type)
    {
        $users_ids = array();
        
        $users_ids = array_keys($this -> {$user_type.'_model'} -> get_all());
        
        return $users_ids;  
    }

	// --------------------------------------------------------------------

	/**
	 * récupère tous les rédacteurs enregistrés 
     * 
     * @access private
	 * @return array
	 */	
    private function _get_writers()
    {
        return $this -> writer_model -> get(array(), 'ch_asc');
    }

	// --------------------------------------------------------------------

	/**
	 * récupère tous les groupes rédacteurs enregistrés 
     * 
     * @access private
	 * @return array
	 */	
    private function _get_groups()
    {
        return $this -> group_model -> get(array(), 'ch_asc');
    }

	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité les documents des rédacteurs
     * 
     * @access private
     * @param array Tableau contenant les identifiants des utilisateurs à contrôler (tous par défaut)
	 * @return void
	 */
    private function _check_writers_docs_integrity($writers_ids = array())
    {
        $this -> load_model('writer_docs_model');
        $this -> load_model('guppy_docid_model');
        
        $guppy_data = $this -> guppy_docid_model -> get(array('status' => array('a', 'i')));
        
        if (empty($writers_ids)) {
            $writers_ids = $this -> _get_users_ids('writer');    
        }
                
        foreach($writers_ids as $writer_id) {
            $this -> writer_docs_model -> load_data($writer_id);
            
            $this -> writer_docs_model -> synchronize_with_guppy_data($guppy_data); // Synchronisation des enregistrements du rédacteur avec ceux de guppy          
        }
        
        return false;
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
/*    protected function set_params()
    {
        $this -> _params = parent :: set_params();
    }
*/    
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['check_plugin_data_integrity']);
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    protected function _set_infos_page_content()
    {		
        return $this -> _lang['infos_page_check_plugin_data_integrity'];
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();
        
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/waiting_process.js"></script>'."\n";
      
        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/form_validator.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/waiting_process.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/check_plugin_data_integrity.css" />'."\n";
 
        return $parent_addons.$js.$css;
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu du plugin qui est affiché en haut de la page
     *
     * @return array
     */
    protected function _set_menu_plugin_items()
    {
        return parent :: _set_menu_plugin_items();
    }
    
	// --------------------------------------------------------------------
	
} //End of Class