<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require ADMR_CORE_PATH.'/admin_controller.php';
 
class Admin_dashboard_controller extends Admin_controller
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();          // Données de langue
    protected $_writer_rights = array(); // Droits du rédacteur    

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct()
    {
        parent :: __construct();
        $this -> load_helper('var_helper');
        $this -> load_helper('url_helper');
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    public function index()
    {
        $data = array(
            'lang' => &$this -> _lang,
            'sections' => $this -> _get_sections_allowed(),
            'addons' => $this -> _get_addons_allowed(),
            'writer_rights' => $this -> _writer_rights,
        );
       
        $this -> render_page('dashboard', $data);
    }
    
	// --------------------------------------------------------------------

    /*
     * Récupère les sections
     *
     * @return array
     */        
    public function _get_sections_allowed()
    {
        $rights = $this -> _admin_rights;
        $sections = array();        

        foreach($rights as $key => $value) {
            if (preg_match('`^([a-z]+)_manage$`', $key, $matches)) {
                if (is_file(ADMR_CONTROLLERS_PATH.'/admin/admin_manage_'.$matches[1].'_controller.php') && !empty($value)) {
                    $sections[] = $matches[1];    
                }    
            }    
        }
        
        sort($sections);

        return $sections;
    }
    
	// --------------------------------------------------------------------

    /*
     * Récupère les addons 
     *
     * @return array
     */        
    public function _get_addons_allowed()
    {
        $rights = $this -> _admin_rights;
        $sections = array();        

        foreach($rights as $key => $value) {
            if (preg_match('`^([a-z]+)_manage$`', $key, $matches)) {
                if (is_dir(ADMR_ADDONS_PATH.'/'.$matches[1]) && !empty($value) && is_dir(CHEMIN.'admin/plugins/'.$matches[1])) {
                    $this -> load_addon_lang($matches[1]);
                    $this -> load_addon_config($matches[1]);
                    
                    if (!isset($this -> _config[$matches[1]]['is_compatible_with_adm_redacteurs']) || !empty($this -> _config[$matches[1]]['is_compatible_with_adm_redacteurs'])) {
                        $sections[] = $matches[1];    
                    }
                }    
            }    
        }
      
        sort($sections);

        return $sections;
    }
    
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['dashboard']); 
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    protected function _set_infos_page_content()
    {
        return $this -> _lang['infos_page_dashboard'];
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    protected function _set_menu_plugin_items()
    {
        return;  
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();

        $js = '';
//        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/dashboard.js"></script>'."\n";

        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/dashboard.css" />'."\n";
        
        return $parent_addons.$js.$css;
    }
    
	// --------------------------------------------------------------------
    
} // End Class