<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require ADMR_CORE_PATH.'/admin_controller.php';

class Admin_migrate_plugin_data_controller extends Admin_controller
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();         // Données de langue
    protected $_config = array();       // Données de configuration
//    protected $_params = array();       // Données récupérés par post ou get
//    protected $_sort_options = array();	// Options de tri    
  
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct()
    {
        parent :: __construct();
        
        $this -> load_model('group_model');
        $this -> load_model('writer_model');
        
        
        $this -> load_helper('url_helper');
        $this -> load_helper('var_helper');
        $this -> load_helper('security_helper');
        $this -> load_helper('file_helper');
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    public function index()
    {
        if (!is_dir(ADMR_PUBLIC_ROOT_PATH.'/data')) {
            Url_helper :: redirect($this -> _config['controller_by_default']['admin']);        
        }
        
        $this -> migrate();
    }

	// --------------------------------------------------------------------

    public function migrate()
    {
        set_time_limit(0);
        
        /**
         * Migration des données
         */
        $step = Var_helper :: import('step', 'post', 0, array(), array(array('Var_helper', 'is_digit')));
        $token_name = 'ADMR_migrate_data';
        $token_time_expire = $this -> _config['token_time_expire'];
        $referer = ADMR_SITE_URL.'admin/'.ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER;
        $message = '';
        
        if (!empty($_POST) && Security_helper :: check_token($token_time_expire, $referer, $token_name) ) {            
 
            if ($step == 1) {  // Migration des données des groupes            
                $this -> _migrate_groups();
                $message = ucfirst(sprintf($this -> _lang['the(f)_%s_succeeded'], $this -> _lang['migration_of_groups_data']));
            }
            else if ($step == 2) { // Migration des données des rédacteur
                $this -> _migrate_writers();
                $message = ucfirst(sprintf($this -> _lang['the(f)_%s_succeeded'], $this -> _lang['migration_of_writers_data']));
            }
            else if ($step == 3) { // Migration des données des rédacteur
                $this -> _migrate_writers_docs();
                $message = ucfirst(sprintf($this -> _lang['the(f)_%s_succeeded'], $this -> _lang['migration_of_writers_docs']));
            }
            elseif ($step == 4) {
               Url_helper :: redirect($this -> _config['controller_by_default']['admin']);
            }
        }       
        //

        $data = array(
            'message' => $message,
            'lang' => $this -> _lang,
            'form_uri' => ADMR_BASE_HREF_PLUGIN.'&amp;ctrl='.ADMR_CONTROLLER,
            'token' => Security_helper :: create_token($token_name),
            'step' => $step+1,
        );

        parent :: render_page('migrate_plugin_data', $data);
    }
   
	// --------------------------------------------------------------------

	/**
	 * renvoie les chemins des fichiers des rédacteurs enregistrés
     * 
     * @access private
	 * @return array
	 */	
    private function _get_writers_filepaths()
    {
        return $this -> _get_users_filepaths('writers');
    }
        
	// --------------------------------------------------------------------

	/**
	 * renvoie les chemins des fichiers des groupes enregistrés
     * 
     * @access private
	 * @return array
	 */	
    private function _get_groups_filepaths()
    {
        return $this -> _get_users_filepaths('groups');
    }
            
	// --------------------------------------------------------------------

	/**
	 * renvoie les chemins des fichiers des rédacteurs et/ou des groupes enregistrés
     * 
     * @access private
     * @param string Type d'utilisateurs (writers ou groups ou les deux si vide (par défaut))
	 * @return array
	 */	
    private function _get_users_filepaths($users = '')
    {
        $dir_path = ADMR_PUBLIC_ROOT_PATH.'/data/redacteurs/';
        $files = array_slice(scandir($dir_path), 2);
        $writers_filepaths = array();
        $groups_filepaths = array();
        
        foreach($files as $file) {
            $ext = strrchr($file, '.');
            if ($ext == '.dtb') {
                $writers_filepaths[] = $dir_path.$file;  
            }
            elseif($ext == '.inc') {
                $groups_filepaths[] = $dir_path.$file;
            }    
        }
        
        if ($users == 'writers') {
            return $writers_filepaths;
        }
        elseif ($users == 'groups') {
            return $groups_filepaths;
        }
        
        return array($writers_filepaths, $groups_filepaths);       
    }
        
	// --------------------------------------------------------------------

	/**
	 * migre les données des rédacteurs
     * 
     * @access private
	 * @return void
	 */
    private function _migrate_groups()
    {
        $files_paths = $this -> _get_groups_filepaths();
        
        $this -> _create_groups_index($files_paths); // Enregistrement dans l'index des groupes
        
        $this -> _create_files_groups_rights($files_paths); // Création des fichiers de droits des groupes
        
        return TRUE;
    }

	// --------------------------------------------------------------------

	/**
	 * migre les données des rédacteurs
     * 
     * @access private 
	 * @return void
	 */	
    private function _migrate_writers()
    {
        $files_paths = $this -> _get_writers_filepaths();

        $this -> _create_writers_index($files_paths); // Enregistrement dans l'index des rédacteurs
        
        $this -> _create_files_writers_rights($files_paths); // Création des fichiers de droits des rédacteurs
        
        return TRUE;
    }


	// --------------------------------------------------------------------

	/**
	 * Enregistre les rédacteurs dans le fichier index writer_id.dtb
     * 
     * @access private
     * @param mixed Chemin du ou des fichiers
	 * @return void
	 */	
    private function _create_writers_index($files_paths)
    {
        settype($files_paths, 'array');

        $writers_data = array();
        
        foreach($files_paths as $file_path) {
            $writer_name = str_replace('.dtb', '', basename($file_path));
            
            $writer = $this -> writer_model -> get_by_name($writer_name);
            
            if (empty($writer)) {
                $writers_data[] = array(
                    'name'    => $writer_name,
                    'status'  => 'a',
                    'groupid' => 0       
                );                
            }          
        }

        /**
         * Enregistrement dans l'index des rédacteurs
         */
        $writer_id = $this -> writer_model -> insert_many($writers_data);
        //
    }

	// --------------------------------------------------------------------

	/**
	 * crée les fichiers de droits des rédacteurs
     * 
     * @access private
     * @param mixed Chemin du ou des fichiers
	 * @return void
	 */	
    private function _create_files_writers_rights($files_paths)
    {
        settype($files_paths, 'array');
        $this -> load_model('rights_model', 'writer', 'writer_rights_model');

        
        foreach($files_paths as $file_path) {
            $redacprefs = array();
            
            include $file_path;
            
            $writer = $this -> writer_model -> get_by_name($redacprefs['rpseudo']);
            
            if (!empty($writer)) {
                $this -> writer_rights_model -> write(
                    $writer['id'],
                    array_merge(
                        array(
                            'id'  => $writer['id'],
                            'name'  => $redacprefs['rpseudo'],
                            'pass'    => $redacprefs['rpass'],
                            'groupid' => 0
                        ),
                        $this -> _get_user_rights_updated($redacprefs)
                    )
                );
            }
        }
    }

	// --------------------------------------------------------------------

	/**
	 * Enregistre les groupes dans le fichier index group_id.dtb
     * 
     * @access private
     * @param mixed Chemin du ou des fichiers
	 * @return void
	 */	
    private function _create_groups_index($files_paths)
    {
        settype($files_paths, 'array');

        $groups_data = array();
        
        foreach($files_paths as $file_path) {
            $group_name = str_replace(array('grp_', '.inc'), '', basename($file_path));
            
            $group = $this -> group_model -> get_by_name($group_name);
            
            if (empty($group)) {
                $groups_data[] = array(
                    'name'    => $group_name,
                );                
            }            
        }

        /**
         * Enregistrement dans l'index des rédacteurs
         */
        $writer_id = $this -> group_model -> insert_many($groups_data);
        //
    }

	// --------------------------------------------------------------------

	/**
	 * crée les fichiers de droits des groupes
     * 
     * @access private
     * @param mixed Chemin du ou des fichiers
	 * @return void
	 */	
    private function _create_files_groups_rights($files_paths)
    {
        settype($files_paths, 'array');
        $this -> load_model('rights_model', 'group', 'group_rights_model');

        
        foreach($files_paths as $file_path) {
            $redacprefs = array();
            
            include $file_path;
            
            $group = $this -> group_model -> get_by_name($redacprefs['rgroupseudo']);
            
            if (!empty($group)) {
                $this -> group_rights_model -> write(
                    $group['id'],
                    array_merge(
                        array(
                            'id'  => $group['id'],
                            'name'  => $group['name'],
                        ),
                        $this -> _get_user_rights_updated($redacprefs)
                    )
                );
            }
        }
    }
        
	// --------------------------------------------------------------------

	/**
	 * Met à jours les anciennes données des utilisateurs (rédacteurs, groupes rédacteurs)
     * 
     * @access private
     * @param array Anciennes données des utilisateurs
	 * @return void
	 */
    private function _get_user_rights_updated($redacprefs)
    {
        return array(
            'modify_password' => ($redacprefs['rwritpass'] == 'Off') ? 0 : 1,
            'agenda_manage' => empty($redacprefs['ragenda']) ? 0 : 1,              'agenda_add' => empty($redacprefs['rwritagenda']) ? 0 : 1,    'agenda_edit' => empty($redacprefs['rmodagenda']) ? 0 : 1,    'agenda_act' => empty($redacprefs['ractagenda']) ? 0 : 1,    'agenda_del' => 0,      'agenda_send_email' => 0,                                                  'agenda_publication_manage' => 0,      'agenda_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1, 
            'articles_manage' => empty($redacprefs['rart']) ? 0 : 1,               'articles_add' => empty($redacprefs['rwritart']) ? 0 : 1,     'articles_edit' => empty($redacprefs['rmodart']) ? 0 : 1,0,   'articles_act' => empty($redacprefs['ractart']) ? 0 : 1,     'articles_del' => 0,    'articles_send_email' => ($redacprefs['rsendmailadmin'] == 'Off') ? 0 : 1, 'articles_publication_manage' => 0,    'articles_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1,                                                                                                                                     'articles_to_be_added' => array(),  'articles_to_be_removed' => array(),    'articles_icon_manage' => 0, 'articles_sidebars_manage' => 0,
            'banners_manage' => empty($redacprefs['rbanner']) ? 0 : 1,             'banners_add' => empty($redacprefs['rwritbanner']) ? 0 : 1,   'banners_edit' => empty($redacprefs['rmodbanner']) ? 0 : 1,   'banners_act' => empty($redacprefs['ractbanner']) ? 0 : 1,   'banners_del' => 0,     'banners_send_email' => 0,                                                 'banners_publication_manage' => 0,     'banners_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1, 
            'blog_manage' => empty($redacprefs['rblog']) ? 0 : 1,                  'blog_add' => empty($redacprefs['rwritblog']) ? 0 : 1,        'blog_edit' => empty($redacprefs['rmodblog']) ? 0 : 1,        'blog_act' => empty($redacprefs['ractblog']) ? 0 : 1,        'blog_del' => 0,        'blog_send_email' => 0,                                                    'blog_publication_manage' => 0,        'blog_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1,       'blog_cats_manage' => empty($redacprefs['rwritcatblog']) ? 0 : 1,        'blog_cats_list_allowed' => array(array(), array()), 
            'boxmenus_manage' => 0,                                                'boxmenus_add' => 0,                                          'boxmenus_edit' => 0,                                         'boxmenus_act' => 0,                                         'boxmenus_del' => 0,    'boxmenus_send_email' => 0,                                                'boxmenus_publication_manage' => 0,    'boxmenus_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1,                                                                                                                                      'boxmenus_to_be_added' => array(),  'boxmenus_to_be_removed' => array(),                                                                  'boxmenus_display_manage' => 0,  'boxmenus_positions_manage' => 0,  'boxmenus_type_manage' => 0, 
            'downloads_manage' => empty($redacprefs['rdnload']) ? 0 : 1,           'downloads_add' => empty($redacprefs['rwritdnload']) ? 0 : 1, 'downloads_edit' => empty($redacprefs['rmoddnload']) ? 0 : 1, 'downloads_act' => empty($redacprefs['ractdnload']) ? 0 : 1, 'downloads_del' => 0,   'downloads_send_email' => 0,                                               'downloads_publication_manage' => 0,   'downloads_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1,  'downloads_cats_manage' => empty($redacprefs['rwritcatdnload']) ? 0 : 1, 'downloads_cats_list_allowed' => array(array(), array()),                                                                                                                                                                                                                                            'downloads_licence_manage' => 0,
            'faq_manage' => empty($redacprefs['rfaq']) ? 0 : 1,                    'faq_add' => empty($redacprefs['rwritfaq']) ? 0 : 1,          'faq_edit' => empty($redacprefs['rmodfaq']) ? 0 : 1,          'faq_act' => empty($redacprefs['ractfaq']) ? 0 : 1,          'faq_del' => 0,         'faq_send_email' => 0,                                                     'faq_publication_manage' => 0,         'faq_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1,        'faq_cats_manage' => empty($redacprefs['rwritcatfaq']) ? 0 : 1,          'faq_cats_list_allowed' => array(array(), array()), 
            'freeboxes_manage' => empty($redacprefs['num_ajoutefreebox']) ? 0 : 1, 'freeboxes_add' => 0,                                         'freeboxes_edit' => 0,                                        'freeboxes_act' => 0,                                        'freeboxes_del' => 0,   'freeboxes_send_email' => 0,                                               'freeboxes_publication_manage' => 0,   'freeboxes_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1,                                                                                                                                    'freeboxes_to_be_added' => array(), 'freeboxes_to_be_removed' => array(),                                                                 'freeboxes_display_manage' => 0, 'freeboxes_positions_manage' => 0, 
            'links_manage' => empty($redacprefs['rlinks']) ? 0 : 1,                'links_add' => empty($redacprefs['rwritlinks']) ? 0 : 1,      'links_edit' => empty($redacprefs['rmodlinks']) ? 0 : 1,      'links_act' => empty($redacprefs['ractlinks']) ? 0 : 1,      'links_del' => 0,       'links_send_email' => 0,                                                   'links_publication_manage' => 0,       'links_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1,      'links_cats_manage' => empty($redacprefs['rwritcatlinks']) ? 0 : 1,      'links_cats_list_allowed' => array(array(), array()), 
            'menuitems_manage' => 0,                                               'menuitems_add' => 0,                                         'menuitems_edit' => 0,                                        'menuitems_act' => 0,                                        'menuitems_del' => 0,   'menuitems_send_email' => 0,                                               'menuitems_publication_manage' => 0,   'menuitems_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1,  'menuitems_cats_manage' => 0,                                            'menuitems_cats_list_allowed' => array(array(), array()), 'menuitems_boxes_manage' => 1,   'menuitems_boxes_list_allowed' => array(),                              'menuitems_sidebars_manage' => 0,        
            'news_manage' => empty($redacprefs['rnews']) ? 0 : 1,                  'news_add' => empty($redacprefs['rwritnews']) ? 0 : 1,        'news_edit' => empty($redacprefs['rmodnews']) ? 0 : 1,        'news_act' => empty($redacprefs['ractnews']) ? 0 : 1,        'news_del' => 0,        'news_send_email' => ($redacprefs['rsendmailadmin'] == 'Off') ? 0 : 1,     'news_publication_manage' => 0,        'news_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1,                                                                                                                                                                                                                      'news_icon_manage' => 0,
            'newsletters_manage' => 0,                                             'newsletters_add' => 0,                                       'newsletters_edit' => 0,                                      'newsletters_act' => 0,                                      'newsletters_del' => 0, 'newsletters_send_email' => 0,                                             'newsletters_publication_manage' => 0, 
            'photoramas_manage' => empty($redacprefs['rphoto']) ? 0 : 1,           'photoramas_add' => empty($redacprefs['rwritphoto']) ? 0 : 1, 'photoramas_edit' => empty($redacprefs['rmodphoto']) ? 0 : 1, 'photoramas_act' => empty($redacprefs['ractphoto']) ? 0 : 1, 'photoramas_del' => 0,  'photoramas_send_email' => 0,                                              'photoramas_publication_manage' => 0,  'photoramas_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1, 'photoramas_cats_manage' => empty($redacprefs['rwritcatphoto']) ? 0 : 1, 'photoramas_cats_list_allowed' => array(array(), array()),
            'photos_manage' => empty($redacprefs['rphoto']) ? 0 : 1,               'photos_add' => empty($redacprefs['rwritphoto']) ? 0 : 1,     'photos_edit' => empty($redacprefs['rmodphoto']) ? 0 : 1,     'photos_act' => empty($redacprefs['ractphoto']) ? 0 : 1,     'photos_del' => 0,      'photos_photoramas_manage' => 1,   'photos_photoramas_list_allowed' => array(),
            'thinks_manage' => empty($redacprefs['rthink']) ? 0 : 1,               'thinks_add' => empty($redacprefs['rwritthink']) ? 0 : 1,     'thinks_edit' => empty($redacprefs['rmodthink']) ? 0 : 1,     'thinks_act' => empty($redacprefs['ractthink']) ? 0 : 1,     'thinks_del' => 0,      'thinks_send_email' => 0,                                                  'thinks_publication_manage' => 0,      'thinks_private_group_manage' => empty($redacprefs['raccessprivategroup']) ? 0 : 1,  
            'files_manage' => empty($redacprefs['rfile']) ? 0 : 1,                 'files_add' => empty($redacprefs['rwritfile']) ? 0 : 1,       'files_edit' => 0, 'files_del' => 0,       
            'files_dirs_manage' => 1,  'files_dirs_add' => empty($redacprefs['rmodfile']) ? 0 : 1,  'files_dirs_edit' => 0, 'files_dirs_del' => 0,  'files_dirs_list_allowed' => array(),
            
            'writers_manage' => 0, 'writers_allowed' => 0, 'writers_list_allowed' => array(), 'writers_groups_list_allowed' => array(), 
            'writers_docs_manage' => 0, 'writers_docs_edit' => 0, 'writers_docs_act' => 0, 'writers_docs_del' => 0, 'writers_docs_types_allowed' => array(),
        );    
    }

	// --------------------------------------------------------------------

	/**
	 * migre les données des rédacteurs et des groupes
     * 
     * @access private
	 * @return void
	 */	
    private function _migrate_writers_docs()
    {
        $dir = ADMR_PUBLIC_ROOT_PATH.'/data/redac_doc/';
        $files = array_slice(scandir($dir), 2);
        
        foreach($files as $file) {
            $ext = strrchr($file, '.');
            if ($ext == '.dtb') {
                $writer_name = str_replace(array('doc_', $ext), '', $file);
                $writer = $this -> writer_model -> get_by_name($writer_name);
                
                if (!empty($writer)) {
                    $old_docs_file = $dir.$file;
                    $new_docs_file = ADMR_WRITER_DOCS_PATH.'/'.ADMR_WRITER_DOCS_FILE_PREFIX.$writer['id'].DBEXT;
                    
                    $data = file_get_contents($old_docs_file);
                    
                    file_put_contents($new_docs_file, $data, FILE_APPEND | LOCK_EX);  
                }
            }
        }
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
/*    protected function set_params()
    {
        $this -> _params = parent :: set_params();
    }
*/    
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['migration_plugin_data']);
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
/*    protected function _set_infos_page_content()
    {		
        return 'Bienvenue dans le processus de migration des données du plugin adm_redacteurs v5.x.';
        
        return $this -> _lang['infos_page_migrate_datas'];
    }
*/    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();
        
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/migrate_plugin_data.js"></script>'."\n";
      
        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/migrate_plugin_data.css" />'."\n";
 
        return $parent_addons.$js.$css;
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu du plugin qui est affiché en haut de la page
     *
     * @return array
     */
    protected function _set_menu_plugin_items()
    {
        return array();
    }
    
	// --------------------------------------------------------------------
	
} //End of Class