<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

abstract class Public_controller extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_writer_rights = array(); // Droits du rédacteur connecté

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */        
    public function __construct()
    {
        parent :: __construct();
        
        $this -> load_helper('var_helper');
        $this -> load_helper('url_helper');       
        $this -> load_helper('plugin_menu_helper');
        $this -> load_helper('page_helper');       
        $this -> load_library('writer_authentification', NULL, 'writer_auth');
        $this -> load_model('writers_online_model');
      
        if (! $this -> writer_auth -> is_logged_in()) {           
            Url_helper :: redirect('connect/logout');
        }
        
        $this -> _writer_rights = $this -> _set_writer_rights();
        $this -> writers_online_model -> update($_SESSION['admr']['writerid']); // Mise à jour du rédacteur en ligne
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    /**
     * Affiche ou renvoie le contenu de la vue
     *
     * @param string Nom du fichier de la vue
     * @param array Données à faire passer à la vue
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    public function render_page($filename, $data = array(), $return = FALSE)
    {
        $this -> page_helper -> set_page_layout('public_layout');
        $this -> page_helper -> set_infos_page_content($this -> _set_infos_page_content());
        $this -> page_helper -> set_menu_plugin_items($this -> _set_menu_plugin_items());
        $this -> page_helper -> set_infos_plugin($this -> _set_infos_plugin());
        
        $this -> page_helper -> render_page($filename, $data, $return);
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie les droits du rédacteur
     *
     * @return array Tableau contenant les droits du rédacteur
     */
    protected function _set_writer_rights()
    {
         return $this -> writer_auth -> get_writer_rights();
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu des informations qui sont affichés dans le bandeau en haut de la page
     *
     * @return string Contenu html des informations (vide par défaut)
     */
    protected function _set_infos_page_content()
    {
        return '';
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    protected function _set_menu_plugin_items()
    {
        return array();    
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu des informations du plugin qui sont affichées en bas de la page
     *
     * @return array Tableau contenant les informations du plugin sous la forme array('version' => , 'licence' => )
     */
    protected function _set_infos_plugin()
    {
        return array();
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();
        
        $js = ''; 
//        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/xxxxxx.js"></script>'."\n";
        
        $css = '';
        $css .= '<link type="text/css" rel="stylesheet" href="'.ADMR_CSS_PATH.'/public_layout.css" />';

        return $css.$js.$parent_addons;        
    }

	// --------------------------------------------------------------------

	/**
	 * renvoie le nom du rédacteur connecté
     * 
     * @access public
	 * @return string Nom du rédacteur
	 */
    public function get_writer_name()
    {
        return $this -> writer_auth -> get_writer_name();
    }

	// --------------------------------------------------------------------

	/**
	 * renvoie l'id du rédacteur connecté
     * 
     * @access public
	 * @return string Nom du rédacteur
	 */
    public function get_writer_id()
    {
        return $this -> writer_auth -> get_writer_id();
    }
    
} // End of class