<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/add_record_helper.php';

class Add_photos_helper extends Add_record_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI;                       // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_record_id = 0;           // Identifiant de l'enregistrement (photo)
    protected $_record_data = array();   // Tableau contenant les données de l'enregistrement
    protected $_form_params = array();   // Tableau contenant les données de l'enregistrement postées dans le formulaire
 	protected $_form_errors = array();	 // Tableau contenant les messages d'erreur dans le formulaire
    protected $_form_validation = FALSE; // Validation du formulaire (TRUE ou FALSE)  

    protected $_doc_infos = array('name' => 'photoramas', 'type' => TYP_PHOTO); // Tableau contenant les informations du document (nom, type)
    protected $_writer_rights = array(); // Droits du rédacteur
    
    protected $_photorama_id = 0; // Identifiant du photorama
    protected $_photo_id = 0;     // Identifiant de la photo du photorama
    //
        
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct($writer_rights = array())
    {        
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);

        parent :: __construct();

        $this -> _photorama_id = $this -> _form_params['galid'];
        $this -> _photo_id = $this -> _record_id;

        $this -> CI -> load_model($this -> _doc_infos['name'].'_model'); // Model du type de document
        $this -> CI -> load_model($this -> _doc_infos['name'].'_index_model'); // Model du type de document
        $this -> CI -> load_model($this -> _doc_infos['name'].'_diapos_model', array('id' => $this -> _photorama_id)); // Model du type de document           
        $this -> CI -> load_model($this -> _doc_infos['name'].'_params_model', array('id' => $this -> _photorama_id)); // Model du type de document           

        $this -> CI -> load_model('writer_docs_model', array('id' => $this -> _writer_rights['id']));
       
        if (! ADMR_IS_ADMIN && (! $this -> _is_photorama_allowed($this -> _photorama_id) || ! $this -> _is_doc_allowed($this -> _photo_id))) {
            Url_helper :: redirect('display_error&type=disallowed');
        }
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */    

    /**
	 * Index
     * 
	 * @access public
     * @return void
	 */	
    public function index()
    {
        parent :: index();    
    }

	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function upload()
    {        
        $errors = '';

        $_SERVER['HTTP_REFERER'] = preg_replace('`'.str_replace('/upload', '', ADMR_CONTROLLER).'[&=#_\-a-z0-9]*$`', str_replace('/upload', '', ADMR_CONTROLLER).'/upload', $_SERVER['HTTP_REFERER']);

        if ($this -> _writer_rights['photos_add'] && parent :: _is_valid_form($form_errors = array(), $token_name = 'upload_record')) {

            // Upload
            $this -> CI -> load_helper('upload_files_helper');       
            $this -> CI -> upload_files_helper -> set_dir_path(PHOTOREP.'gal_'.$this -> _photorama_id);
            $this -> CI -> upload_files_helper -> set_file_type('photo');
            $this -> CI -> upload_files_helper -> do_upload();
            
            $errors = $this -> CI -> upload_files_helper -> get_errors();
            
            // Création des miniatures des fichiers chargés
            $files_uploaded = $this -> CI -> upload_files_helper -> get_files_uploaded();
            
            if (!empty($files_uploaded)) {
                $this -> _create_thumbnails($files_uploaded);
                $this -> _add_diapos_in_photorama($files_uploaded);
            }
                           
           
            // Redirection
            if (empty($errors)) {          
                $uri = str_replace('/upload', '', ADMR_CONTROLLER).'&galid='.$this -> _photorama_id;
                
                if (!empty($this -> _photo_id)) {
                    $uri .= '&id='.$this -> _photo_id;
                }
                
                //Url_helper :: redirect($uri);      
            }
        } elseif(!empty($_POST)) {
            $errors['erreur'] = 'La soumission du formulaire n\'est pas validé';    
        }
        
        $this -> _build_form_upload($errors, FALSE);
    }

	// --------------------------------------------------------------------

 	/**
	 * Crée une miniature des photos du photorama
     *
     * @access public 
	 * @param array Tableau contenant les noms des photos correspondant aux miniatures à créer (si vide => toutes les photos)
	 * @return void
	 */    
    protected function _build_form_upload($errors = array(), $return = TRUE)
    {
        $data = array(
            'lang' => $this -> _lang,
            'config' => $this -> _config,
            'validation' => empty($errors) ? TRUE : FALSE,
            'form_uri' => str_replace('/upload', '', Url_helper :: build_uri()).'/upload',
            'token' => Security_helper :: create_token('upload_record'),
            'errors' => $errors,
            'photoramas' => $this -> _get_photoramas(),
            'photorama_id' => $this -> _photorama_id,
            'photo_id' => $this -> _photo_id,
        );

        if ($return) {
            return $this -> CI -> render('upload_photos_layout', $data, $return);
        } else {
            $this -> CI -> render_page('upload_photos_layout', $data);    
        }
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des galeries photos à gérer en tenant compte de la configuration du rédacteur
	 *
	 * @access	protected
	 * @return	array sous la forme array(id => name)
	 */
    protected function _get_photoramas()
    {        
        $photoramas = array();
        $doc_infos = $this -> _doc_infos;
        $authorization = $this -> _writer_rights['photos_photoramas_manage'];
   
        if (in_array($authorization, array('1', '2', '3'))) {
            $this -> CI -> load_helper('photoramas_helper');
            $photoramas = $this -> CI -> photoramas_helper -> get_all(); // Toutes les galeries photos enregistrées dans guppy (par défaut) 
          
            if ($authorization == '3') { // Uniquement les galeries photos du rédacteur           
                $photoramas = array_intersect_key($photoramas, $this -> CI -> writer_docs_model -> get(array('type' => $doc_infos['type'])));
            }
            //
            
            elseif ($authorization == '2') { // Uniquement les galeries photos sélectionnées
                $photoramas = array_intersect_key($photoramas, array_flip($this -> _writer_rights['photos_photoramas_list_allowed']));                  
            }
            //
        }

        return $photoramas;     
    }

	// --------------------------------------------------------------------

 	/**
	 * Crée une miniature des photos du photorama
     *
     * @access public 
	 * @param array Tableau contenant les noms des photos correspondant aux miniatures à créer (si vide => toutes les photos)
	 * @return void
	 */    
    protected function _create_thumbnails($photos = array())
    {
        $photorama_params = $this -> CI -> photoramas_params_model -> read();
        
        $this -> CI -> photoramas_diapos_model -> create_thumnails($photos, $photorama_params['width_max'], $photorama_params['height_max']);       

        return TRUE;
    }

	// --------------------------------------------------------------------

 	/**
	 * Crée une miniature des photos du photorama
     *
     * @access public 
	 * @param array Tableau contenant les noms des photos correspondant aux miniatures à créer (si vide => toutes les photos)
	 * @return void
	 */    
    protected function _add_diapos_in_photorama($photos = array())
    {
        $records = array();
        
        foreach($photos as $photo) {
            $records[]['filename'] = basename($photo); 
        }

        $this -> CI -> photoramas_diapos_model -> insert($records);       

        return TRUE;
    }

	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
//        return ucfirst($this -> _lang['add_'.$this -> _doc_infos['name'].'_diapos']);

        return ucfirst('Ajouter des photos dans la galerie photos');
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string infos de la page
	 */	
    public function set_infos_page_content()
    {		
        return '';
    }

	// --------------------------------------------------------------------

    /*
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {
        if (ADMR_IS_ADMIN) {
            return Plugin_menu_helper :: set_admin_menu_items($this -> _lang, $this -> _config);    
        } else {
            return array(
                Plugin_menu_helper :: add_item_for_go_dashboard('photos', $this -> _lang), // retour au tableau de bord
                Plugin_menu_helper :: add_item( // Icone pour la gestion des photos
                    array(
                        'is_allowed' => $this -> _writer_rights['photos_manage'],
                        'title' => $this -> _lang['manage_photos'],
                        'class' => 'manage_docs photos',
                        'controller' => 'manage_photos',
                        'query' => '&galid='.$this -> _photorama_id,
                    )
                ),
                Plugin_menu_helper :: add_item( // Icone pour l'ajout des photos
                    array(
                        'is_allowed' => $this -> _writer_rights['photos_add'],
                        'title' => $this -> _lang['add_photos'],
                        'class' => 'add_doc photos',
                        'controller' => 'add_photos',
                        'pattern_to_search_in_uri' => array('method' => 'no_strict'),
                        'query' => '&galid='.$this -> _photorama_id,
                    )
                ),
                Plugin_menu_helper :: add_item_for_disconnect('photos', $this -> _lang) // Déconnexion
            );           
        }
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {        
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/placeholder/jquery.placeholder.min.js"></script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/datetimepicker/jquery.datetimepicker.min.js"></script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/form-validator/jquery.form-validator.min.js"></script>'."\n";
        $js .= '<script type="text/javascript">$.formUtils.loadModules("module_add_doc", "'.ADMR_JS_PATH.'/form-validator/my_modules/");</script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/add_doc.js"></script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/add_photos.js"></script>'."\n";
        
        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/form_validator.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/add_doc.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/add_photos.css" />'."\n";

        return $js.$css;
    }

	// --------------------------------------------------------------------

	/**
	 * définit les droits du rédacteur
     * 
     * @access protected
     * @param array Tabelau définissant les droits du rédacteur (vide par défaut) 
	 * @return array Tableau contenant les droits du rédacteur
	 */	
    protected function _set_writer_rights($writer_rights = array())
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;        
    }

	// --------------------------------------------------------------------

	/**
	 * construit et retourne le contenu de l'attribut action du formulaire
     * 
     * @access protected
     * @param mixed Options du menu select
	 * @return void
	 */	
    protected function _build_form_action_content()
    {
        return Url_helper :: build_uri(array(
            'galid' => $this -> _photorama_id,
            'id' => $this -> _photo_id,
//            'idpg'  => Var_helper :: import('idpg', '', 1, array('trim'), array(array('Var_helper', 'is_digit'))),
//            'sort'  => Var_helper :: import('sort', '', $this -> _config['sort_option_by_default'], array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))),
        ));
    }

	// --------------------------------------------------------------------

    /**
	 * Ajoute des données supplémentaires pour la vue sous la forme array(key => value)
     * 
	 * @access protected
     * @return array
	 */	
    protected function _add_more_data_for_add_record_view()
    {
        return array(
            'writer_rights' => $this -> _writer_rights,
            'photorama_id' => $this -> _photorama_id,
            'photos' => $this -> _get_photos(),
          //  'dir_path' => $this -> CI -> photoramas_diapos_model -> get_dir_path(),
            'dir_path_for_thumbs' => $this -> CI -> photoramas_diapos_model -> get_dir_path_for_thumbs(),
            'form_upload' => $this -> _build_form_upload(),
            'photorama_params' => $this -> CI -> photoramas_params_model -> read(),
        );
    }

	// --------------------------------------------------------------------

	/**
	 * construit le formulaire de sélection des photos du photorama
     * 
     * @access protected
	 * @return string
	 */	
    protected function _get_photos()
    {
        $photos = array();

        $photos = $this -> CI -> photoramas_diapos_model -> scan_photos();       

        return $photos;               
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_add_record_view()
    {
        return 'add_photos_layout';    
    }

	// --------------------------------------------------------------------

    /**
	 * Ajoute ou modifie un enregistrement
     * 
	 * @access protected
     * @return boolean
	 */	
    protected function _add_record()
    {
        return parent :: _add_record();
    }

	// --------------------------------------------------------------------

    /**
	 * Crée un nouvel enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return integer Identifiant de l'enregistrement créé
	 */
    protected function _insert_record($record)
    {
        return FALSE;    
    }
    
	// --------------------------------------------------------------------

    /**
	 * Met à jours les données de l'enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return void
	 */
    protected function _update_record($record)
    {
        $this -> CI -> {$this -> _doc_infos['name'].'_diapos_model'} -> update($record); // Guppy

        return TRUE;    
    }
    
	// --------------------------------------------------------------------

    /**
	 * Ajoute d'autres actions après l'ajout ou la mise à jour d'un document
     * 
	 * @access protected
     * @return void
	 */
    protected function _add_more_action_after_adding_record()
    {
        $params =& $this -> _form_params;
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les données du document
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array Données enregistrées du document
	 */    
    protected function _get_record_data($record_id)
    {
        $this -> _photorama_id = Var_helper :: import('galid', 'POST_GET', 0, array('trim'), array(array('Var_helper', 'is_digit')));

        $this -> CI -> load_model($this -> _doc_infos['name'].'_diapos_model', array('id' => $this -> _photorama_id)); // Model du type de document           

        $record = $this -> CI -> {$this -> _doc_infos['name'].'_diapos_model'} -> get(array('id' => $record_id));
        
        return !empty($record[$record_id]) ? $record[$record_id] : array();     
    }

	// --------------------------------------------------------------------
    
    /**
	 * Définit les valeurs des paramètres du formulaire
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array
	 */    
    protected function _set_form_params()
    {
        return array_merge(
            parent :: _set_form_params(),
            array(
                'galid' => Var_helper :: import('galid', '', 0, array('trim'), array(array('Var_helper', 'is_digit'))),
            )
        );
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les paramètres postés dans le formulaire
     * 
	 * @access protected
     * @return array Tableau contenant les paramètres postés dans le formulaire
	 */    
    protected function _get_form_params_posted()
    {
        return parent :: _get_form_params_posted();
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les paramètres avec leur valeur par défaut dans le formulaire
     * 
	 * @access protected
     * @return array Tableau contenant les paramètres postés dans le formulaire
	 */    
    protected function _get_form_params_by_default()
    {
        return  parent :: _get_form_params_by_default();      
    }

	// --------------------------------------------------------------------

    /**
	 * définit et renvoie les règles de validation des paramètres du formulaire
     * 
	 * @access protected
     * @param array Tableau contenant les paramètres à vérifer lors de la validation
     * @return array Tableau contenant les règles de validation des paramètres ainsi que les messages d'erreur associés 
     * sous la forme suivante : array(param1 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                                param2 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                               ...
     *                          )
	 */	
    protected function _get_form_params_rules($params)
    {
        return $this -> CI -> {$this -> _doc_infos['name'].'_diapos_model'} -> set_params_rules($params, $this -> _lang, $this -> _config);
    }

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès au photorama par le rédacteur
     * 
	 * @access public
     * @return void
	 */
    protected function _is_photorama_allowed($photorama_id)
    {
        if (!empty($photorama_id) && ! array_key_exists($photorama_id, $this -> _get_photoramas())) {
            return FALSE;
        }

        return TRUE;    
    }

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès au document par le rédacteur
     * 
	 * @access public
     * @return void
	 */
    protected function _is_doc_allowed($photo_id)
    {   
        if (empty($photo_id) && !empty($this -> _writer_rights['photos_add'])) { // Ajout de nouveau document
            return TRUE;
        }
        else {  // Edition d'un document
        
            $doc = $this -> CI -> photoramas_diapos_model -> get_by_id($photo_id);

            if (!empty($doc) && !empty($this -> _writer_rights['photos_edit'])) {
                return TRUE;
            }   
        }
        
        return FALSE;    
    }

	// --------------------------------------------------------------------

 } // End of class