<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Date_helper
{
	/**
	 * renvoie la date d'aujourd'hui
     * 
     * @access public 
	 * @param string Format de sortie de la date (format Y/m/d par défaut)
	 * @return string Date prête à être enregistrée dans la base de donnée
	 */
    public static function get_current_date($format = 'Y/m/d')
    {
        return date($format);
    }

	// --------------------------------------------------------------------

	/**
	 * renvoie l'heure actuelle
     * 
     * @access public 
	 * @param string Format de sortie de l'heure (format H par défaut)
	 * @return string Heure prête à être enregistrée dans la base de donnée
	 */
    public static function get_current_hour($format = 'H')
    {
        return date($format);
    }

	// --------------------------------------------------------------------

	/**
	 * renvoie les minutes à l'instant actuel
     * 
     * @access public
	 * @return string Nombre de minutes à l'instant actuel
	 */
    public static function get_current_minutes()
    {
        return date('i');
    }

	// --------------------------------------------------------------------

	/**
	 * renvoie le  nombre de secondes à l'instant actuel
     * 
     * @access public 
	 * @param string Nombre de secondes à l'instant actuel
	 */
    public static function get_current_seconds()
    {
        return date('s');
    }

	// --------------------------------------------------------------------

    /**
     * récupère les dates de publication à partir de la date de création formatée sous la forme date0('YmdHi')-date1('YmdHi')
     *
     * @access public
     * @param string Date de création du document sous la forme date0('YmdHi')-date1('YmdHi')
     * @return array Tableau contenant les dates de publication
     */
    public static function convert_createdate_to_pubdates($createdate)
    {
		$out = array();

        $pubdates = explode('-', $createdate);
        if (empty($pubdates[1])) {
            $pubdates[1] = '';    
        }
            
		foreach($pubdates as $pubdate) {
            if (!empty($pubdate)) {
                $year = substr($pubdate, 0, 4);
                $month = substr($pubdate, 4, 2);
                $day = substr($pubdate, 6, 2);
                $hour = substr($pubdate, 8, 2);
                $minute = substr($pubdate, 10, 2);
                
                $date = $year.'/'.$month.'/'.$day;
                $out = array_merge($out, array($date, $hour, $minute));  
    		} else {
                $out = array_merge($out, array('', '', '')); 
    		}		  
		}
      
        return $out;       
    }

	// --------------------------------------------------------------------

    /**
     * construit la date de création à partir des dates de publication
     *
     * @access public
     * @param array Tableau contenant les dates de début et fin de publication
     * @param array Tableau contenant les heures de début et fin de publication
     * @param array Tableau contenant les minutes de début et fin de publication
     * @return string Date de création sous la forme date0('YmdHi') - date1('YmdHi')
     */
    public static function convert_pubdates_to_createdate($dates = array('', ''), $hours = array('', ''), $minutes = array('', ''))
    {
        $pubdates = array();
        
        for($i = 0; $i < 2; $i ++) {
            if (!empty($dates[$i])) {
                $dates[$i] = str_replace('/', '', $dates[$i]);
                
                if (empty($hours[$i])) {
                    $hours[$i] = date('H');    
                }
                
                if (empty($minutes[$i])) {
                    $minutes[$i] = date('i');    
                }
                
                $pubdates[] = $dates[$i].$hours[$i].$minutes[$i];
            } else {
                $pubdates[] = '';
            }
        }        
        
        $createdate = rtrim(implode('-', $pubdates), '-');
        
        return $createdate;
    }   

	// --------------------------------------------------------------------

	/**
	 * Vérifie si la publication du document est autorisée ou non à la date du jour
     * 
     * @access public 
	 * @param string Dates de publication sous la forme date0('YmdHi') - date1('YmdHi')
	 * @return boolean
	 */
    public static function is_valid_date_for_publication($dates)
	{
        $pubdates = explode('-', $dates);
        $current_date  = self :: get_current_date('YmdHi');
        
        if ($current_date >= $pubdates[0]) {          
            if (empty($pubdates[1]) || $current_date < $pubdates[1]) {
                return TRUE;
            }
        }
                
        return FALSE;
	}

	// --------------------------------------------------------------------

    /**
     * Retourne le timestamp UNIX d'une date de publication
     *
     * @access public
     * @param string Date de publication sous la forme Y/m/d
     * @param integer Heure de publication
     * @param integer Minutes de publication
     * @return array
     */
    public static function get_time_from_pubdate($date, $hour = 0, $minute = 0)
    {
        list($year, $month, $day) = explode('/', $date);
        
        return mktime($hour, $minute, 0, $month, $day, $year);
    }   

}