<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Dir_helper
{

    /**
     * Lit le répertoire source et construit un tableau qui contient les chemins des sous répertoires présents.  
     * Chaque sous répertoire est lu également
     *
     * @access	public
     * @param	string	path to source
     * @param	bool	whether to include the sub directories
     * @param	bool	whether to include the relative path as part of the filename
     * @param	bool	internal variable to determine recursion status - do not use in calls
     * @return	array
     */
    public static function get_dirs_path_name($source_dir, $include_sub_dir = TRUE, $include_path = TRUE, $_recursion = FALSE)
    {
        static $_base_path = '';
        static $_dirnames = array();
    			
    	if ($fp = @opendir($source_dir))
    	{
            if ($_recursion === FALSE)
    		{
                // Initialize the static variable and make sure $source_dir has a trailing slash on the initial call
                $source_dir = rtrim($source_dir, '/').'/';
                $_dirnames = array();
                $_base_path = $source_dir;
    		}
            
            while (FALSE !== ($file = readdir($fp)))
    		{
    			if (@is_dir($source_dir.$file) && strncmp($file, '.', 1) !== 0)
    			{
                    if ($include_sub_dir === TRUE && $include_path === TRUE) {
                        $_dirnames[] = str_replace($_base_path, '', $source_dir.$file);
                    } else {
                        $_dirnames[] = $file;                    
                    }
                    
                    if ($include_sub_dir === TRUE)
                    {
                        self :: get_dirs_path_name($source_dir.$file.'/', $include_sub_dir, $include_path, TRUE);  
                    }
    			}
    		}
            
    		return $_dirnames;
    	}
    	else
    	{
    		return FALSE;
    	}
    }

    // ------------------------------------------------------------------------
    
    /**
     * Crée un répertoire avec un fichier index.php à l'intérieur
     *
     * @access	public
     * @param	string	path to directory
     * @return	array
     */
    public static function create_dir($dir_path)
    {
        if (!is_dir($dir_path) && mkdir($dir_path, 0755) && chmod($dir_path, 0755)) {	
            if (copy(CHEMIN.'data/index.php', $dir_path.'/index.php') && chmod($dir_path.'/index.php', 0644)) {
                return TRUE; 
    		}
		}
        
        return FALSE;
    }    

    // ------------------------------------------------------------------------

    /** 
      * Supprime un répertoire et tout son contenu
      * 
      * @param string $dir Chemin du répertoire à suprimer
      * @return boolean 
      */ 
    public static function delete_dir($dir) 
     { 
         if(!$dh = @opendir($dir)) 
         { 
             return FALSE; 
         } 
         while (FALSE !== ($obj = readdir($dh))) 
         { 
             if ($obj == '.' || $obj == '..') { 
                 continue; 
             } 
    
             if (!@unlink($dir.'/'.$obj)) 
             { 
                 self :: delete_dir($dir.'/'.$obj); 
             } 
         } 
    
         closedir($dh); 
         
         @rmdir($dir); // suppression du répertoire vidé
         
         return TRUE; 
     }

    // ------------------------------------------------------------------------

    public static function scan_dir($dir, $only_files = TRUE, $except_file = array('index.php'))
    { 
        $objects = array();
        
        if (is_dir($dir)) { 
            $objects = array_slice(scandir($dir), 2);
            
            foreach ($objects as $key => $object) { 
                if (($only_files && !is_file($dir.'/'.$object)) || in_array($object, $except_file)) { 
                    unset($objects[$key]);
                } 
            }
        }
        
        return $objects; 
    } 
 

    // ------------------------------------------------------------------------
/*
    public static function remove_dir($dir)
    { 
        if (is_dir($dir)) { 
            $objects = scandir($dir); 
            
            foreach ($objects as $object) { 
                if ($object != '.' && $object != '..') { 
                    if (filetype($dir.'/'.$object) == 'dir') {
                        self :: remove_dir($dir.'/'.$object);     
                    } else {
                        @unlink($dir.'/'.$object);    
                    } 
                } 
            }
            
            reset($objects);
             
            @rmdir($dir);
            
            return TRUE;
        }
        
        return FALSE; 
    } 
 */ 
               
    /**
     * Build an array containing the directory tree 
     *
     * Reads the specified directory and builds an array
     * representation of it.  Sub-folders contained with the
     * directory will be mapped as well.
     *
     * @access	public
     * @param	string	path to source
     * @param	bool	whether to limit the result to the top level only
     * @param	bool	whether to limit the result to directories only
     * @param	bool	internal variable to determine recursion status - do not use in calls
     * @return	array
     */	
    public static function tree2array($source_dir, $top_level_only = FALSE, $dir_only = FALSE, $_recursion = FALSE)
    {	
        static $_base_path = '';
        
        if ($fp = @opendir($source_dir))
    	{
            if ($_recursion === FALSE)
    		{
                // Initialize the static variable and make sure $source_dir has a trailing slash on the initial call
                $source_dir = rtrim($source_dir, '/').'/';
                $_base_path = $source_dir;
    		}

    		$filedata = array();
    		
    		while (FALSE !== ($file = readdir($fp)))
    		{
    			if (strncmp($file, '.', 1) == 0 OR ($file == '.' OR $file == '..'))
    			{
    				continue;
    			}
    			
                // modif
                if ($dir_only == TRUE && @is_file($source_dir.$file))
                {
                    continue;
                }
                // end modif
                
    			if ($top_level_only == FALSE && @is_dir($source_dir.$file))
    			{
    				$temp_array = array();
    			
    				$temp_array = self :: tree2array($source_dir.$file.'/', $top_level_only, $dir_only, TRUE);
    			
    				$filedata[$file] = array(
                        'name' => $file,
                        'path' => str_replace($_base_path, '', $source_dir.$file),
                        'children' => $temp_array,
                    );
    			}
                else
                {
                    $filedata[] = $file;
                }
    		}
    		
    		closedir($fp);
            
    		return $filedata;
    	}
    	else
    	{
    		return array();
    	}
    }


/*    public static function directory_map($source_dir, $top_level_only = FALSE, $dir_only = FALSE, $hidden = FALSE)
    {	
    	if ($fp = @opendir($source_dir))
    	{
            $source_dir = rtrim(realpath($source_dir), DIRECTORY_SEPARATOR).DIRECTORY_SEPARATOR;
    		$filedata = array();
    		
    		while (FALSE !== ($file = readdir($fp)))
    		{
    			if (($hidden == FALSE && strncmp($file, '.', 1) == 0) OR ($file == '.' OR $file == '..'))
    			{
    				continue;
    			}
    			
                // modif
                if ($dir_only == TRUE && @is_file($source_dir.$file))
                {
                    continue;
                }
                // end modif
                
    			if ($top_level_only == FALSE && @is_dir($source_dir.$file))
    			{
    				$temp_array = array();
    			
    				$temp_array = self :: directory_map($source_dir.$file.DIRECTORY_SEPARATOR, $top_level_only, $dir_only, $hidden);
    			
    				$filedata[$file] = $temp_array;
    			}
                else
                {
                    $filedata[] = $file;
                }
    		}
    		
    		closedir($fp);
    		return $filedata;
    	}
    	else
    	{
    		return array();
    	}
    }
*/


/*
public static function dir_tree($dir, $dir_only = TRUE)
{
    $path = '';
    $stack[] = $dir;
    while ($stack) {
        $thisdir = array_pop($stack);
        if ($dircont = scandir($thisdir)) {
            $i=0;
            while (isset($dircont[$i])) {
                if ($dircont[$i] !== '.' && $dircont[$i] !== '..') {
                    $current_file = $thisdir.'/'.$dircont[$i];
                    if ($dir_only === FALSE && is_file($current_file)) {
                        $path[] = str_replace(CHEMIN, '', $current_file);
                    } elseif (is_dir($current_file)) {
                        $path[] = str_replace(CHEMIN, '', $current_file);
                        $stack[] = $current_file;
                    }
                }
                $i++;
            }
        }
    }
    
    sort($path);
    
    return $path;
 }
*/










 /*   
    public static function get_list_dirs($source_dir, $directory_depth = 0, $hidden = FALSE, $connector = '||')
    {
        $list_dirs = self :: _list_dirs_in_string($source_dir, $directory_depth, $hidden, $connector);
        
        $dirs =  explode($connector, trim($list_dirs, $connector));
        
        return $dirs;
    }
*/
    /**
     * Create a Directory Map in a string with connector separation between directories
     *
     * @access	public
     * @param	string	path to source
     * @param	int		depth of directories to traverse (0 = fully recursive, 1 = current dir, etc)
     * @param   bool    include hiiden or not
     * @param   string  connector between directories
     * @return	string
     */
/*    private static function _list_dirs_in_string($source_dir, $directory_depth = 0, $hidden = FALSE, $connector = '||')
    {
    	if ($fp = @opendir($source_dir))
    	{
    		$filedata	= '';
            $filedata .= $connector.str_replace('../', '',$source_dir);            
    		$new_depth	= $directory_depth - 1;
    		$source_dir	= rtrim($source_dir, '/').'/';
    
    		while (FALSE !== ($file = readdir($fp)))
    		{
    			// Remove '.', '..', and hidden files [optional]
    			if ( ! trim($file, '.') OR ($hidden == FALSE && $file[0] == '.'))
    			{
    				continue;
    			}
    
    			if (($directory_depth < 1 OR $new_depth > 0) && @is_dir($source_dir.$file))
    			{    	            
                    $filedata .= self :: _list_dirs_in_string($source_dir.$file, $new_depth, $hidden, $connector);
    			}
    		}
    
    		closedir($fp);
            
    		return $filedata;
    	}
    
    	return FALSE;
    }   
*/
}