<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/html_helper.php';

class Form_helper extends Html_helper
{
	/**
	 * Ajoute un block contenant un bouton de type Submit
     * 
	 * @access public
	 * @param $legend string Intitulé du bouton
	 * @return code html du block
	 */
	public static function add_block_button_submit($legend, $attr = array())
	{	
		$attr = (isset($attr) && is_array($attr))? $attr : array();
		
		$view  = parent :: openP($attr);
		$view .= parent :: addButton($legend, $attr = array('title' => $legend));
		$view .= parent :: closeP();
			
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * affiche un champ de texte <input /> pour chacune des deux langues
     * 
     * @access protected
	 * @param string $label Libellé du champ
	 * @param array $name Nom du champ
	 * @param array $value Valeur du champ
	 * @param array $attr Largeur du champ
	 * @param array $addons Ajout après le champ
	 * @return string Code Html du champ
	 */	
	public static function add_block_input_bilang($label, $name, $value, $attr = array(), $addons = array())
	{
		global $lang;
		
		$html = '';
		$text = $label;
		settype($name, 'array');
		settype($value, 'array');
		settype($attr, 'array');
		settype($addons, 'array');

		for ($i = 0; $i < 2; $i ++) {
			if (!empty($lang[$i])) {
				// Ajout du drapeau au label
				$attr['img']['title'] = $lang[$i];
				$label = parent :: addImg($path = CHEMIN.INCREP.'lang/'.$lang[$i].'.gif', $alt = $lang[$i], $attr['img']).'&nbsp;'.$text;
				
				$html .= self :: add_block_input($label, $name[$i], $value[$i], $attr['input'], $addons[$i]);
			}
		}
		
		return $html;	
	}

	// --------------------------------------------------------------------

	/**
	 * affiche un champ de texte <input />
     * 
     * @access protected
	 * @param $label string Libellé du champ
	 * @param $name string Nom du champ
	 * @param $value string Valeur du champ
	 * @param $width string Largeur du champ
	 * @param $addon string Ajout après le champ
	 * @param $readonly boolean Champ en lecture seule ou non
	 * @return string Code Html du champ
	 */
	public static function add_block_input($label, $type, $name, $value = '', $attr = array(), $addons = '')
	{
		global $charset;
		
		$pAttr = (isset($attr['p']) && is_array($attr['p']))? $attr['p'] : array(); // Attributs P
		$labelAttr = (isset($attr['label']) && is_array($attr['label']))? $attr['label'] : array(); // Attributs Label
		$inputAttr = (isset($attr['input']) && is_array($attr['input']))? $attr['input'] : array(); // Attributs Input
	
	//	$id = preg_replace("`[^a-z0-9_]+`i", '_', $name);
		$id = str_replace(array('[', ']'), array('_', ''), $name);

		$labelAttr['for'] = $id;
		$labelAttr['title'] = strip_tags($label);
		$inputAttr['id'] = $id;

		parent :: $charset = $charset;
		
		$html = parent :: openP($pAttr);
		$html .= parent :: addLabel($label.'&nbsp;:&nbsp;', $labelAttr);
		$html .= parent :: addInput(
			$type,
			$name,
			$value,
			$inputAttr
		);
		$html .= parent :: addAnything($addons);	
		$html .= parent :: closeP();
	
		return $html;
	}

	// --------------------------------------------------------------------

	/**
	 * affiche un block avec un menu de sélections <select>
     * 
	 * @param $label string Libellé du menu
	 * @param $name string Nom du menu
	 * @param $options array Tableau contenant les options du menu
	 * @param $optionsValueSelect array Option sélectionnée du menu
	 * @return string Code Html du menu
	 */	
	public static function add_block_menu_select($label, $name, $options, $optionsValueSelect = array(), $attr = array())
	{
	//	$id = preg_replace("`[^a-z0-9_]+`", '_', $name);
		$id = str_replace(array('[', ']'), array('_', ''), $name);
        $select_attrs = empty($attr['multiple'])? array('id' => $id) : array('id' => $id, 'multiple' => 'multiple', 'size' => 4);


		$html = parent :: openP($attr);
		$html .= parent :: addLabel($label.'&nbsp;:&nbsp;', $attr = array('for' => $id, 'title' => $label));
        $html .= self :: add_menu_select($name, $options, $optionsValueSelect, $select_attrs);
		$html .= parent :: closeP();
	
		return $html;	
	}

	/**
	 * affiche un menu de sélections <select>
     * 
	 * @param $name string Nom du menu
	 * @param $options array Tableau contenant les options du menu
	 * @param $optionsValueSelect array Option sélectionnée du menu
	 * @return string Code Html du menu
	 */
	public static function add_menu_select($name, $options, $optionsValueSelect = array(), $attr = array())
	{
		global $charset;

        parent :: $charset = $charset;
	
        settype($optionsValueSelect, 'array');
	//	$id = preg_replace("`[^a-z0-9_]+`", '_', $name);
		$id = str_replace(array('[', ']'), array('_', ''), $name);        
        $select_attrs = array_merge(array('id' => $id), $attr);
		
		$html = parent :: openSelect($name, $select_attrs);
		foreach($options as $optionsName => $optionsValue) {
            $optionsName = strip_tags(str_replace('<!--', '', str_replace('-->', ' ', $optionsName)));
			
			$html .= parent :: addOption(
				$legend = stripslashes($optionsName),
				$value = $optionsValue,
				$attr = array(
//					'selected' => ($optionsValueSelect == stripslashes($optionsValue)) ? 'selected' : ''
					'selected' => in_array($optionsValue, $optionsValueSelect) ? 'selected' : ''
				)
			);
		}		
		$html .= parent :: closeSelect();
	
		return $html;	
	}
    
	// --------------------------------------------------------------------

	/**
	 * addBlockTextareaBilang
	 * affiche un champ de texte <input /> pour chacune des deux langues
	 * @param string $label Libellé du champ
	 * @param array $name Nom du champ
	 * @param array $value Valeur du champ
	 * @param array $attr Largeur du champ
	 * @param array $addons Ajout après le champ
	 * @return string Code Html du champ
	 */	
	public static function add_block_textarea_bilang($label, $name, $contents, $attr = array(), $addons = array())
	{
		global $lang;
		
		$html = '';
		$text = $label;
		settype($name, 'array');
		settype($contents, 'array');
		settype($attr, 'array');
		settype($addons, 'array');

		for ($i = 0; $i < 2; $i ++) {
			if (!empty($lang[$i])) {
				// Ajout du drapeau au label
				$attr['img']['title'] = $lang[$i];
				$label = parent :: addImg($path = CHEMIN.INCREP.'lang/'.$lang[$i].'.gif', $alt = $lang[$i], $attr['img']).'&nbsp;'.$text;
				
				$html .= self :: add_block_textarea($label, $name[$i], $contents[$i], $attr['textarea'][$i], $addons[$i]);
			}
		}
		
		return $html;
	}

	// --------------------------------------------------------------------

	/**
	 * affiche un block contenant un champ de texte multiligne <textarea>
     * 
	 * @param $label string Libellé du champ
	 * @param $name string Nom du champ
	 * @param $contents string Contenu du champ
	 * @param $attr array Attributs
	 * @param $addon string Ajout après le champ
	 * @return string Code Html du champ
	 */
	public static function add_block_textarea($label, $name, $contents = '', $attr = array(), $addons = '')
	{
		global $charset;
		
		$pAttr = (isset($attr['p']) && is_array($attr['p']))? $attr['p'] : array(); // Attributs P
		$labelAttr = (isset($attr['label']) && is_array($attr['label']))? $attr['label'] : array(); // Attributs Label
		$textareaAttr = (isset($attr['textarea']) && is_array($attr['textarea']))? $attr['textarea'] : array(); // Attributs Textarea
	
		//$id = preg_replace("`[^a-z0-9_]+`i", '_', $name);
//		$id = str_replace(array('[', ']'), array('_', ''), $name);
        $id = $name;

		$labelAttr['for'] = $id;
		$labelAttr['title'] = strip_tags($label);
		$textareaAttr['id'] = $id;

		parent :: $charset = $charset;
		
		$html = parent :: openDiv($pAttr);
		$html .= parent :: addLabel($label.'&nbsp;:&nbsp;', $labelAttr);
//		$html .= parent :: addBr();
		$html .= parent :: addTextarea(
			$name,
			$contents,
			$textareaAttr
		);
		$html .= parent :: addAnything($addons);	
		$html .= parent :: closeDiv();
	
		return $html;
	}

	// --------------------------------------------------------------------

	/**
	 * affiche un paragraphe contenant des boutons radios <input type="radio" />
     * 
	 * @param $legend string Libellé du paragraphe
	 * @param $name string Nom des boutons
	 * @param $radios array Tableau contenant les libellés et les valeurs associées des boutons
	 * @param $valueChecked string valeur du bouton sélectionné
	 * @param array $attr Attributs du block <p> sous la forme d'un tableau associatif array(key => value)
	 * @return string Code Html du menu
	 */	
	public static function add_block_input_radios($legend, $name, $radios = array('label' => 'value'), $valueChecked = '', $attr = array(), $addons = '')
	{
		settype($radios, 'array');
		$html = '';
		
		$html .= parent :: openP($attr)."\n";
		$html .= !empty($legend) ? '<span title="'.$legend.'">'.$legend.'&nbsp;:&nbsp;</span>' : '';
		$html .= self :: add_input_radios($name, $radios, $valueChecked)."\n";
		$html .= !empty($addons)? parent :: addAnything($addons)."\n" : '';
		$html .= parent :: closeP()."\n";	
		
		return $html;
	}

	// --------------------------------------------------------------------

	/**
	 * affiche des boutons radios <input type="radio" />
     * 
	 * @param $name string Nom des boutons
	 * @param $radios array Tableau contenant les libellés et les valeurs associées des boutons
	 * @param $valueChecked string valeur du bouton sélectionné
	 * @return string Code Html du menu
	 */	
	public static function add_input_radios($name, $radios = array('label' => 'value'), $valueChecked = '')
	{
		settype($radios, 'array');
		$html = '';
		$i = 0;
        
		$id = str_replace(array('[', ']'), array('_', ''), $name);
		
		foreach ($radios as $label => $value) {
			$html .= parent :: addInput(
				$type = 'radio',
				$name,
				$value,
				$attr = array(
					'id' => $id.'_'.$value,
					'checked' => ($value == $valueChecked)? 'checked' : ''
				)
			)."\n";
			$html .= parent :: addLabel($label, $attr = array('for' => $id.'_'.$value, 'title' => $label))."\n";
			$i ++;
					
			if ($i < count($radios)) {
				$html .= parent :: addAnything($contents = '<span>&nbsp;&nbsp;</span>')."\n";
			}	
		}
		
		return $html;
	}

	// --------------------------------------------------------------------

	/**
	 * affiche un paragraphe contenant des boutons radios <input type="radio" />
     * 
	 * @param $legend string Libellé du paragraphe
	 * @param $name string Nom des boutons
	 * @param $radios array Tableau contenant les libellés et les valeurs associées des boutons
	 * @param $valueChecked string valeur du bouton sélectionné
	 * @param array $attr Attributs du block <p> sous la forme d'un tableau associatif array(key => value)
	 * @return string Code Html du menu
	 */	
	public static function add_block_input_checkbox($legend, $name, $valueChecked = '', $attr = array())
	{
		$html = '';
		$legend_pos = empty($attr['legend_pos']) ? 'after' : 'before';
        
		$html .= parent :: openP($attr)."\n";
		if ($legend_pos == 'before') {
            $html .= parent :: addLabel($legend, array('for' => $name, 'title' => $legend))."\n";
		}
        $html .= Html_helper :: addInput(
			$type = 'checkbox',
			$name,
			$value = 'on',
			$attr = array(
				'id' => $name,
				'checked' => !empty($valueChecked) ? 'checked' : ''
			)
		)."\n";
		if ($legend_pos == 'after') {
            $html .= parent :: addLabel($legend, array('for' => $name, 'title' => $legend))."\n";
		}
		$html .= parent :: closeP()."\n";	
		
		return $html;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute un message d'erreur
     * 
	 * @param string $error Message d'erreur
	 * @return string
	 * @access public
	 */
	public static function add_msg_error($error)
	{	
		return parent :: addBr().$error.parent :: addBr();	
	}

	// --------------------------------------------------------------------

}