<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');
 
class Html_helper
{
	/****************************************************************************************************************************
	 * PROPRIETE
	 */
	 
	/*******************************************************
	 * Attributs optionels communs à toutes les balises HTML
	 * basés sur le doctype DTD XHTML 1.0 Transitional
	 */	 
	private static $commonAttr = array(
		'id' => '',
		'class' => '',
		'title' => '',
		'style' => '',
		'onclick' => '',
		'ondblclick' => '',
		'onmousedown' => '',
		'onmouseup' => '',
		'onmouseover' => '',
		'onmouseout' => '',
		'onmousemove' => '',
		'onkeypress' => '',
		'onkeydown' => '',
		'onkeyup' => '',		
	);

	/*******************************************************
	 * Blocks
	 */	 	
	private static $hAttr = array('align' => '');	// Entêtes <h1> -> <h6>
	private static $pAttr = array('align' => '');
	private static $divAttr = array('align' => '');
	
	/*******************************************************
	 * Listes
	 */	 		
	private static $ulAttr = array(
		'type' => '' // (disc|square|circle)
	);

	private static $olAttr = array(
		'type' => '', // (1|a|A|i|I)
		'start' => ''	// Nombre (numéro du premir item)
	);
	
	private static $liAttr = array(
		'type' => '',
		'value' => ''
	);
	
	private static $dlAttr = array();	// Liste de définitions
	private static $dtAttr = array();	// Titre de définitions
	private static $ddAttr = array();	// Description de définitions
	
	/*******************************************************
	 * Liens
	 */	
	private static $aAttr = array(	// Lien ou ancre
		'name' => '',
		'target' => '',
		'onfocus' => '',
		'onblur' => ''
	);
	
	/*******************************************************
	 * Images
	 */	
	private static $imgAttr = array(	// Les attributs height et width sont pris en charge
		'longdesc' => '',	// par la fonction getimagesize()
		'align' => '',
		'border' => '',
		'hspace' => '',
		'vspace' => '',
		'usemap' => '',
		'ismap' => ''
	);

	/*******************************************************
	 * Section Body
	 */
	private static $brAttr = array(
		'clear' => ''	// (left|all|right)
	);

	private static $hrAttr = array(
		'align' => '',
		'size' => '',
		'width' => ''
	);

	/*******************************************************
	 * Section Head
	 */
	private static $titleAttr = array(); // Title

	private static $metaAttr = array(	// Meta
		'content' => '',	// Attribut obligatoire
		'name' => '',
		'http-equiv' => ''
	);
	
	private static $scriptAttr = array(	// Script
		'type' => 'text/javascript',
		'src' => '',
		'defer' => ''
	);

	private static $noscriptAttr = array(); // Noscript

	private static $linkAttr = array(	// Link
		'type' => 'text/css',
		'media' => 'screen', // (all|print|screen(par defaut))
		'rel' => 'stylesheet',
		'rev' => '',
		'target' => '',
		'$charset' => ''			
	);
	
	private static $styleAttr = array(	// Style
		'type' => 'text/css',
		'media' => ''	// (all(par defaut)|print|screen)
	);

	/*******************************************************
	 * Formulaire
	 */
	private static $formAttr = array(
		'method' => 'post',
		'enctype' => '',
		'accept' => '',
		'accept-$charset' => '',
		'onsubmit' => '',
		'onreset' => ''
	);

	private static $fieldsetAttr = array();
	
	private static $legendAttr = array(
		'accesskey' => '',
		'align' => ''
	);
	
	private static $labelAttr = array(
		'for' => '',
		'accesskey' => '',
		'onfocus' => '',
		'onblur' => ''
	);

	private static $inputAttr = array(
		'button' => array(
			'tabindex' => '',
			'accesskey' => '',
			'disabled' => '',
			'onfocus' => '',
			'onblur' => ''
		),
		
		'checkbox' => array(
			'tabindex' => '',
			'accesskey' => '',
			'disabled' => '',
			'checked' => ''
		),

		'file' => array(
			'tabindex' => '',
			'accesskey' => '',
			'disabled' => '',
			'accept' => '',
			'size ' => '',
			'maxlength' => '',
			'onselect' => '',
			'onchange' => '',
			'onfocus' => '',
			'onblur' => ''
		),

		'hidden' => array(),
		
		'image' => array(
			'alt' => '',
			'align' => '',
			'tabindex' => '',
			'accesskey' => '',
			'disabled' => '',
			'usemap' => ''
		),

		'password' => array(
			'tabindex' => '',
			'accesskey' => '',
			'disabled' => '',
			'readonly' => '',
			'maxlength' => '',
			'size ' => '',
			'onselect' => '',
			'onchange' => '',
			'onfocus' => '',
			'onblur' => ''
		),
		
		'radio' => array(
			'tabindex' => '',
			'accesskey' => '',
			'disabled' => '',
			'checked' => '',
		),

		'reset' => array(
			'tabindex' => '',
			'accesskey' => '',
			'disabled' => '',
		),

		'submit' => array(
			'tabindex' => '',
			'accesskey' => '',
			'disabled' => ''
		),

		'text' => array(
			'tabindex' => '',
			'accesskey' => '',
			'disabled' => '',			
			'readonly' => '',
			'maxlength' => '',
			'size' => '',
			'onselect' => '',
			'onchange' => '',
			'onfocus' => '',
			'onblur' => ''
		)
	);
	
	private static $textareaAttr = array(
		'tabindex' => '',
		'accesskey' => '',
		'disabled' => '',			
		'readonly' => '',
		'rows' => 15,	// Ne pas mettre à vide
		'cols' => 30,	// Ne pas mettre à vide
		'onselect' => '',
		'onchange' => '',
		'onfocus' => '',
		'onblur' => ''
	);
	
	private static $selectAttr = array(
		'tabindex' => '',
		'disabled' => '',			
		'multiple' => '',
		'size' => '',
		'onchange' => '',
		'onfocus' => '',
		'onblur' => ''
	);

	private static $optgroupAttr = array('disabled' => ''); // Attribut label obligatoire 
	
	private static $optionAttr = array(
		'disabled' => '',
		'label' => '',
		'selected' => ''
	);

	private static $buttonAttr = array(
		'name' => '',
		'value' => '',
		'tabindex' => '',
		'accesskey' => '',
		'disabled' => '',
		'type' => 'submit',
		'onfocus' => '',
		'onblur' => ''			
	);
	
	/*******************************************************
	 * Tableau
	 */
	private static $tableAttr = array(
		'summary' => '',
		'cellspacing' => '',
		'cellpadding' => '',
		'width' => '',
		'border' => '',
		'align' => '',
		'bgcolor' => '',
		'frame' => '',
		'rules' => ''
	);

	private static $captionAttr = array(
		'align' => ''	
	);

	private static $colgroupAttr = array(	// groups a set of col elements
		'span' => '',	// Number
		'width' => '',	// Width in pixels (number) or relative width (number*)
		'valign' => '',	// Vertical alignment (top|middle|bottom|baseline)
		'align' => '',	// Horizontal alignment (left|center|right|justify|char)
		'char' => '',	// Horizontal alignment char, e.g. char=':'
		'charoff' => ''	// Offset for horizontal alignment char
	);
	
	private static $colAttr = array(	// define the alignment properties for cells in one or more columns.
		'span' => '',	// Number
		'width' => '',	// Width in pixels (number) or relative width (number*)
		'valign' => '',	// Vertical alignment (top|middle|bottom|baseline)
		'align' => '',	// Horizontal alignment (left|center|right|justify|char)
		'char' => '',	// Horizontal alignment char, e.g. char=':'
		'charoff' => ''	// Offset for horizontal alignment char
	);

	private static $theadAttr = array(
		'valign' => '',	// Vertical alignment (top|middle|bottom|baseline)
		'align' => '',	// Horizontal alignment (left|center|right|justify|char)
		'char' => '',	// Horizontal alignment char, e.g. char=':'
		'charoff' => ''	// Offset for horizontal alignment char
	);

    private static $tfootAttr = array(
		'valign' => '',	// Vertical alignment (top|middle|bottom|baseline)
		'align' => '',	// Horizontal alignment (left|center|right|justify|char)
		'char' => '',	// Horizontal alignment char, e.g. char=':'
		'charoff' => ''	// Offset for horizontal alignment char
	);

	private static $tbodyAttr = array(
		'valign' => '',	// Vertical alignment (top|middle|bottom|baseline)
		'align' => '',	// Horizontal alignment (left|center|right|justify|char)
		'char' => '',	// Horizontal alignment char, e.g. char=':'
		'charoff' => ''	// Offset for horizontal alignment char
	);
	
	private static $trAttr = array(
		'bgcolor' => '',
		'valign' => '',	// Vertical alignment (top|middle|bottom|baseline)
		'align' => '',	// Horizontal alignment (left|center|right|justify|char)
		'char' => '',	// Horizontal alignment char, e.g. char=':'
		'charoff' => ''	// Offset for horizontal alignment char
	);

	private static $thAttr = array(
		'abbr' => '',
		'axis' => '',
		'headers' => '',
		'scope' => '',
		'rowspan' => '',
		'colspan' => '',
		'nowrap' => '',
		'bgcolor' => '',
		'width' => '',
		'height' => '',
		'valign' => '',	// Vertical alignment (top|middle|bottom|baseline)
		'align' => '',	// Horizontal alignment (left|center|right|justify|char)
		'char' => '',	// Horizontal alignment char, e.g. char=':'
		'charoff' => ''	// Offset for horizontal alignment char
	);

	private static $tdAttr = array(
		'abbr' => '',
		'axis' => '',
		'headers' => '',
		'scope' => '',
		'rowspan' => '',
		'colspan' => '',
		'nowrap' => '',
		'bgcolor' => '',
		'width' => '',
		'height' => '',
		'valign' => '',	// Vertical alignment (top|middle|bottom|baseline)
		'align' => '',	// Horizontal alignment (left|center|right|justify|char)
		'char' => '',	// Horizontal alignment char, e.g. char=':'
		'charoff' => ''	// Offset for horizontal alignment char
	);
	
	private static $imgExtAllowed = array('.gif', '.png', '.jpg', '.jpeg', '.ico'); // Extension des images autorisées	
	
	protected static $charset = 'UTF-8';	//Jeux de caractères

	/****************************************************************************************************************************
	 * METHODES
	 */
	
	/**
     * open a tag
     * 
	 * @access private
	 * @param string $tag tag name
	 * @param string $attr tag attributs
	 * @return string Code html of opened tag

	 */
	private static function _openTag($tag, $attr = '')
	{
		return !empty($tag)? '<'.$tag.$attr.'>' : '';
	}

	/**
     * close a tag
     * 
	 * @access private
	 * @param string $tag tag name
	 * @return string Code html of closed tag
	 */
	private static function _closeTag($tag)
	{
		return !empty($tag)? '</'.$tag.'>' : '';
	}

	/**
	 * _addTag
	 * @param string $tag tag name
	 * @param mixed $contents tag contents
	 * @param string $attr tag attributs
	 * @return string Code html of tag
	 * @access private
	 */		
	private static function _addTag($tag, $contents, $attr = '')
	{
		$html = self :: _openTag($tag, $attr);
		if (is_array($contents)) {
			foreach($contents as $val) {
				$html .= $val;
			}
		} else {
			$html .= $contents;
		}
		$html .= self :: _closeTag($tag);

		return $html;
	}

	/**
	 * _addShortTag
	 * @param string $tag tag name
	 * @param string $attr tag attributs
	 * @return string Code html of short cut tag
	 * @access private
	 */
	private static function _addShortTag($tag, $attr = '')
	{
		return !empty($tag)? '<'.$tag.$attr.' />' : '';
	}
	
	/**
	 * _getAttributes
	 * renvoie les attributs déclarés d'une balise
	 * @param array $defaultAttr Attributs définis par défaut déclarés sous la forme array('attribut' => 'value')
	 * @param array $attr Attributs définis et déclarés sous la forme array('attribut' => 'value') 
	 * @return string Code HTML des attributs de la balise
	 * @access private
	 */
	private static function _getAttributes($defaultAttr, $attr = array())
	{	
		settype($defaultAttr, 'array');
		settype($attr, 'array');
		$attributes = '';
		
		foreach ($defaultAttr as $name => $value) {
			if (array_key_exists($name, $attr)) {
				if ($attr[$name] != '') {
					$attributes .= ' '.$name.'="'.$attr[$name].'"';					    
				}
            } elseif ($value != '') {
				$attributes .= ' '.$name.'="'.$defaultAttr[$name].'"';
			}
		}

		// Data-* attribute
        foreach ($attr as $name => $value) {
            if (preg_match("`^data-[a-z0-9_]+`i", $name)) {
				$attributes .= ' '.$name.'="'.$value.'"';
            }
		}
					
		return $attributes; 
	}

	/*******************************************************
	 * Blocks
	 */

	/**
	 * addH
	 * affiche le code HTML d'une entête <h1>,<h2>,...<h6>
	 * @param number $levels Niveau de l'entête
	 * @param mixed $contents Contenu à afficher
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $hAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du block <div>
	 * @access public
	 */	
	public static function _addH($levels, $contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $hAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('h'.$levels, $contents, $attributes);
	}

	public static function addH1($contents, $attr = array())
	{
		return self :: _addH(1, $contents, $attr);
	}
	
	public static function addH2($contents, $attr = array())
	{
		return self :: _addH(2, $contents, $attr);
	}
	
	public static function addH3($contents, $attr = array())
	{
		return self :: _addH(3, $contents, $attr);
	}

	public static function addH4($contents, $attr = array())
	{
		return self :: _addH(4, $contents, $attr);
	}

	public static function addH5($contents, $attr = array())
	{
		return self :: _addH(5, $contents, $attr);
	}

	public static function addH6($contents, $attr = array())
	{
		return self :: _addH(6, $contents, $attr);
	}
	  	
	/**
	 * openDiv
	 * ouvre un block <div>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $divAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la balise d'ouverture du block <div>
	 * @access public
	 */	
	public static function openDiv($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $divAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('div', $attributes);
	}
	
	/**
	 * closeDiv
	 * ferme un block <div>
	 * @return string Code HTML de la balise de fermeture du block <div>
	 * @access public
	 */	
	public static function closeDiv()
	{
		return self :: _closeTag('div');
	}

	/**
	 * addDiv
	 * affiche le code HTML d'un block <div>
	 * @param mixed $contents Contenu du block
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $divAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du block <div>
	 * @access public
	 */	
	public static function addDiv($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $divAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('div', $contents, $attributes);
	}

	/**
	 * openP
	 * ouvre un block <p>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $divAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la balise d'ouverture du block <p>
	 * @access public
	 */	
	public static function openP($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $pAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('p', $attributes);
	}

	/**
	 * closeP
	 * ferme un block <p>
	 * @return string Code HTML de la balise de fermeture du block <p>
	 * @access public
	 */	
	public static function closeP()
	{
		return self :: _closeTag('p');
	}
	
	/**
	 * addP
	 * affiche le code HTML d'un block <p>
	 * @param mixed $contents Contenu du block
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $pAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du block <p>
	 * @access public
	 */	
	public static function addP($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $pAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('p', $contents, $attributes);
	}

	/*******************************************************
	 * Listes
	 */	 		

	/**
	 * openUl
	 * ouvre un block de liste non ordonnée <ul>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $ulAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la balise d'ouverture du block <ul>
	 * @access public
	 */	
	public static function openUl($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $ulAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('ul', $attributes);
	}

	/**
	 * closeUl
	 * ferme un block de liste non ordonnée <ul>
	 * @return string Code HTML de la balise de fermeture du block <ul>
	 * @access public
	 */	
	public static function closeUl()
	{
		return self :: _closeTag('ul');
	}

	/**
	 * openOl
	 * ouvre un block de liste ordonnée <ol>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $olAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la balise d'ouverture du block <ol>
	 * @access public
	 */	
	public static function openOl($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $olAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('ol', $attributes);
	}

	/**
	 * closeOl
	 * ferme un block de liste ordonnée <ol>
	 * @return string Code HTML de la balise de fermeture du block <ol>
	 * @access public
	 */	
	public static function closeOl()
	{
		return self :: _closeTag('ol');
	}

	/**
	 * openLi
	 * ouvre un élément de liste <li>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $liAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la balise d'ouverture de l'élément de liste <li>
	 * @access public
	 */	
	public static function openLi($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $liAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('li', $attributes);
	}

	/**
	 * closeLi
	 * ferme un élément de liste <li>
	 * @return string Code HTML de la balise de fermeture de l'élément de liste <li>
	 * @access public
	 */	
	public static function closeLi()
	{
		return self :: _closeTag('li');
	}

	/**
	 * addLi
	 * affiche le code HTML d'un élément de liste <li>
	 * @param mixed $contents Contenu de l'élément de liste
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $liAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du block <li>
	 * @access public
	 */	
	public static function addLi($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $liAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('li', $contents, $attributes);
	}

	/**
	 * openDl
	 * ouvre un block de liste de définitions <dl>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $dlAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la balise d'ouverture du block <dl>
	 * @access public
	 */	
	public static function openDl($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $dlAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('dl', $attributes);
	}

	/**
	 * closeDl
	 * ferme un block de liste de définitions <dl>
	 * @return string Code HTML de la balise de fermeture du block <dl>
	 * @access public
	 */	
	public static function closeDl()
	{
		return self :: _closeTag('dl');
	}

	/**
	 * addDt
	 * affiche le code HTML d'un élément de titre de définition <dt>
	 * @param mixed $contents Contenu de l'élément de liste
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $dtAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du block <dt>
	 * @access public
	 */	
	public static function addDt($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $dtAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('dt', $contents, $attributes);
	}

	/**
	 * addDd
	 * affiche le code HTML d'un élément de description de définition <dd>
	 * @param mixed $contents Contenu de l'élément de liste
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $ddAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du block <dd>
	 * @access public
	 */	
	public static function addDd($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $ddAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('dd', $contents, $attributes);
	}

	/*******************************************************
	 * Formulaire
	 */

	/**
	 * openForm
	 * ouvre un formulaire <form>
	 * @param string $action attribut action
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $formAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la balise d'ouverture du formulaire <form>
	 * @access public
	 */	
	public static function openForm($action, $attr = array())
	{
		// Attribut obligatoire
		$attributes = ' action="'.$action.'"';
		// Attributs facultatifs
		$optAttr = array_merge(self :: $commonAttr, self :: $formAttr);		
		$attributes .= self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('form', $attributes);
	}

	/**
	 * closeForm
	 * ferme un formulaire <form>
	 * @return string Code HTML de la balise de fermeture du formulaire <form>
	 * @access public
	 */	
	public static function closeForm()
	{
		return self :: _closeTag('form');
	}

	/**
	 * openFieldset
	 * ouvre un regroupement de champ <fieldset>
	 * @param string $legend légende du regroupement de champ
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr, $fieldsetAttr et $legendAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la balise du regroupement de champ <fieldset>
	 * @access public
	 */	
	public static function openFieldset($legend, $attr = array('fieldset' => array(), 'legend' => array()))
	{
		// Tag fieldset
		if (is_array($attr) && !isset($attr['fieldset'])) {
			$attr['fieldset'] = $attr;
		} elseif (!isset($attr['fieldset']) || !is_array($attr['fieldset'])) {
			$attr['fieldset'] = array();
		}
		
		$optAttr = array_merge(self :: $commonAttr, self :: $fieldsetAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr['fieldset']);
		$html = self :: _openTag('fieldset', $attributes);
		
		// Tag legend
		if (!isset($attr['legend']) || !is_array($attr['legend'])) {
			$attr['legend'] = array();
		}
		$html .= self :: addLegend($legend, $attr['legend']);
		
		return $html;
	}

	/**
	 * closeFieldset
	 * ferme regroupement de champ <fieldset>
	 * @return string Code HTML de la balise du regroupement de champ <fieldset>
	 * @access public
	 */	
	public static function closeFieldset()
	{
		return self :: _closeTag('fieldset');
	}

	/**
	 * addLegend
	 * affiche le code HTML d'une légende d'un regroupement de champ <legend>
	 * @param mixed $contents contenu de la légende
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $legendAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la légende d'un regroupement de champ <legend>
	 * @access public
	 */	
	public static function addLegend($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $legendAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('legend', $contents, $attributes);
	}
	
	/**
	 * addLabel
	 * affiche le code HTML d'une étiquette <label>
	 * @param mixed $contents Contenu du block
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $labelAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de l'étiquette <label>
	 * @access public
	 */	
	public static function addLabel($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $labelAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('label', $contents, $attributes);
	}
	
	/**
	 * addInput
	 * ajoute un champ <input />
	 * @param string $type attribut type
	 * @param string $name attribut name
	 * @param string $value attribut value (ou src pour le type image)
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $inputAttr[type] pour connaitre la liste des attributs disponibles)
	 * @return Code HTML du champ <input>
	 * @access private
	 */	
	public static function addInput($type, $name, $value, $attr = array())
	{
		// Attributs obligatoires
		switch ($type) {
			case 'hidden' :
			case 'text' :
			case 'checkbox' :
			case 'radio' :
			case 'password' :
			case 'submit' :
			case 'reset' :
			case 'button' :
			case 'file' :		
				$attributes = ' value="'.htmlspecialchars($value, ENT_COMPAT, self :: $charset).'"';
				break;
			case 'image' :
				$attributes = ' src="'.htmlspecialchars($value, ENT_COMPAT, self :: $charset).'"';
				break;
			default :
				die('Error : illegal value in $type');
		}
		$attributes .= ' type="'.$type.'"';
		$attributes .= ' name="'.$name.'"';
		
		// Attributs facultatifs
		$optAttr = array_merge(self :: $commonAttr, self :: $inputAttr[$type]);		
		$attributes .= self :: _getAttributes($optAttr, $attr);

		//print_r($attributes);
			
		return self :: _addShortTag('input', $attributes);
	}	

	/**
	 * addTextarea
	 * affiche le code HTML d'un champ de texte multiligne <textarea>
	 * @param string $contents Contenu du champ
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $textareaAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du champ de texte multiligne <textarea>
	 * @access public
	 */	
	public static function addTextarea($name, $contents = '', $attr = array())
	{
		$attributes = ' name="'.$name.'"';
		$contents = htmlspecialchars($contents, ENT_COMPAT, self :: $charset);
		
		$optAttr = array_merge(self :: $commonAttr, self :: $textareaAttr);		
		$attributes .= self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('textarea', $contents, $attributes);
	}

	/**
	 * openSelect
	 * ouvre un sélecteur d'options <select>
	 * @param string $name attribut name
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $selectAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du sélecteur d'options <select>
	 * @access public
	 */	
	public static function openSelect($name, $attr = array())
	{
		$attributes = ' name="'.$name.'"';
				
		// Attributs select
		$optAttr = array_merge(self :: $commonAttr, self :: $selectAttr);		
		$attributes .= self :: _getAttributes($optAttr, $attr);		

		$html = self :: _openTag('select', $attributes);		
		
		return $html;
	}

	/**
	 * closeSelect
	 * ferme un sélecteur d'options <select>
	 * @return string Code HTML du sélecteur d'options <select>
	 * @access public
	 */	
	public static function closeSelect()
	{
		return self :: _closeTag('select');
	}

	/**
	 * addSelect
	 * affiche le code HTML d'un sélecteur d'options <select>
	 * @param string $name attribut name du  sélecteur d'options
	 * @param mixed $contents Contenu du sélecteur d'options
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $selectAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML d'un sélecteur d'options <select>
	 * @access public
	 */	
	public static function addSelect($name, $contents, $attr = array())
	{
		$attributes = ' name="'.$name.'"';
		
		$optAttr = array_merge(self :: $commonAttr, self :: $selectAttr);		
		$attributes .= self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('select', $contents, $attributes);
	}

	/**
	 * openOptgroup
	 * ouvre un groupe d'options <optgroup>
	 * @param string $label attribut label
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $optgroupAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du groupe d'options <optgroup>
	 * @access public
	 */	
	public static function openOptgroup($label, $attr = array())
	{
		$attributes = ' label="'.$label.'"';
				
		// Attributs select
		$optAttr = array_merge(self :: $commonAttr, self :: $optgroupAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);		

		$html = self :: _openTag('optgroup', $attributes);		
		
		return $html;
	}

	/**
	 * closeOptgroup
	 * ferme un groupe d'options <optgroup>
	 * @return string Code HTML du groupe d'options <optgroup>
	 * @access public
	 */	
	public static function closeOptgroup()
	{
		return self :: _closeTag('optgroup');
	}
		
	/**
	 * affiche le code HTML d'une option d'un sélecteur d'option <option>
     * 
	 * @param string $legend Légende de l'option affiché dans la liste
	 * @param string $value Attribut value de l'option
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $optionAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de l'option d'un sélecteur d'option <option>
	 * @access public
	 */	
	public static function addOption($legend, $value, $attr = array())
	{
		$attributes = ' value="'.htmlspecialchars($value, ENT_COMPAT, self :: $charset).'"';
		
		$optAttr = array_merge(self :: $commonAttr, self :: $optionAttr);		
		$attributes .= self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('option', $legend, $attributes);
	}
	
	/**
	 * addButton
	 * affiche le code HTML d'un bouton <button>
	 * @param mixed $contents Contenu du bouton
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $buttonAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du bouton <button>
	 * @access public
	 */	
	public static function addButton($contents, $attr = array())
	{		
		$optAttr = array_merge(self :: $commonAttr, self :: $buttonAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('button', $contents, $attributes);
	}
	
	/*******************************************************
	 * Tableau
	 */	
	/**
	 * openTable
	 * ouvre un tableau de donnée <table>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $tableAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du tableau de donnée <table>
	 * @access public
	 */	
	public static function openTable($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $tableAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('table', $attributes);
	}

	/**
	 * closeTable
	 * ferme un tableau de donnée <table>
	 * @return string Code HTML du tableau de donnée <table>
	 * @access public
	 */	
	public static function closeTable()
	{
		return self :: _closeTag('table');
	}

	/**
	 * addCaption
	 * affiche le code HTML d'une légende associée à un tableau de donnée <caption>
	 * @param string $legend Légende à afficher
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $tdAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la légende associée à un tableau de donnée <caption>
	 * @access public
	 */	
	public static function addCaption($legend, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $captionAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('caption', $legend, $attributes);
	}	

	/**
	 * openThead
	 * ouvre un groupe de lignes d'en-tête d'un tableau de donnée <thead>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $theadAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du groupe de lignes d'en-tête d'un tableau de donnée <thead>
	 * @access public
	 */	
	public static function openThead($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $theadAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('thead', $attributes);
	}

	/**
	 * closeThead
	 * ferme un groupe de lignes d'en-tête d'un tableau de donnée <thead>
	 * @return string Code HTML du groupe de lignes d'en-tête d'un tableau de donnée <thead>
	 * @access public
	 */	
	public static function closeThead()
	{
		return self :: _closeTag('thead');
	}

	/**
	 * addThead
	 * affiche le code HTML d'un groupe de lignes d'en-tête d'un tableau de donnée <thead>
	 * @param mixed $rows Ligne du groupe
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $theadAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du groupe de lignes d'en-tête d'un tableau de donnée <thead>
	 * @access public
	 */	
	public static function addThead($rows, $attr = array())
	{
		$html = self :: openThead($attr);
		if (is_array($rows)) {
			foreach ($rows as $row) {
				$html .= $row."\n";
			}
		} else {
			$html .= $rows."\n";
		}
		
		$html .= self :: closeThead();
		
		return $html;
	}	

	/**
	 * openTfoot
	 * ouvre un groupe de lignes de pied d'un tableau de donnée <tfoot>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $tfootAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du groupe de lignes de pied d'un tableau de donnée <tfoot>
	 * @access public
	 */	
	public static function openTfoot($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $tfootAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('tfoot', $attributes);
	}

	/**
	 * closeTfoot
	 * ferme un groupe de lignes de pied d'un tableau de donnée <tfoot>
	 * @return string Code HTML du groupe de lignes de pied d'un tableau de donnée <tfoot>
	 * @access public
	 */	
	public static function closeTfoot()
	{
		return self :: _closeTag('tfoot');
	}

	/**
	 * addTfoot
	 * affiche le code HTML d'un groupe de lignes de pied d'un tableau de donnée <tfoot>
	 * @param mixed $rows Lignes du groupe
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $tfootAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du groupe de lignes de pied d'un tableau de donnée <tfoot>
	 * @access public
	 */	
	public static function addTfoot($rows, $attr = array())
	{
		$html = self :: openTfoot($attr);
		if (is_array($rows)) {
			foreach ($rows as $row) {
				$html .= $row."\n";
			}
		} else {
			$html .= $rows."\n";
		}
		
		$html .= self :: closeTfoot();
		
		return $html;
	}	

	/**
	 * openTbody
	 * ouvre un groupe de lignes de corps d'un tableau de donnée <tbody>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $tbodyAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du groupe de lignes de corps d'un tableau de donnée <tbody>
	 * @access public
	 */	
	public static function openTbody($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $tbodyAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('tbody', $attributes);
	}

	/**
	 * closeTbody
	 * ferme un groupe de lignes de corps d'un tableau de donnée <tbody>
	 * @return string Code HTML du groupe de lignes de corps d'un tableau de donnée <tbody>
	 * @access public
	 */	
	public static function closeTbody()
	{
		return self :: _closeTag('tbody');
	}

	/**
	 * addTbody
	 * affiche le code HTML d'un groupe de lignes de corps d'un tableau de donnée <tbody>
	 * @param mixed $rows Lignes du groupe
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $tbodyAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du groupe de lignes de corps d'un tableau de donnée <tbody>
	 * @access public
	 */	
	public static function addTbody($rows, $attr = array())
	{
		$html = self :: openTbody($attr);
		if (is_array($rows)) {
			foreach ($rows as $row) {
				$html .= $row."\n";
			}
		} else {
			$html .= $rows."\n";
		}
		
		$html .= self :: closeTbody();
		
		return $html;
	}	

	/**
	 * openTr
	 * ouvre une ligne d'un tableau de donnée <tr>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $trAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la ligne d'un tableau de donnée <tr>
	 * @access public
	 */	
	public static function openTr($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $trAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('tr', $attributes);
	}

	/**
	 * closeTr
	 * ferme une ligne d'un tableau de donnée <tr>
	 * @return string Code HTML de la rangée du tableau de donnée <tr>
	 * @access public
	 */	
	public static function closeTr()
	{
		return self :: _closeTag('tr');
	}

	/**
	 * addTr
	 * affiche le code HTML d'une ligne d'un tableau de donnée <tr>
	 * @param mixed $cells Cellules de la ligne
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $trAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la ligne d'un tableau de donnée <tr>
	 * @access public
	 */	
	public static function addTr($cells, $attr = array())
	{
		$html = self :: openTr($attr);
		if (is_array($cells)) {
			foreach ($cells as $cell) {
				$html .= $cell."\n";
			}
		} else {
			$html .= $cells."\n";
		}
		
		$html .= self :: closeTr();
		
		return $html;
	}	

	/**
	 * openTh
	 * ouvre une cellule d'en-tête d'un tableau de donnée <th>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $thAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la cellule d'en-tête d'un tableau de donnée <th>
	 * @access public
	 */	
	public static function openTh($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $thAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('th', $attributes);
	}

	/**
	 * closeTh
	 * ferme une cellule d'en-tête d'un tableau de donnée <th>
	 * @return string Code HTML de la cellule d'en-tête d'un tableau de donnée <th>
	 * @access public
	 */	
	public static function closeTh()
	{
		return self :: _closeTag('th');
	}

	/**
	 * addTh
	 * affiche le code HTML d'une cellule d'en-tête d'un tableau de donnée <th>
	 * @param mixed $contents contenu de la cellule
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $thAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la cellule d'en-tête d'un tableau de donnée <th>
	 * @access public
	 */	
	public static function addTh($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $thAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('th', $contents, $attributes);
	}	

	/**
	 * openTd
	 * ouvre une cellule d'un tableau <td>
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $tdAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la cellule d'un tableau <td>
	 * @access public
	 */	
	public static function openTd($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $tdAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _openTag('td', $attributes);
	}

	/**
	 * closeTd
	 * ferme une cellule d'un tableau <td>
	 * @return string Code HTML de la cellule d'un tableau <td>
	 * @access public
	 */	
	public static function closeTd()
	{
		return self :: _closeTag('td');
	}

	/**
	 * addTd
	 * affiche le code HTML d'une cellule d'un tableau <td>
	 * @param mixed $contents contenu de la cellule
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $tdAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la cellule d'un tableau <td>
	 * @access public
	 */	
	public static function addTd($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $tdAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('td', $contents, $attributes);
	}	

	/*******************************************************
	 * Images
	 */	

	/**
	 * addImg
	 * ajoute le code HTML d'une image <img />
	 * @param string $path Chemin de l'image
	 * @param string $alt Texte alternatif de l'image
	 * @param array $attr Attributs facultatifs de l'image déclarés sous la forme array('attribut' => 'value') 
	 * @return string Code HTML de l'image
	 * @access public
	 */	
	public static function addImg($path, $alt = '', $attr = array())
	{
		$html = '';
		
		if (!empty($path) && 
			is_string($path) && 
			is_file($path) && 
			in_array($imgExt = strrchr(basename($path), '.'), self :: $imgExtAllowed)
		) {		
			// Attribut obligatoire
			$src = ' src="'.$path.'"';
			$alt = ' alt="'.(($alt != '')? $alt : basename($path, $imgExt)).'"';			
			$size = @getimagesize($path);		
			$attributes = $src.$alt.' '.$size[3];
					
    		// Attributs optionnels
			$optAttr = array_merge(self :: $commonAttr, self :: $imgAttr);		
			$attributes .= self :: _getAttributes($optAttr, $attr);

			$html .= self :: _addShortTag('img', $attributes);
		}
	
		return $html;
	}

	/*******************************************************
	 * Section Head
	 */	

	/**
	 * addTitle
	 * affiche le code HTML d'un titre de document <title>
	 * @param string $contents Contenu du titre
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $titleAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du titre de document <title>
	 * @access public
	 */	
	public static function addTitle($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $titleAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);

		return self :: _addTag('title', $contents, $attributes);
	}

	/**
	 * addMeta
	 * affiche le code HTML d'une méta-information <meta />
	 * @param string $content Valeur de la méta-information
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $metaAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la meta-information <meta />
	 * @access public
	 */	
	public static function addMeta($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $metaAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addShortTag('meta', $attributes);
	}
	
	/**
	 * addScript
	 * affiche le code HTML d'un script <script>
	 * @param string $contents Contenu du script
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $scriptAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du script <script>
	 * @access public
	 */	
	public static function addScript($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $scriptAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);

		return self :: _addTag('script', $contents, $attributes);
	}

	/**
	 * addNoscript
	 * affiche le code HTML d'un block de texte alternatif aux scripts <noscript>
	 * @param string $contents Contenu du noscript
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $noscriptAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du noscript <noscript>
	 * @access public
	 */	
	public static function addNoscript($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $noscriptAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);

		return self :: _addTag('noscript', $contents, $attributes);
	}

	/**
	 * addLink
	 * affiche le code HTML d'un lien externe <link>
	 * @param string $path Chemin du lien
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $aAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du lien ou de l'ancre <a>
	 * @access public
	 */	
	public static function addLink($path, $attr = array())
	{
		// Attribut obligatoire
		$attributes = ' href="'.$path.'"';

		$optAttr = array_merge(self :: $commonAttr, self :: $linkAttr);		
		$attributes .= self :: _getAttributes($optAttr, $attr);
		
		return self :: _addShortTag('link', $attributes);
	}

	/**
	 * addStyle
	 * affiche le code HTML d'un block faisant référence à des styles CSS <style type="text/css">
	 * @param string $contents Contenu du style CSS
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $styleAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du block <style type="text/css">
	 * @access public
	 */	
	public static function addStyle($contents, $attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $styleAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);

		return self :: _addTag('style', $contents, $attributes);
	}

	/*******************************************************
	 * Section inline
	 */

	/**
	 * addA
	 * affiche le code HTML d'un lien ou d'une ancre <a>
	 * @param string $path Chemin du lien
	 * @param mixed $contents Contenu du lien ou de l'ancre
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $aAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du lien ou de l'ancre <a>
	 * @access public
	 */	
	public static function addA($path, $contents, $attr = array())
	{
		// Attribut obligatoire si c'est un lien
		$attributes = ($path != '')? ' href="'.$path.'"' : '';

		$optAttr = array_merge(self :: $commonAttr, self :: $aAttr);		
		$attributes .= self :: _getAttributes($optAttr, $attr);
		
		return self :: _addTag('a', $contents, $attributes);
	}
	
	/**
	 * addBr
	 * affiche le code HTML d'un saut de ligne <br />
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $brAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du saut de ligne
	 * @access public
	 */	
	public static function addBr($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $brAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);

		return self :: _addShortTag('br', $attributes);
	}
	
	/**
	 * addHr
	 * affiche le code HTML d'une ligne horizontale <hr />
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr et $hrAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la ligne horizontale
	 * @access public
	 */	
	public static function addHr($attr = array())
	{
		$optAttr = array_merge(self :: $commonAttr, self :: $hrAttr);		
		$attributes = self :: _getAttributes($optAttr, $attr);
		
		return self :: _addShortTag('hr', $attributes);
	}

	
	/**
	 * addEm
	 * affiche le code HTML d'un emphasis <em>
	 * @param mixed $contents Contenu textuel de l'emphasis
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML du lien ou de l'ancre <a>
	 * @access public
	 */	
	public static function addEm($contents, $attr = array())
	{
		$attributes = self :: _getAttributes(self :: $commonAttr, $attr);
		
		return self :: _addTag('em', $contents, $attributes);
	}

	/**
	 * addStrong
	 * affiche le code HTML d'un texte mis en valeur de façon forte <strong>
	 * @param mixed $contents Contenu textuel de la balise
	 * @param array $attr Attributs sous la forme d'un tableau associatif array(key => value)
	 *					  (voir les propriétés $commonAttr pour connaitre la liste des attributs disponibles)
	 * @return string Code HTML de la balise <strong>
	 * @access public
	 */	
	public static function addStrong($contents, $attr = array())
	{
		$attributes = self :: _getAttributes(self :: $commonAttr, $attr);
		
		return self :: _addTag('strong', $contents, $attributes);
	}

	/*******************************************************
	 * Autres
	 */	

	/**
	 * addAnything
	 * affiche le code HTML du contenu
	 * @param mixed $contents Contenu à afficher
	 * @return string Code HTML du contenu
	 * @access public
	 */	
	public static function addAnything($contents)
	{
		$html = '';
		if (is_array($contents)) {
			foreach($contents as $val) {
				$html .= $val;
			}
		} else {
			$html .= $contents;
		}

		return $html;
	}

	/**
	 * addSpace
	 * ajoute des espaces dans but de formatter le code source
	 * @param number $nbSpace Nombre d'espaces consécutifs
	 * @return string Espaces consécutifs
	 * @access public
	 */	
	public static function addSpace($nbSpace)
	{
		$html = '';
		for($i = 0; $i < $nbSpace; $i ++) {
			$html .= ' ';	
		}
		
		return $html;
	}

}