<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/manage_records_helper.php';

class Manage_addons_writers_docs_helper extends Manage_records_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_sort_options = array();	 // Options de tri
    protected $_addons = array();        // Tableau contenant les addons
    protected $_writer_rights = array(); // Droits du rédacteur
    protected $_doc_infos = array('name' => '', 'type' => ''); // Tableau contenant les informations des documents (nom, type)
    //

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct($writer_rights = array(), $doc_infos = array('name' => '', 'type' => ''))
    {        
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);
        $this -> _doc_infos = $this -> _set_doc_infos($doc_infos);

        parent :: __construct();

        $this -> CI -> load_helper('addons_helper');

        $this -> _addons = $this -> _get_addons();
        
        $this -> _load_addons_lang();
 //       $this -> _load_addons_model();
        
        $this -> CI -> load_library('writers_managed', $this -> _writer_rights['id']);

        /**
         * controle de sécurité
         */
        if ($this -> _params['doctype'] != $this -> _doc_infos['type']) { // Redirection si nécessaire
           $this -> search();    
        }         
         
        if (! ADMR_IS_ADMIN && ! $this -> _is_doc_allowed()) {
            Url_helper :: redirect('display_error&type=disallowed');
        }
        //
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_writer_rights($writer_rights)
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;	// Droits du rédacteur         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les propriétés du document (type et nom)
     * 
     * @access protected
     * @param string Type du document
	 * @return array Tableau contenant les informations (type, nom) du document
	 */	
    protected function _set_doc_infos($doc_infos)
    {
        if (!isset($doc_infos['type']) || !isset($doc_infos['name'])) {
            die('ERROR : vous devez définir le type et le nom du document');    
        }        
        
        return $this -> _doc_infos = $doc_infos;        
    }
    
	// --------------------------------------------------------------------

    /**
	 * Renvoie les noms des addons
     * 
	 * @access private
     * @return void
	 */
    protected function _get_addons()
    {
        return $this -> CI -> addons_helper -> get_addons($except = array('messages'));
    }
    
	// --------------------------------------------------------------------

    /**
	 * Charge les items de langue des addons
     * 
	 * @access private
     * @return void
	 */
    private function _load_addons_lang()
    {
        $addons = $this -> _get_addons();        

        $this -> CI -> addons_helper -> load_addons_lang($addons);
              
        $this -> _lang = $this -> CI -> get_lang(); // Nécessaire pour récupérer les items de langue des addons chargés
    }

	// --------------------------------------------------------------------

    /**
	 * Charge les fichiers de modèles des addons
     * 
	 * @access private
     * @return void
	 */
 /*   private function _load_addons_model()
    {
        $addons = $this -> _get_addons();        

        foreach($addons as $addon_name) {
            $this -> CI -> load_addon_model($addon_name, 'writer_'.$addon_name.'_model', array('id' => $this -> _params['writerid']));
        }           
    }*/

	// --------------------------------------------------------------------

	/**
	 * renvoie les paramètres utilisés dans la page
     * 
     * @access public
	 * @return void
	 */	
/*    public function get_params()
    {
        return $this -> _params;	// Paramètres         
    }
*/
	// --------------------------------------------------------------------

	/**
	 * renvoie les options de tri des données
     * 
     * @access public
	 * @return void
	 */	
/*    public function get_sort_options()
    {
        return $this -> _sort_options;	// Options de tri         
    }
*/
	// --------------------------------------------------------------------
    
	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_sort_options()
    {
        return $this -> _sort_options = array('id_asc', 'id_desc', 'status_asc', 'status_desc', 'up_asc', 'up_desc');	// Options de tri         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        $this -> _params = array_merge(
            parent :: _set_params(),
            array(
                'writerid' => Var_helper :: import('writerid', '', 0, array('trim'), array(array('Var_helper', 'is_digit'))),
                'doctype'  => Var_helper :: import('doctype',  '', NULL, array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))),
                'docid'    => trim(Var_helper :: import('docid',    '', 0, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
/*                'writerid' => trim(Var_helper :: import('writerid', '', 0, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
                'doctype'  => trim(Var_helper :: import('doctype',  '', NULL, array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))), '-'),
                'docid'    => trim(Var_helper :: import('docid',    '', 0, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),*/
            )
        );
       
        return $this -> _params;
    }
    
	// --------------------------------------------------------------------

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        parent :: manage();
    }

	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        $uri = $this -> _build_uri_for_search_redirection();
                
        if (!empty($this -> _params['writerid'])) {
            $uri .= '&writerid='.$this -> _params['writerid'];
        }
        		
		Url_helper :: redirect($uri);
    }

	// --------------------------------------------------------------------

	/**
	 * construit le lien de redirection vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    protected function _build_uri_for_search_redirection()
    {
        $doc_infos = $this -> _get_doc_infos_by_type($this -> _params['doctype']); 
        
        if (!empty($doc_infos) && !empty($this -> _params['writerid'])) {
            $uri = 'addons/'.$doc_infos['name'].'/manage_addons_writers_'.$doc_infos['name'].'/synchronize&doctype='.$doc_infos['type'];  
        } else {
            $uri = 'manage_addons_writers_docs';  
        }

        return $uri;        
    }

	// --------------------------------------------------------------------

	/**
	 * synchronize les données des documents enregistrées pour le rédacteur avec ceux enregistrés dans guppy
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    public function synchronize()
    {
        $uri = Url_helper :: build_uri(
            $params = array('writerid' => $this -> _params['writerid'], 'doctype' => $this -> _params['doctype']),
            $basehref = str_replace('/synchronize', '', ADMR_CONTROLLER)
        );
              
        Url_helper :: redirect($uri);
    }
    
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        $title = ucfirst($this -> _lang['manage_addons_writers_docs']);
        
        if (!empty($this -> _params['writerid']) && !empty($this -> _params['doctype'])) {
            $this -> CI -> load_model('writer_model');
            $writer = $this -> CI -> writer_model -> get_by_id($this -> _params['writerid']);
            
            if (!empty($writer)) {
                $title = ucfirst(sprintf($this -> _lang['manage_'.$this -> _params['doctype'].'_docs_created_by_writer_%s'], $writer['name']));     
            }      
        }
        
        return $title;       
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_infos_page_content()
    {		
        return $this -> _lang['infos_page_manage_addons_writers_docs'];
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
     * @access public
     * @return string menu de la page
	 */	
    public function set_menu_plugin_items()
    {		
        $this -> CI -> load_helper('plugin_menu_for_writers_helper');
        
        if (ADMR_IS_ADMIN) {
            return Plugin_menu_helper :: set_admin_menu_items($this -> _lang, $this -> _config);    
        } else {
            return $this -> CI -> plugin_menu_for_writers_helper -> set_public_items('writers', $this -> _lang, $this -> _config, $this -> _writer_rights);         
        }  
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _get_records()
    {
        return array();
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
/*    protected function _filter_records($records)
    {
        return $records;       
    }
*/    
	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements postés
     * 
     * @access protected
	 * @return void
	 */	
	/**
	 * Met à jour des données des enregistrements postés
     * 
     * @access public
	 * @return boolean
	 */	
    protected function _update_records()
    {
        return parent :: _update_records();
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options du menu de sélection des actions pour la mise à jours des enregistrements sous la forme 
     * array(
     *    array('label' => '', 'value' => '', 'attrs' => array()),
     * )
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_select_actions_for_update_records()
    {
        $actions = array();
    
        // (Dés)activation
        if (!empty($this -> _writer_rights['writers_docs_act'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['activate_docs_selected']),   'value' => 'a');
            $actions[] = array('label' => ucfirst($this -> _lang['inactivate_docs_selected']), 'value' => 'i');
        }
        
        // Suppression
        if (!empty($this -> _writer_rights['writers_docs_del'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['delete_docs_selected']), 'value' => 'd', 'attrs' => array('title' => ucfirst($this -> _lang['action_removes_docs_definitively'])));
        }

        // Validation
        $actions[] = array('label' => ucfirst($this -> _lang['validate_docs_selected']), 'value' => 'v');

        return $actions;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements selon l'action sélectionnée
     * 
     * @access protected

     * @param string Identifiant de l'action à appliquer pour la mise à jour
	 * @return boolean
	 */
    protected function _update_records_by_action($records_ids, $action)
    {
        // (Dés)Activation
        if (in_array($action, array('a', 'i'))) {
            return $this -> _activate_records_or_not($records_ids, $action);
        }
        // Suppression
        elseif ($action == 'd') { 
            return $this -> _delete_records($records_ids);
        }
        // Validation
        elseif ($action == 'v') {
            return $this -> _validate_records($records_ids);
        }

        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Active ou désactive les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
     * @param string action à appliquer (a = activation et i = désactivation)
	 * @return boolean
	 */
    protected function _activate_records_or_not($records_ids, $action)
    {
        // TODO
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return boolean
	 */
    protected function _delete_records($records_ids)
    {
        // TODO
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Valide les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return boolean
	 */
    protected function _validate_records($records_ids)
    {
        // TODO
        return FALSE;
    }

	// --------------------------------------------------------------------

    /*
     * Affiche ou renvoie le contenu de la vue
     *
     * @param array Données des enregistrements
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    protected function _build_view($records)
    {
        return parent :: _build_view($records);
    }    

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_manage_records_view()
    {
        return parent :: _get_layout_for_manage_records_view();    
    }

	// --------------------------------------------------------------------

	/**
	 * construit le formulaire de sélection des données
     * 
     * @access protected
	 * @return string
	 */	
    protected function _build_form_data_filtering()
    {
        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => Url_helper :: build_uri().'/search',
            'writers' => $this -> _get_writers(),
            'writer_id' => $this -> _params['writerid'],
            'docs' => $this -> _get_docs_infos(),
            'doctype' => !empty($this -> _params['doctype']) ? explode('-', $this -> _params['doctype']) : array(),
            'sort' => $this -> _params['sort'],
        );
        
        return $this -> CI -> render($this -> _get_layout_for_form_data_filtering_view(), $data, TRUE);               
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue pour la recherche de documents des rédacteurs
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_form_data_filtering_view()
    {
        $layout = 'fragments/form_addons_writers_docs_filtering';
        
        return $layout;    
    }

	// --------------------------------------------------------------------

	/**
	 * récupère la liste des rédacteurs
     * 
     * @access protected
	 * @return array Tableau contenant la liste des rédacteurs
	 */
    protected function _get_writers()
    {
        $writers = $this -> CI -> writers_managed -> get_writers_managed(array(), 'ch_asc');
        
        return $writers;
    }

	// --------------------------------------------------------------------

	/**
	 * récupère les infos des documents des plugins
     * 
     * @access protected
	 * @return array Tableau contenant les différents types de documents des plugins
     *               sous la forme array('ar' => array(name => 'xxxxx', 'type' => 'xxxxx'),
     *                                   'ne' => array(name => 'yyyyy', 'type' => 'yyyyy'),
     *                                   ...)
	 */
    protected function _get_docs_infos()
    {
        $docs_infos = array();

        if (!empty($this -> _writer_rights['writers_docs_manage'])) {
            $addons = $this -> _get_addons();
        
            foreach($addons as $addon_name) {               
                $docs_infos = array_merge($docs_infos, array($addon_name => array('name' => $addon_name, 'type' => $addon_name)));
//                $docs_infos = array_merge($docs_infos, $this -> CI -> {'writer_'.$addon_name.'_model'} -> get_doc_infos());
            }
        }
        
        if ($this -> _writer_rights['writers_docs_manage'] == 2) {
            $docs_infos = array_intersect_key($docs_infos, array_flip($this -> _writer_rights['writers_docs_types_allowed']));
        }
        

        return $docs_infos;
    }

	// --------------------------------------------------------------------

	/**
	 * récupère les infos des documents du plugin identifié par son type
     * 
     * @access protected
     * @param string Type de l'addon
	 * @return array Tableau contenant les infos des documents du plugin identifié par son type
     *               sous la forme array('ar' => array(name => 'xxxxx', 'type' => 'xxxxx')
	 */
    protected function _get_doc_infos_by_type($doc_type)
    {
        $docs_infos = $this -> _get_docs_infos();
        
        return (!empty($doc_type) && !empty($docs_infos[$doc_type])) ? $docs_infos[$doc_type] : array();
    }

	// --------------------------------------------------------------------

	/**
	 * récupère les infos des documents de l'addon identifié par son nom
     * 
     * @access protected
     * @param string Nom de l'addon
	 * @return array Tableau contenant les infos des documents de l'addon identifié par son nom
     *               sous la forme array('ar' => array(name => 'xxxxx', 'type' => 'xxxxx')
	 */
    protected function _get_doc_infos_by_name($doc_name)
    {
        $docs_infos = $this -> _get_docs_infos();
        
        foreach($docs_infos as $doc_infos) {
            if ($doc_infos['name'] === $doc_name) {
                return $doc_infos;    
            }    
        }
        
        return array();
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $parent = parent :: set_header_addons();

        $js = '<script type="text/javascript" src="'.ADMR_JS_PATH.'/toggle_records_selection_display_for_management.js"></script>'."\n";
        
        $css = '';
                
        return $parent.$css.$js;
    }


	// --------------------------------------------------------------------

	/**
	 * construit le tableau de données
     * 
	 * @return string Tableau HTML contenant les enregistrements
	 * @access public
	 */	
    protected function _build_data_table($records)
    {		
        return parent :: _build_data_table($records);        
    }
  
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
		$headers = array(
            parent :: _set_data_table_header_for_id(),
            array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['type']), 'type'), 'attrs' => array('id' => 'rtype')),
            parent :: _set_data_table_header_for_description($this -> _lang['title']),
			array('contents' => parent :: _anchor_sort_records(ucfirst($this -> _lang['state']), 'up'),   'attrs' => array('id' => 'rstate')),
            parent :: _set_data_table_header_for_status(),
		);

        return $headers;
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne Type de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne "type"
	 */    
/*    protected function _set_data_table_header_for_type()
    {
        return array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['type']), 'type'), 'attrs' => array('id' => 'r_type'));
    }
*/   
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne status de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne status
	 */    
/*    protected function _set_data_table_header_for_status()
    {
		return array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['status']), 'status'), 'attrs' => array('id' => 'rstatus'));
    }
 */   
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne Description de la table de données
     * 
	 * @access protected
     * @param string Intitulé de la colonne Description
	 * @return array Tableau contenant l'entêtes de la colonne Description
	 */    
 /*   protected function _set_data_table_header_for_description($label)
    {
        return array('contents' => $this -> _anchor_sort_records(ucfirst($label), 'ch'), 'attrs' => array('id' => 'rdesc'));
    }
  */  
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne Commandes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne Commandes
	 */    
/*    protected function _set_data_table_header_for_commands()
    {
        return array('contents' => ucfirst($this -> _lang['commands']), 'attrs' => array('id' => 'rcommands'));
    }
*/
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {
    	$cells = array(
            parent :: _set_data_table_cell_for_id($record),
			array('contents' => $this -> _add_contents_for_td_type($record), 'attrs' => array('align' => 'center')),
			parent :: _set_data_table_cell_for_description($record),
            array('contents' => $this -> _add_contents_for_td_state($record), 'attrs' => array('align' => 'center')),
            parent :: _set_data_table_cell_for_status($record),

    	);
        
        return $cells;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Id" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Id" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
/*    protected function _set_data_table_cell_for_id($record)
    {
        return array('contents' => $this -> _add_contents_for_td_id($record), 'attrs' => array('align' => 'left'));
    }
*/
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Status" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Status" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
 /*   protected function _set_data_table_cell_for_status($record)
    {
        return array('contents' => $this -> _add_contents_for_td_status($record), 'attrs' => array('align' => 'center'));
    }
*/

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Description" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Description" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
 /*   protected function _set_data_table_cell_for_description($record)
    {
        return array('contents' => $this -> _add_contents_for_td_description($record), 'attrs' => array('align' => 'left'));
    }
*/

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Commands" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Commands" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
/*    protected function _set_data_table_cell_for_commands($record)
    {
        return array('contents' => $this -> _add_contents_for_td_commands($record), 'attrs' => array('align' => 'center'));
    }
*/
	// --------------------------------------------------------------------

	/**
	 * Définit et renvoie le contenu de la cellule "Id" du tableau de données
     * 
	 * @access private
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
/*	protected function _add_contents_for_td_id($record)
	{
		$id = $record['id'];
        $actions = $this -> _set_select_actions_for_update_records();
        $view = '';
        
        if (! empty($actions)) {
            $view .= Html_helper :: addInput(
                $type = 'checkbox',
                $name = 'ids[]',
                $value = $id,
                $attr = array('id' => 'record'.$id,'title' => ucfirst($this -> _lang['select_record']))
    		);
            $view .= '&nbsp;';
            $view .= Html_helper :: addLabel(
                $content = $id,
                $attr = array('for' => 'record'.$id)
    		);	
        } else {
            $view .= $id;
        }
        
		return $view;
	}
*/
	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Status" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
/*	protected function _add_contents_for_td_status($record)
	{
		global $admin;
		
        $status = $record['status'];
		
		if ($status == 'a') { // Status activé
			$view = Html_helper :: addImg(
				$path = ADMR_IMG_ACTIVE,
				$alt = $admin[765],
				$attr = array('title' => $alt)
			);
			
  		} elseif ($status == 'i') { // Status désactivé
			$view = Html_helper :: addImg(
				$path = ADMR_IMG_INACTIVE,
				$alt = $admin[766],
				$attr = array('title' => $alt)
			);
            
    	} else {
    		$view = 'ERROR';
  		}
				
		return $view;
	}
*/
	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule intitulée "Type"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_type($record)
	{
		$type = $record['type'];
        $doc_types = $this -> _get_docs_infos();
       
        $label_type = $this -> _lang[$doc_types[$type]['name']];

        $view = '&nbsp;'.$label_type;	
		
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "State" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_state($record)
	{
		$mode = $record['mode'];
        
        if ($mode == 2) { // Mise à jour
            $view = '&nbsp;'.Html_helper :: addImg(
    			$path = ADMR_IMG_UPDATE,
    			$alt = ucfirst($this -> _lang['update']),
    			$attr = array('title' => $alt, 'border' => '0')
    		);		  

		} elseif ($mode == 1) { // Nouveauté   
            $view = '&nbsp;'.Html_helper :: addImg(
    			$path = ADMR_IMG_NEW,
    			$alt = ucfirst($this -> _lang['new']),
    			$attr = array('title' => $alt, 'border' => '0')
    		);
		} else {
            $view = '&nbsp;'.Html_helper :: addImg(
    			$path = ADMR_IMG_APPROVED,
    			$alt = ucfirst($this -> _lang['approved']),
    			$attr = array('title' => $alt, 'border' => '0')
    		);
		}
        
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu à la cellule "Description" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_description($record)
	{
        if (!empty($this -> _writer_rights['writers_docs_edit'])) {
            $view = Html_helper :: addA(
    				$href = $this -> _build_href_for_td_description($record),
    				$contents = Html_helper :: addImg(
    					$path = ADMR_IMG_EDIT,
    					$alt = $this -> _lang['edit'],
    					$attr = array('title' => $alt, 'border' => '0')
    				)
    				.'&nbsp;'.$this -> _get_record_description($record),
    				$attr = array('title' => $alt)
    		);	
        } else {
            $view = $this -> _get_record_description($record);
        }

        return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie le contenu de la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
     * @param object Modèle de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
    protected function _get_record_description($record)
    {
        return 'TODO';
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie l'url du lien du document dans la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _build_href_for_td_description($record)
    {
        return 'TODO';
    }

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès au document par le rédacteur
     * 
	 * @access private
     * @return void
	 */
    private function _is_doc_allowed()
    {   
        if (!empty($this -> _params['writerid']) && !$this -> CI -> writers_managed -> is_writer_managed($this -> _params['writerid'])) { // Rédacteur non géré
            return FALSE;
        }       
        
        if (!empty($this -> _doc_infos['type']) && !$this -> CI -> writers_managed -> is_addons_doc_type_allowed($this -> _doc_infos['type'])) {  // Document non géré
            return FALSE;        
        }
        
        return TRUE;    
    }

	// ---------------------------------------------------------------------------- //

} // End of Class