<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/manage_docs_helper.php';

class Manage_menuitems_helper extends Manage_docs_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_sort_options = array();	 // Options de tri    
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    function __construct($writer_rights = array())
    {
        parent :: __construct(TYP_OPTMENU, $writer_rights);    
        
        $this -> CI -> load_library('writer_acl', $writer_rights);

        $this -> CI -> load_model('menuitems_model');
        $this -> CI -> load_model('boxmenus_model');
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        parent :: manage();
    }
    
	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        parent :: search();       
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @access public
     * @return string titre de la page
     */        
    public function set_title_page()
    {
        return parent :: set_title_page();
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     *
	 * @access public
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();
 //       $js = '<script type="text/javascript" src="'.ADMR_JS_PATH.'/public_manage_menuitems.js"></script>'."\n";
         
        return $parent_addons.$js;
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
     * @access public
     * @return string description de la page
	 */	
    public function set_infos_page_content()
    {		
        return parent :: set_infos_page_content();
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
     * @access public
     * @return string menu de la page
	 */	
    public function set_menu_plugin_items()
    {		
        return parent :: set_menu_plugin_items();
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
		$headers = array(
            parent :: _set_data_table_header_for_id(),
            array('contents' => ucfirst($this -> _lang['menu']), 'attrs' => array('id' => 'r_menuid')),
            parent :: _set_data_table_header_for_description($this -> _lang['title']),			
			parent :: _set_data_table_header_for_status(),
            parent :: _set_data_table_header_for_commands(),
		);

        return $headers;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {    	
		$cells = array(
            parent :: _set_data_table_cell_for_id($record),
            array('contents' => $this -> _add_contents_for_td_boxmenu($record), 'attrs' => array('align' => 'center')),
            parent :: _set_data_table_cell_for_description($record),			
			parent :: _set_data_table_cell_for_status($record),
            parent :: _set_data_table_cell_for_commands($record),
		);
        
        return $cells;
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule intitulée "Menu"
     * 
	 * @access protected
	 * @param integer Identifiant du document
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_boxmenu($record)
	{        
        $menu_id = $record['menuid'];        
        $boxmenu = $this -> CI -> boxmenus_model -> read($menu_id);

        $view = '';

		$view .= Html_helper :: addA(
			$href = ADMR_BASE_HREF_PLUGIN.'&amp;ctrl='.ADMR_CONTROLLER.'&amp;menuid='.$boxmenu['id'],
			$contents = $this -> CI -> boxmenus_model -> set_doc_heading($boxmenu),
			$attr = array('title' => ucfirst($this -> _lang['show_menu_items']))
		);	
        
        return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Commandes" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_commands($record)
	{        
        $item_id = $record['id'];        
        $doc_id = $this -> CI -> menuitems_model -> _get_doc_id_linked_to_item($item_id);
        $writer_doc = $this -> CI -> writer_docs_model -> get_by_id($doc_id);
        $view = '';
        
        if (!empty($writer_doc)) {
            $doc_type = $this -> CI -> writer_docs_model -> get_doc_types($writer_doc['type']);
          
    		$view .= Html_helper :: addA(
    			$href = ADMR_BASE_HREF_PLUGIN.'&amp;ctrl=add_'.$doc_type['name'].'&amp;sort='.$this -> _config['sort_option_by_default'].'&amp;id='.$doc_id,
    			$contents = Html_helper :: addImg(
    				$path = ADMR_IMG_EDIT,
    				$alt = ucfirst($this -> _lang['edit_doc_linked_to_menu_item']),
    				$attr = array(
    					'title' => $alt,
    					'border' => '0'
    				)
    			)
                .'&nbsp;&nbsp;',
    			$attr = array()
    		);	
        }
        
        return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        $this -> _params = parent :: _set_params();       
        $this -> _params['menuid'] = trim(Var_helper :: import('menuid', '', NULL, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'); // Id du menu lié à l'item de menu
        $this -> _params['itemdocid'] =  trim(Var_helper :: import('itemdocid', '', NULL, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-');  // Id du document lié à l'item de menu
        
        return $this -> _params;
    }

	// --------------------------------------------------------------------
	/**
	 * Filtre les enregistrements et renvoie le résultat
     * 
     * @access protected
     * @param array Enregistrements à filtrer
	 * @return array Tableau contenant les enregistrements qui ont passés le(s) filtre(s)
	 */
    protected function _filter_records($records)
    {        
        $menuid = empty($this -> _params['menuid']) ? NULL : explode('-', $this -> _params['menuid']); 
        $itemdocid  = empty($this -> _params['itemdocid'])  ? NULL : explode('-', $this -> _params['itemdocid']);

        /**
         *  Sélection par id des menus auxquels appartiennent les items de menus
         */       
        if (!empty($menuid)) {
            $records = $this -> _filter_menu_items_by_menus($records, $menuid);        
        }
        //
        
        /**
         *  Sélection par id des documents internes liés à l'item de menu
         */        
        else if (!empty($itemdocid)) {
            $records = $this -> _filter_menu_items_by_docs($records, $itemdocid);    
        }      

        return $records;    
    }

	// --------------------------------------------------------------------
 
	/**
	 * Récupère les données des options de menu correspondant au menu
     * 
     * @access private
	 * @param array Identifiants du ou des menus
	 * @return array
	 */    
    private function _filter_menu_items_by_menus($items, $menu_ids)
    {
        $data = array();
        
        if (empty($menu_ids)) {
            return array();
        }
         
        settype($menu_ids, 'array');
       
        foreach($items as $item) {
            $tmp = $this -> CI -> menuitems_model -> read($item['id']);
            
            if (in_array($tmp['menuid'], $menu_ids)) {
                $data[$item['id']] = $item;    
            }   
        }
        
        return $data; 
    }

	// --------------------------------------------------------------------
 
	/**
	 * Récupère les données des options de menu correspondant aux documents (articles,..) sélectionnés
     * 
     * @access private
	 * @param array Tableau contenant les items de menu
	 * @param array Tableau contenant les identifiant des documents (articles,..) sélectionnés
	 * @return array
	 */    
    private function _filter_menu_items_by_docs($items, $doc_ids)
    {
        $data = array();
        
        if (empty($doc_ids)) {
            return array();
        }    

        foreach($items as $item) {
            $id = $this -> CI -> menuitems_model -> _get_doc_id_linked_to_item($item['id']);
            
            if (in_array($id, $doc_ids)) {
                $data[$item['id']] = $item;    
            }
        }
        
        return $data; 
    }

	// --------------------------------------------------------------------

} //End of Class