<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/manage_records_helper.php';

class Manage_photos_helper extends Manage_records_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_sort_options = array();	 // Options de tri
    protected $_doc_infos = array('name' => 'photoramas', 'type' => TYP_PHOTO); // Tableau contenant les informations du document (nom, type)
    
    protected $_photorama_id = 0; // Identifiant du photorama
    //
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct($writer_rights)
    {
        parent :: __construct();

        $this -> _photorama_id = $this -> _params['galid']; // Id du photorama
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);
        
        $this -> CI -> load_model('photoramas_model');
        $this -> CI -> load_model('photoramas_index_model');
        $this -> CI -> load_model('photoramas_diapos_model', array('id' => $this -> _photorama_id));
        $this -> CI -> load_model('photoramas_params_model', array('id' => $this -> _photorama_id));
        
        $this -> CI -> load_model('writer_docs_model', array('id' => $this -> _writer_rights['id']));

        
        if (! ADMR_IS_ADMIN && ! $this -> _is_doc_allowed($this -> _photorama_id)) {
            Url_helper :: redirect('display_error&type=disallowed');
        }
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_writer_rights($writer_rights)
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;	// Droits du rédacteur         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
/*    protected function _set_sort_options()
    {
        return parent :: _set_sort_options();         
    }
*/
	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        $this -> _params = array_merge(
            parent :: _set_params(),
            array(
                'galid'     => Var_helper :: import('galid', '', 0, array('trim'), array(array('Var_helper', 'is_digit'))),
                'photo_id' => trim(Var_helper :: import('id', '', 0, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
            )
        );
       
        return $this -> _params;
    }

	// --------------------------------------------------------------------

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        parent :: manage();
    }

	// --------------------------------------------------------------------

	/**
	 * crée ou régénère une miniature
     * 
     * @access public
	 * @return string code html
	 */	
    public function rebuild_thumbnail()
    {
        $photorama_params = $this -> CI -> photoramas_params_model -> read();
    
        if (!empty($photorama_params)) {
            /**
             * Récupération des noms des photos à traiter
             */
            $photos_names = array();
            
            if (!empty($this -> _params['photo_id'])) {
                $photos_ids = explode('-', $this -> _params['photo_id']);
                
                foreach($photos_ids as $photo_id) {
                    $photo = $this -> CI -> photoramas_diapos_model -> get_by_id($photo_id);
                    
                    if (!empty($photo)) {
                        $photos_names[] = $photo['filename'];    
                    }                   
                }
            }
            //
                       
            // Création des miniatures
            $this -> CI -> photoramas_diapos_model -> create_thumnails($photos_names, $photorama_params['width_max'], $photorama_params['height_max']);    
        }
        
        /**
         * Redirection
         */
        $uri = Url_helper :: build_uri(
            $params = array(
                'galid' => $this -> _photorama_id,
                'idpg' => $this -> _params['idpg'],
                'sort' => $this -> _params['sort']
            ),
            $basehref = Url_helper :: site_url(str_replace('/rebuild_thumbnail', '', ADMR_CONTROLLER))
        );

        Url_helper :: redirect($uri);
        //
        
        return TRUE;
    }

	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        $uri = str_replace('/search', '', ADMR_CONTROLLER);
        
        if (!empty($this -> _photorama_id)) {
            $uri .= '&galid='.$this -> _photorama_id;
        }

		Url_helper :: redirect($uri);
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @access public
     * @return string titre de la page
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['manage_photos']);
    }
 
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        return parent :: set_header_addons();        
    }
   
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
     * @access public
     * @return string description de la page
	 */	
    public function set_infos_page_content()
    {		
        return $this -> _lang['infos_page_manage_photos'];
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
     * @access public
     * @return string menu de la page
	 */	
    public function set_menu_plugin_items()
    {		
        $this -> CI -> load_helper('plugin_menu_for_photos_helper');

        if (ADMR_IS_ADMIN) {
            return $this -> CI -> plugin_menu_for_photos_helper -> set_admin_items('photos', $this -> _lang, $this -> _config, $this -> _writer_rights);        
        } else {
            return $this -> CI -> plugin_menu_for_photos_helper -> set_public_items('photos', $this -> _lang, $this -> _config, $this -> _writer_rights, array('photorama_id' => $this -> _photorama_id));        
        }
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _get_records()
    {
        $doc_ids = empty($this -> _params['docid']) ? array() : explode('-', $this -> _params['docid']);        
        
        $records = $this -> CI -> photoramas_diapos_model -> get(array('id' => $doc_ids, 'status' => array('a','i')), $this -> _params['sort']);    
        
        return $records;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
/*    protected function _filter_records($records)
    {
        return $records;       
    }
*/    
	// --------------------------------------------------------------------

	/**
	 * Met à jour des données des enregistrements postés
     * 
     * @access public
	 * @return string code html
	 */	
/*    protected function _update_records()
    {
        parent :: _update_records();
    }
*/
	// --------------------------------------------------------------------

	/**
	 * définit les options du menu de sélection des actions pour la mise à jours des enregistrements sous la forme 
     * array(
     *    array('label' => '', 'value' => '', 'attrs' => array()),
     * )
     * 
     * @access protected
	 * @return array
	 */	
    protected function _set_select_actions_for_update_records()
    {
        $actions = array();
      
        // (Dés)Activation des enregistrements
        if (!empty($this -> _writer_rights['photos_act'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['activate_docs_selected']),   'value' => 'a');
            $actions[] = array('label' => ucfirst($this -> _lang['inactivate_docs_selected']), 'value' => 'i');            
        }

        // Suppression des enregistrements
        if (!empty($this -> _writer_rights['photos_del'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['delete_docs_selected']), 'value' => 'd', 'attrs' => array('title' => ucfirst($this -> _lang['action_removes_docs_definitively'])));
        }

        return $actions;
    }

	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements selon l'action sélectionnée
     * 
     * @access protected
     * @param array Identifiants des enregistrements à mettre à jour
     * @param string Identifiant de l'action à appliquer pour la mise à jour
	 * @return void
	 */
    protected function _update_records_by_action($records_ids, $action)
    {
        // (Dés)Activation des enregistrements
        if (in_array($action, array('a', 'i'))) {
            return $this -> _activate_records_or_not($records_ids, $action);
        }
        // Suppression des enregistrements
        elseif ($action == 'd') { 
            return $this -> _delete_records($records_ids);
        }        
        //           
        
        return FALSE;
    }

	// --------------------------------------------------------------------

	/**
	 * Active ou désactive les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
     * @param string action à appliquer (a = activation et i = désactivation)
	 * @return void
	 */
    protected function _activate_records_or_not($records_ids, $action)
    {
        if (!empty($this -> _writer_rights['photos_act'])) {
            return $this -> CI -> photoramas_diapos_model -> update_status_by_id($records_ids, $action);
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return void
	 */
    protected function _delete_records($records_ids)
    {      
        if (!empty($this -> _writer_rights['photos_del'])) {
            return $this -> CI -> photoramas_diapos_model -> update_status_by_id($records_ids, 'd');
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

    /*
     * Affiche ou renvoie le contenu de la vue
     *
	 * @access protected
     * @param array Données des enregistrements
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    protected function _build_view($records)
    {
        return parent :: _build_view($records);
    }    

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_manage_records_view()
    {
        return parent :: _get_layout_for_manage_records_view();   
    }

	// --------------------------------------------------------------------

	/**
	 * construit le formulaire de sélection des données
     * 
     * @access protected
	 * @return string Formulaire html
	 */	
    protected function _build_form_data_filtering()
    {
        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => Url_helper :: build_uri().'/search',
            'photoramas' => $this -> _get_photoramas(),
            'photorama_id' => $this -> _photorama_id,
        );
        
        return $this -> CI -> render('fragments/form_photoramas_filtering', $data, TRUE);
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des galeries photos
	 *
	 * @access	protected
	 * @return	array sous la forme array(id => name)
	 */
    protected function _get_photoramas()
    {        
        $photoramas = array();
        $doc_infos = $this -> _doc_infos;
        $authorization = $this -> _writer_rights['photos_photoramas_manage'];
   
        if (in_array($authorization, array('1', '2', '3'))) {
            $this -> CI -> load_helper('photoramas_helper');
            $photoramas = $this -> CI -> photoramas_helper -> get_all(); // Toutes les galeries photos enregistrées dans guppy (par défaut) 
          
            if ($authorization == '3') { // Uniquement les galeries photos du rédacteur           
                $photoramas = array_intersect_key($photoramas, $this -> CI -> writer_docs_model -> get(array('type' => $doc_infos['type'])));
            }
            //
            
            elseif ($authorization == '2') { // Uniquement les galeries photos sélectionnées
                $photoramas = array_intersect_key($photoramas, array_flip($this -> _writer_rights['photos_photoramas_list_allowed']));                  
            }
            //
        }

        return $photoramas;     
    }

	// --------------------------------------------------------------------

	/**
	 * construit le tableau de données
     * 
	 * @return string Tableau HTML contenant les enregistrements
	 * @access public
	 */	
    protected function _build_data_table($records)
    {		
        return parent :: _build_data_table($records);        
    }

	// --------------------------------------------------------------------
  
	/**
	 * ajoute des données supplémentaires à l'enregistrement
     * 
	 * @access protected
     * @param array Tableau de données initiales de l'enregistrement
	 * @return array Tableau contenant les nouvelles données de l'enregistrement
	 */    
    protected function _add_more_data_for_record($record)
    {
//        return $this -> CI -> quizzplus_ids_model -> get_by_id($record['id']);        
        return array();
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
		$headers = array(
            parent :: _set_data_table_header_for_id(),
			parent :: _set_data_table_header_for_description($this -> _lang['title']),
            array('contents' => ucfirst($this -> _lang['preview']), 'attrs' => array('id' => 'rpreview')),
            parent :: _set_data_table_header_for_status(),
            parent :: _set_data_table_header_for_commands(),            
		);

        return $headers;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {
    	$cells = array(
            parent :: _set_data_table_cell_for_id($record),
            parent :: _set_data_table_cell_for_description($record),
            array('contents' => $this -> _add_contents_for_td_preview($record), 'attrs' => array('align' => 'center')),
            parent :: _set_data_table_cell_for_status($record),
            parent :: _set_data_table_cell_for_commands($record),
    	);
        
        return $cells;
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Id" du tableau de données
     * 
	 * @access private
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_id($record)
	{        
		return parent :: _add_contents_for_td_id($record);
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu à la cellule "Description" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_description($record)
	{
        if (!empty($this -> _writer_rights['photos_edit'])) {
            return parent :: _add_contents_for_td_description($record);
        } else {
            return $this -> _get_text_for_td_description($record);
        }
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie le texte de la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
    protected function _get_text_for_td_description($record)
    {
        return $record['filename'];
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu à la cellule "Aperçu" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
    protected function _add_contents_for_td_preview($record)
    {
        $dir_path = $this -> CI -> photoramas_diapos_model -> get_dir_path_for_thumbs();
        
        $img_path = is_file($dir_path.'/'.$record['filename']) ? $dir_path.'/'.$record['filename'] : 'none';

        return '<img class="photos" src="'.$img_path.'" />';
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie l'url du lien du document dans la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _build_href_for_td_description($record)
    {
		$base_href = (ADMR_IS_ADMIN) ? CHEMIN.'admin/'.ADMR_BASE_HREF_PLUGIN : ADMR_BASE_HREF_PLUGIN;

        return $base_href.'&ctrl=add_photos&galid='.$this -> _photorama_id.'&id='.$record['id'].'#ADMR_form_diapos';       
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Status" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_status($record)
	{
		return parent :: _add_contents_for_td_status($record);
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Commandes" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_commands($record)
	{        
        $item_id = $record['id'];        

        $view = '';

		// Création de la miniature
        $view .= Html_helper :: addA(
			$href = Url_helper :: build_uri(
                $params = array(
                    'galid' => $this -> _photorama_id,
                    'id' => $record['id'],
                    'idpg' => $this -> _params['idpg'],
                    'sort' => $this -> _params['sort']
                ),
                $basehref = Url_helper :: site_url(ADMR_CONTROLLER.'/rebuild_thumbnail')
            ),
			$contents = Html_helper :: addImg(
				$path = ADMR_IMG_PATH.'/rebuild.gif',
				$alt = ucfirst($this -> _lang['rebuild_thumbnail']),
				$attr = array(
					'title' => $alt,
					'border' => '0'
				)
			)
            .'&nbsp;&nbsp;',
			$attr = array('class' => 'waiting_process')
		);	
        
        return $view;
	}

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès au document par le rédacteur
     * 
	 * @access public
     * @return void
	 */
    protected function _is_doc_allowed($doc_id)
    {   
        if (empty($doc_id)) {
            return TRUE;
        }
        
        $authorization = $this -> _writer_rights['photos_photoramas_manage'];
      
        if ($authorization == '1') { // Toutes les galeries photos           
            return TRUE;
        }
        elseif ($authorization == '3') { // Uniquement les galeries photos du rédacteur           
            $doc = $this -> CI -> writer_docs_model -> get_by_id($doc_id);
            
            if (!empty($doc) && $doc['type'] == $this -> _doc_infos['type']) {
                return TRUE;
            }
        }
        elseif ($authorization == '2' && in_array($doc_id, $this -> _writer_rights['photos_photoramas_list_allowed'])) { // Uniquement les galeries photos sélectionnées
            return TRUE;
        }
          
        return FALSE;    
    }

	// ---------------------------------------------------------------------------- //
    
} // End of Class