<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

abstract class Manage_records_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_sort_options = array();	 // Options de tri
    protected $_form_validation = FALSE; // Validation ou non du formulaire
    //

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct()
    {        
        $this -> CI =& Controller :: get_instance();
        
        $this -> CI -> load_helper('var_helper');
        $this -> CI -> load_helper('html_helper');
        $this -> CI -> load_helper('url_helper');
        $this -> CI -> load_helper('security_helper');      
        
        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();
        $this -> _params = $this -> _set_params();
        $this -> _sort_options = $this -> _set_sort_options();       
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * renvoie les paramètres utilisés dans la page
     * 
     * @access public
	 * @return void
	 */	
    public function get_params()
    {
        return $this -> _params;	// Paramètres         
    }

	// --------------------------------------------------------------------

	/**
	 * renvoie les options de tri des données
     * 
     * @access public
	 * @return void
	 */	
    public function get_sort_options()
    {
        return $this -> _sort_options;	// Options de tri         
    }

	// --------------------------------------------------------------------
    
	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_sort_options()
    {
        return $this -> _sort_options = array('id_asc', 'id_desc', 'ch_asc', 'ch_desc', 'status_asc', 'status_desc');	// Options de tri         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        return $this -> _params = array(
            'sort'     => Var_helper :: import('sort', '', $this -> _config['sort_option_by_default'], array('trim'), array(array('Var_helper', 'is_in_array['.implode(',', $this -> _set_sort_options()).']'))),
            'idpg'     => Var_helper :: import('idpg', '', 1, array('trim'), array(array('Var_helper', 'is_digit'))),
        );
    }
    
	// --------------------------------------------------------------------

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        // Mise à jour des données des enregistrements postés
        if ($this -> _update_records()) {
            $this -> _form_validation = TRUE;
        };

        // Récupération des données
        $items = $this -> _get_records();
 
        // Filtrage des données récupérées
        $items = $this -> _filter_records($items);

        // Affichage de la page avec les données
        $this -> _build_view($items);
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/form-validator/jquery.form-validator.min.js"></script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/manage_records.js"></script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/search_records.js"></script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/waiting_process.js"></script>'."\n";

        $css = '<link type="text/css" rel="stylesheet" href="'.ADMR_CSS_PATH.'/manage_records.css" />';
        $css .= '<link type="text/css" rel="stylesheet" href="'.ADMR_CSS_PATH.'/waiting_process.css" />';
        $css .= '<link type="text/css" rel="stylesheet" href="'.ADMR_CSS_PATH.'/form_validator.css" />';

        return $css.$js;        
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _get_records()
    {
        return array();       
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _filter_records($records)
    {
        return $records;       
    }
    
	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements postés
     * 
     * @access protected
	 * @return void
	 */	
    protected function _update_records()
    {
        if ($this -> _check_security_for_update_records() === TRUE)
        {
            $action = Var_helper :: import('action', 'post', '');
            $records_ids = Var_helper :: import('ids', 'post', array());
            
            return !empty($records_ids) ? $this -> _update_records_by_action($records_ids, $action) : FALSE;
        }
               
        return FALSE;
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options du menu de sélection des actions pour la mise à jours des enregistrements sous la forme 
     * array(
     *    array('label' => '', 'value' => '', 'attrs' => array()),
     * )
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_select_actions_for_update_records()
    {
        return array(
/*            array('label' => ucfirst($this -> _lang['activate_records_selected']),        'value' => 'a'),
            array('label' => ucfirst($this -> _lang['inactivate_records_selected']),      'value' => 'i'),
            array('label' => ucfirst($this -> _lang['delete_records_selected']),          'value' => 'd', 'attrs' => array('title' => ucfirst($this -> _lang['action_removes_records_definitively']))),
*/        );
    }
    
	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements selon l'action sélectionnée
     * 
     * @access protected

     * @param string Identifiant de l'action à appliquer pour la mise à jour
	 * @return void
	 */
    protected function _update_records_by_action($records_ids, $action)
    {
/*        // (Dés)Activation des enregistrements
        if (in_array($action, array('a', 'i'))) {
            $this -> _activate_records_or_not($records_ids, $action);
        }
        // Suppression des enregistrements
        elseif ($action == 'd') { 
            $this -> _delete_records($records_ids);
        }
*/        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Vérifie la sécurité pour la mise à jour des données des enregistrements postés
     * 
     * @access protected
	 * @return boolean
	 */	
    private function _check_security_for_update_records()
    {
        $token_name = 'manage_records';
        $token_time_expire = $this -> _config['token_time_expire'];
        $referer = $this -> _get_current_url();

        if (empty($_POST) || Security_helper :: check_token($token_time_expire, $referer, $token_name) === FALSE) {
            return FALSE;
        }

        return TRUE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * retourne l'url complète de la page
     * 
     * @access public
	 * @return string Url complète de la page
	 */
    protected function _get_current_url()
    {
        if (ADMR_IS_ADMIN) {
            $current_url = ADMR_SITE_URL.'admin/'.ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER;    
        } else {
            $current_url = ADMR_SITE_URL.'plugins/'.ADMR_DIRNAME.'/'.ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER;           
        }
        
        return $current_url;     
    }

	// --------------------------------------------------------------------

    /*
     * Affiche ou renvoie le contenu de la vue
     *
     * @param array Données des enregistrements
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    protected function _build_view($records)
    {
        settype($records, 'array');
        
        $this -> CI -> load_library('pagination');

        /**
         * Initialisation des variables
         */
        $nb_records = count($records);	  // Nombre total d'enregitrements
        $nb_records_per_page = $this -> _config['nb_records_per_page']; // Nombre d'enregitrements maximum à afficher par page        
        $idpg = $this -> _valid_id_page($this -> _params['idpg'], $nb_records, $nb_records_per_page); // Id de la page affichée
        $records = array_slice($records, ($idpg - 1)*$nb_records_per_page, $nb_records_per_page, TRUE); // Sélection des enregistrements à afficher
        
        // Construction de la vue
        $data = array(
            'validation' => $this -> _form_validation,
            'message' => ($this -> _form_validation) ? $this -> _lang['msg_updating_success'] : $this -> _lang['msg_updating_fail'],
            'lang' => $this -> _lang,
            'form_data_filtering' => $this -> _build_form_data_filtering(),      
            'nb_records' => $nb_records,
            'nb_records_per_page' => $nb_records_per_page, 
            'form_uri' => $this -> _build_form_action_content(),
            'token' => Security_helper :: create_token('manage_records'),
            'idpg' => $idpg,
            'navbar' => $this -> CI -> pagination -> generate(
                array(
                    'class_name' => 'ADMR_navbar',
                    'url' => $this -> _build_navbar_href().'&amp;idpg=',
                    'total_items' => $nb_records,
                    'max_items_per_page' => $nb_records_per_page,
                    'current_page' => $idpg,
                    'anchor' => 'ADMR_manage_contents'
                )      
            ),
            'data_table' => $this -> _build_data_table($records, $idpg), // Grille de donnée
            'select_actions' => $this -> _set_select_actions_for_update_records(),   // Option du menu de sélection des actions pour la mise à jour des enregistrements
        );
        
        $this -> CI -> render_page($this -> _get_layout_for_manage_records_view(), $data);
    }    

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_manage_records_view()
    {
        $layout = 'manage_records_layout';           
        
        return $layout;    
    }

	// --------------------------------------------------------------------

	/**
	 * construit le formulaire de sélection des données
     * 
     * @access protected
	 * @return string
	 */	
    protected function _build_form_data_filtering()
    {
        return '';
    }

	// --------------------------------------------------------------------

	/**
	 * construit et retourne le contenu de l'attribut action du formulaire
     * 
     * @access protected
     * @param mixed Options du menu select
	 * @return void
	 */	
    protected function _build_form_action_content()
    {
        return Url_helper :: build_uri($this -> _get_params_except($this -> _params, array('idpg')));
    }

	// --------------------------------------------------------------------

	/**
	 * construit et retourne le lien des onglets de la barre de navigation
     * 
     * @access protected
     * @param mixed Options du menu select
	 * @return void
	 */	
    protected function _build_navbar_href()
    {
        return Url_helper :: build_uri($this -> _get_params_except($this -> _params, array('idpg')));
    }

	// --------------------------------------------------------------------

	/**
	 * corrige et retourne le contenu de la variable idpg (identifiant de la page)
     * 
     * @access protected
     * @param integer Identifiant de la page
     * @param integer Nombre d'enregistrements
     * @param integer Nombre denregistrements affichés par page
	 * @return void
	 */	
    private function _valid_id_page(&$idpg, $nb_records, $nb_records_per_page)
    {
		while ($nb_records > 0 && $nb_records <= ($idpg - 1) * $nb_records_per_page) {
			$idpg--;
		}

        return $idpg;
    }

	// --------------------------------------------------------------------

	/**
	 * construit le tableau de données
     * 
	 * @return string Tableau HTML contenant les enregistrements
	 * @access public
	 */	
    protected function _build_data_table($records)
    {		
		$this -> CI -> load_library('data_table');

        /**
         *  Définitions des attributs du tableau
         */        
        $this -> CI -> data_table -> set_table_attributes(
            array(
    			'id' => 'ADMR_DB_table',
    			'class' => 'tableDB',
    			'cellpadding' => 5,
    			'cellspacing' => 1,
    			'border' => 1,
    			'width' => '100%',
    			'align' => 'center',
    			'summary' => $this -> _lang['summary_data_table'],
            )
        );

        $this -> CI -> data_table -> set_thead_attributes(array('class' => 'forum'));
        //

        // Définitions des entêtes du tableau
        $this -> CI -> data_table -> set_headers($this -> _set_data_table_headers());

		/**
		 * Définitions des lignes du tableau
		 */
		foreach ($records as $record) {
            $class_row = (empty($class_row) || $class_row == 'quest')? 'rep' : 'quest';
            $record = array_merge($record, (array) $this -> _add_more_data_for_record($record));

            $this -> CI -> data_table -> add_row(
                $cells = $this -> _set_data_table_cells($record),
                $attrs = array('class' => $class_row)
			);
		}
		//

		return $this -> CI -> data_table -> generate();
    }

	// --------------------------------------------------------------------
  
	/**
	 * ajoute des données supplémentaires à l'enregistrement
     * 
	 * @access protected
     * @param array Tableau de données initiales de l'enregistrement
	 * @return array Tableau contenant les nouvelles données de l'enregistrement
	 */    
    protected function _add_more_data_for_record($record)
    {
        return array();
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
		$headers = array(
            'id' => $this -> _set_data_table_header_for_id(),
			'status' => $this -> _set_data_table_header_for_status(),
		);

        return $headers;
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne id de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne id
	 */    
    protected function _set_data_table_header_for_id()
    {
        return array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['id']), 'id'), 'attrs' => array('id' => 'rid', 'data-label' => ucfirst($this -> _lang['select_all_items'])));
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne Description de la table de données
     * 
	 * @access protected
     * @param string Intitulé de la colonne Description
	 * @return array Tableau contenant l'entêtes de la colonne Description
	 */    
    protected function _set_data_table_header_for_description($title)
    {
        $title = ucfirst($title);
        
        if (in_array('ch_asc', $this -> _sort_options)) {
            $title = $this -> _anchor_sort_records($title, 'ch');    
        }        
                
        return array('contents' => $title, 'attrs' => array('id' => 'rdesc'));
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne Etat de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne status
	 */    
    protected function _set_data_table_header_for_state()
    {
		return array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['state']), 'up'),   'attrs' => array('id' => 'rstate'));
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne status de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne status
	 */    
    protected function _set_data_table_header_for_status()
    {
		return array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['status']), 'status'), 'attrs' => array('id' => 'rstatus'));
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne Commandes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne Commandes
	 */    
    protected function _set_data_table_header_for_commands()
    {
        return array('contents' => ucfirst($this -> _lang['commands']), 'attrs' => array('id' => 'rcommands'));
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {
    	$cells = array(
            'id' => $this -> _set_data_table_cell_for_id($record),
            'status' => $this -> _set_data_table_cell_for_status($record),
    	);
        
        return $cells;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Id" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Id" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
    protected function _set_data_table_cell_for_id($record)
    {
        return array('contents' => $this -> _add_contents_for_td_id($record), 'attrs' => array('align' => 'left'));
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Status" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Status" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
    protected function _set_data_table_cell_for_status($record)
    {
        return array('contents' => $this -> _add_contents_for_td_status($record), 'attrs' => array('align' => 'center'));
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Description" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Description" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
    protected function _set_data_table_cell_for_description($record)
    {
        return array('contents' => $this -> _add_contents_for_td_description($record), 'attrs' => array('align' => 'left'));
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Etat" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Status" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
    protected function _set_data_table_cell_for_state($record)
    {
        return array('contents' => $this -> _add_contents_for_td_state($record), 'attrs' => array('align' => 'center'));
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Commands" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Commands" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
    protected function _set_data_table_cell_for_commands($record)
    {
        return array('contents' => $this -> _add_contents_for_td_commands($record), 'attrs' => array('align' => 'center'));
    }

	// --------------------------------------------------------------------

	/**
	 * Définit et renvoie le contenu de la cellule "Id" du tableau de données
     * 
	 * @access private
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_id($record)
	{
		$id = $record['id'];
        $actions = $this -> _set_select_actions_for_update_records();
        $view = '';
        
        if (! empty($actions)) {
            $view .= Html_helper :: addInput(
                $type = 'checkbox',
                $name = 'ids[]',
                $value = $id,
                $attr = array('id' => 'record'.$id,'title' => ucfirst($this -> _lang['select_record']))
    		);
            $view .= '&nbsp;';
            $view .= Html_helper :: addLabel(
                $content = $id,
                $attr = array('for' => 'record'.$id)
    		);	
        } else {
            $view .= $id;
        }
        
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Status" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_status($record)
	{
        $status = $record['status'];
		
		if ($status == 'a') { // Status activé
			$view = Html_helper :: addImg(
				$path = ADMR_IMG_ACTIVE,
				$alt = ucfirst($this -> _lang['activated']),
				$attr = array('title' => $alt)
			);
			
  		} elseif ($status == 'i') { // Status désactivé
			$view = Html_helper :: addImg(
				$path = ADMR_IMG_INACTIVE,
				$alt = ucfirst($this -> _lang['desactivated']),
				$attr = array('title' => $alt)
			);

  		} elseif ($status == 'd') { // Status supprimé
			$view = Html_helper :: addImg(
				$path = ADMR_IMG_DELETE,
				$alt = ucfirst($this -> _lang['deleted']),
				$attr = array('title' => $alt)
			);
            
    	} else {
    		$view = 'ERROR';
  		}
				
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu à la cellule "Description" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_description($record)
	{
        $view = Html_helper :: addA(
				$href = $this -> _build_href_for_td_description($record),
				$contents = Html_helper :: addImg(
					$path = ADMR_IMG_EDIT,
					$alt = $this -> _lang['edit'],
					$attr = array('title' => $alt, 'border' => '0')
				)
				.'&nbsp;'.$this -> _get_text_for_td_description($record),
				$attr = array('title' => $alt)
		);	
        
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "State" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_state($record)
	{
		$mode = $record['mode'];
        
        if ($mode == 2) { // Mise à jour
            $view = '&nbsp;'.Html_helper :: addImg(
    			$path = ADMR_IMG_UPDATE,
    			$alt = ucfirst($this -> _lang['update']),
    			$attr = array('title' => $alt, 'border' => '0')
    		);		  

		} elseif ($mode == 1) { // Nouveauté   
            $view = '&nbsp;'.Html_helper :: addImg(
    			$path = ADMR_IMG_NEW,
    			$alt = ucfirst($this -> _lang['new']),
    			$attr = array('title' => $alt, 'border' => '0')
    		);
		} else {
            $view = '&nbsp;'.Html_helper :: addImg(
    			$path = ADMR_IMG_APPROVED,
    			$alt = ucfirst($this -> _lang['approved']),
    			$attr = array('title' => $alt, 'border' => '0')
    		);
		}
        
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie l'url du lien du document dans la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _build_href_for_td_description($record)
    {
        return 'TODO';       
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie le texte de la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
    protected function _get_text_for_td_description($record)
    {
        return 'TODO';       
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Commandes" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_commands($record)
	{
		return '';
	}

	// ---------------------------------------------------------------------------- //

	/**
	 * Construit et retourne un lien pour le tri des enregistrements
	 *
	 * @access protected
	 * @params string $text Texte du lien
	 * @params string $sort_basename Nom de base de l'item de tri (optionnel)
	 * @return string Tableau html contenant le lien de tri
	 */
    protected function _anchor_sort_records($text, $sort_basename = '')
    {        
        if (empty($sort_basename)) {
            $sort_basename = strtolower($text);
        }

        $sort_item = ($this -> _params['sort'] == $sort_basename.'_asc') ? $sort_basename.'_desc' : $sort_basename.'_asc';        
        $img_src = ($this -> _params['sort'] == $sort_basename.'_asc') ? ADMR_IMG_SORT_DESC : ADMR_IMG_SORT_ASC;

        $title = sprintf($this -> _lang['sort_records_by_%s'], $this -> _lang[$sort_item]);
        
        return Html_helper :: addA(
            $path = Url_helper :: build_uri($this -> _get_params_except($this -> _params, array('sort'))).'&sort='.$sort_item,
            $contents = $text.'&nbsp;'.Html_helper :: addImg($img_src, $title),
            $attrs = array('title' => $title)
        );
    }

	// ---------------------------------------------------------------------------- //

	/**
	 * retourne les paramètres avec leur valeur à l'exception des paramètres indésirables
     * 
     * @access protected
     * @param array Tableau contenant l'ensemble des paramètres
     * @param array Tableau contenant les noms/clés des paramètres à supprimer
	 * @return void
	 */	
    private function _get_params_except($params, $unset = array())
    {
        settype($params, 'array');
        settype($unset, 'array');
        
        if (!empty($unset)) {
            foreach($params as $name => $value) {
                if (in_array($name, $unset)) {
                    unset($params[$name]);
                }
            }
        }
        
        return $params;
    }

	// --------------------------------------------------------------------

} //End of Class