<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/manage_records_helper.php';

class Manage_writers_docs_helper extends Manage_records_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();         // Données de langue
    protected $_config = array();       // Données de configuration
    protected $_params = array();       // Données récupérés par post ou get
    protected $_sort_options = array();	// Options de tri
    protected $_writer_rights = array(); // Droits du rédacteur
    //

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct($writer_rights)
    {        
        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);

        parent :: __construct();
        
        $this -> CI -> load_library('writers_managed', $this -> _writer_rights['id']);
      
        /**
         * Controle de sécurité
         */
        if (! ADMR_IS_ADMIN && ! $this -> _is_doc_allowed()) {
            Url_helper :: redirect('display_error&type=disallowed');
        }
        //
        
        $this -> CI -> load_model('writer_model');
        $this -> CI -> load_model('guppy_doc_model');
        $this -> CI -> load_model('writer_docs_model', array('id' => $this -> _params['writerid']));
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_writer_rights($writer_rights)
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;	// Droits du rédacteur         
    }

	// --------------------------------------------------------------------
    
	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_sort_options()
    {
        return $this -> _sort_options = array('id_asc', 'id_desc', 'type_asc', 'type_desc', 'status_asc', 'status_desc', 'up_asc', 'up_desc');	// Options de tri         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        $this -> _params = array_merge(
            parent :: _set_params(),
            array(
//                'groupid'  => trim(Var_helper :: import('groupid', '', NULL, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
                'writerid' => trim(Var_helper :: import('writerid', '', 0, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
                'doctype'  => trim(Var_helper :: import('doctype',  '', NULL, array('trim'), array(array('Var_helper', 'is_alpha_num_dash'))), '-'),
                'docid'    => trim(Var_helper :: import('docid',    '', 0, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
//                'filter' => Var_helper :: import('filter', 'post', 0, array(), array(array('Var_helper', 'is_digit'))),
            )
        );
       
        return $this -> _params;
    }
    
	// --------------------------------------------------------------------

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        parent :: manage();
    }

	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        $filter = Var_helper :: import('filter', 'post', 0, array(), array(array('Var_helper', 'is_digit')));
        $writer_id = ($filter == '1') ? Var_helper :: import('writerid1', 'post', '') : Var_helper :: import('writerid2', 'post', '');
        $doctypes = Var_helper :: import('doctypes', 'post', array());
        $uri = str_replace('/search', '', ADMR_CONTROLLER);
        
        if ($filter == '1') {
            $uri .= '/synchronize'; // Synchronization des documents du rédacteur géré
        }
         
        if (!empty($writer_id)) {
            $uri .= '&writerid='.$writer_id;
        }

		/**
		 * Sélection des documents par leurs types
		 */    
        if ($filter == '2' && !empty($writer_id) && !empty($doctypes)) {
            $uri .= is_array($doctypes) ? '&doctype='.implode('-', $doctypes) : '';         
        }
        		
		Url_helper :: redirect($uri);
    }

	// --------------------------------------------------------------------

	/**
	 * synchronize les données des documents enregistrées pour le rédacteur avec ceux enregistrés dans guppy
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    public function synchronize()
    {
        $this -> CI -> load_model('guppy_docid_model');
        
        $this -> CI -> writer_docs_model -> synchronize($this -> CI -> guppy_docid_model); // Synchronisation des enregistrements du rédacteur avec ceux de guppy
       
        $uri = Url_helper :: build_uri(
            $params = array('writerid' => $this -> _params['writerid'], 'doctype' => $this -> _params['doctype']),
            $basehref = str_replace('/synchronize', '', ADMR_CONTROLLER)
        );
              
        Url_helper :: redirect($uri);
    }
    
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        $title = ucfirst($this -> _lang['manage_writers_docs']);
        
        if (!empty($this -> _params['writerid'])) {
            $writer = $this -> CI -> writer_model -> get_by_id($this -> _params['writerid']);
            
            if (!empty($writer)) {
                $title = ucfirst(sprintf($this -> _lang['manage_docs_created_by_writer_%s'], $writer['name']));     
            }      
        }
        
        return $title;       
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_infos_page_content()
    {		
        return $this -> _lang['infos_page_manage_writers_docs'];
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
     * @access public
     * @return string menu de la page
	 */	
    public function set_menu_plugin_items()
    {		
        $this -> CI -> load_helper('plugin_menu_for_writers_helper');
        
        if (ADMR_IS_ADMIN) {
            return Plugin_menu_helper :: set_admin_menu_items($this -> _lang, $this -> _config);    
        } else {
            return $this -> CI -> plugin_menu_for_writers_helper -> set_public_items('writers', $this -> _lang, $this -> _config, $this -> _writer_rights);         
        }  
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _get_records()
    {
        $doc_types = empty($this -> _params['doctype']) ? array() : explode('-', $this -> _params['doctype']);
        $doc_ids = empty($this -> _params['docid']) ? array() : explode('-', $this -> _params['docid']);
      
        $records = $this -> CI -> writers_managed -> get_writer_docs($this -> CI -> writer_docs_model, array('type' => $doc_types, 'id' => $doc_ids), $this -> _params['sort']); // Récupération et tri des enregistrements autorisés

        return $records;       
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
/*    protected function _filter_records($records)
    {
        return $records;       
    }
*/    
	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements postés
     * 
     * @access protected
	 * @return void
	 */	
	/**
	 * Met à jour des données des enregistrements postés
     * 
     * @access public
	 * @return string code html
	 */	
    protected function _update_records()
    {
        return parent :: _update_records();
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options du menu de sélection des actions pour la mise à jours des enregistrements sous la forme 
     * array(
     *    array('label' => '', 'value' => '', 'attrs' => array()),
     * )
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_select_actions_for_update_records()
    {
        $actions = array();
  
        // (Dés)activation
        if (!empty($this -> _writer_rights['writers_docs_act'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['activate_docs_selected']),   'value' => 'a');
            $actions[] = array('label' => ucfirst($this -> _lang['inactivate_docs_selected']), 'value' => 'i');
        }
        
        // Suppression
        if (!empty($this -> _writer_rights['writers_docs_del'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['delete_docs_selected']), 'value' => 'd', 'attrs' => array('title' => ucfirst($this -> _lang['action_removes_docs_definitively'])));
        }

        // Validation
        $actions[] = array('label' => ucfirst($this -> _lang['validate_docs_selected']), 'value' => 'v');

        return $actions;
    }

	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements selon l'action sélectionnée
     * 
     * @access protected

     * @param string Identifiant de l'action à appliquer pour la mise à jour
	 * @return void
	 */
    protected function _update_records_by_action($records_ids, $action)
    {
        $records_ids = $this -> _check_records_ids($records_ids); // Vérification des enregistrements à traiter (sécurité)
      
        // (Dés)Activation
        if (in_array($action, array('a', 'i'))) {
            return $this -> _activate_records_or_not($records_ids, $action);
        }
        // Suppression
        elseif ($action == 'd') { 
            return $this -> _delete_records($records_ids);
        }
        // Validation
        elseif ($action == 'v') {
            return $this -> _validate_records($records_ids);
        }

        return FALSE;
    }

	// --------------------------------------------------------------------

	/**
	 * vérifie et renvoie uniquement les ids autorisées des enregistrements
     * 
     * @access private
     * @param array Tableau contenant les ids des enregistrements à vérifier
	 * @return array Tableau contenant les ids des enregistrements validés
	 */	
    private function _check_records_ids($records_ids)
    {
        $this -> CI -> load_helper('array_helper');
        
        $records_ids_allowed = Array_helper :: array_column($this -> _get_records(), 'id');
        
        return array_intersect($records_ids, $records_ids_allowed);
    }
    
	// --------------------------------------------------------------------

	/**
	 * Active ou désactive les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
     * @param string action à appliquer (a = activation et i = désactivation)
	 * @return void
	 */
    protected function _activate_records_or_not($records_ids, $action)
    {
        if (!empty($this -> _writer_rights['writers_docs_act'])) {
            $this -> CI -> writer_docs_model -> update_status_by_id($records_ids, $action);
            $this -> CI -> guppy_doc_model -> update_status_by_id($records_ids, $action);
            
            return TRUE;
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return void
	 */
    protected function _delete_records($records_ids)
    {
        if (!empty($this -> _writer_rights['writers_docs_del'])) {
            $this -> CI -> writer_docs_model -> delete_by_id($records_ids);
            $this -> CI -> guppy_doc_model -> update_status_by_id($records_ids, 'd');
            
            return TRUE;
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Valide les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return void
	 */
    protected function _validate_records($records_ids)
    {
        return $this -> CI -> writer_docs_model -> update_mode_by_id($records_ids, 0);
    }

	// --------------------------------------------------------------------

    /*
     * Affiche ou renvoie le contenu de la vue
     *
     * @param array Données des enregistrements
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    protected function _build_view($records)
    {
        return parent :: _build_view($records);
    }    

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_manage_records_view()
    {
        return parent :: _get_layout_for_manage_records_view();    
    }

	// --------------------------------------------------------------------

	/**
	 * construit le formulaire de sélection des données
     * 
     * @access protected
	 * @return string
	 */	
    protected function _build_form_data_filtering()
    {
        $data = array(
            'lang' => $this -> _lang,
            'form_uri' => Url_helper :: build_uri().'/search',
            'writers' => $this -> _get_writers(),
            'writer_id' => $this -> _params['writerid'],
            'docs' => $this -> _get_docs_types(),
            'doctype' => !empty($this -> _params['doctype']) ? explode('-', $this -> _params['doctype']) : array(),
            'sort' => $this -> _params['sort'],
        );
        
        return $this -> CI -> render('fragments/form_writers_docs_filtering', $data, TRUE);               
    }

	// --------------------------------------------------------------------

	/**
	 * récupère la liste des rédacteurs
     * 
     * @access protected
	 * @return array Tableau contenant la liste des rédacteurs
	 */
    protected function _get_writers()
    {
        return $this -> CI -> writers_managed -> get_writers_managed(array(), 'ch_asc');
    }

	// --------------------------------------------------------------------

	/**
	 * récupère les différents types de documents (articles, news, ...)
     * 
     * @access protected
	 * @return array Tableau contenant les différents types de documents (articles, news, ...)
     *               sous la forme array('ar' => array(name => 'articles', 'type' => 'ar'),
     *                                   'ne' => array(name => 'news', 'type' => 'ne'),
     *                                   ...)
	 */
    protected function _get_docs_types()
    {
        return $this -> CI -> writers_managed -> get_doc_types_allowed();
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $parent = parent :: set_header_addons();

        $js = '<script type="text/javascript" src="'.ADMR_JS_PATH.'/toggle_records_selection_display_for_management.js"></script>'."\n";
        
        $css = '';
                
        return $parent.$css.$js;
    }

	// --------------------------------------------------------------------

	/**
	 * construit le tableau de données
     * 
	 * @return string Tableau HTML contenant les enregistrements
	 * @access public
	 */	
    protected function _build_data_table($records)
    {		
        return parent :: _build_data_table($records);        
    }
  
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
		$headers = array(
            parent :: _set_data_table_header_for_id(),
            array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['type']), 'type'), 'attrs' => array('id' => 'rtype')),
            parent :: _set_data_table_header_for_description($this -> _lang['title']),
			parent :: _set_data_table_header_for_state(),
            parent :: _set_data_table_header_for_status(),
		);

        return $headers;
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne Type de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne "type"
	 */    
/*    protected function _set_data_table_header_for_type()
    {
        return array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['type']), 'type'), 'attrs' => array('id' => 'r_type'));
    }
*/   
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne status de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne status
	 */    
/*    protected function _set_data_table_header_for_status()
    {
		return array('contents' => $this -> _anchor_sort_records(ucfirst($this -> _lang['status']), 'status'), 'attrs' => array('id' => 'rstatus'));
    }
 */   
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne Description de la table de données
     * 
	 * @access protected
     * @param string Intitulé de la colonne Description
	 * @return array Tableau contenant l'entêtes de la colonne Description
	 */    
 /*   protected function _set_data_table_header_for_description($label)
    {
        return array('contents' => $this -> _anchor_sort_records(ucfirst($label), 'ch'), 'attrs' => array('id' => 'rdesc'));
    }
  */  
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne Commandes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne Commandes
	 */    
/*    protected function _set_data_table_header_for_commands()
    {
        return array('contents' => ucfirst($this -> _lang['commands']), 'attrs' => array('id' => 'rcommands'));
    }
*/
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {
    	$cells = array(
            parent :: _set_data_table_cell_for_id($record),
			array('contents' => $this -> _add_contents_for_td_type($record), 'attrs' => array('align' => 'center')),
			parent :: _set_data_table_cell_for_description($record),
            parent :: _set_data_table_cell_for_state($record),
            parent :: _set_data_table_cell_for_status($record),
    	);
        
        return $cells;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Id" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Id" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
/*    protected function _set_data_table_cell_for_id($record)
    {
        return array('contents' => $this -> _add_contents_for_td_id($record), 'attrs' => array('align' => 'left'));
        //return array('contents' => $this -> _add_contents_of_table_cell_for_id($record), 'attrs' => array('align' => 'left'));
    }
*/
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Status" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Status" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
 /*   protected function _set_data_table_cell_for_status($record)
    {
        return array('contents' => $this -> _add_contents_for_td_status($record), 'attrs' => array('align' => 'center'));
    }
*/

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Description" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Description" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
 /*   protected function _set_data_table_cell_for_description($record)
    {
        return array('contents' => $this -> _add_contents_for_td_description($record), 'attrs' => array('align' => 'left'));
    }
*/

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Commands" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Commands" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
/*    protected function _set_data_table_cell_for_commands($record)
    {
        return array('contents' => $this -> _add_contents_for_td_commands($record), 'attrs' => array('align' => 'center'));
    }
*/
	// --------------------------------------------------------------------

	/**
	 * Définit et renvoie le contenu de la cellule "Id" du tableau de données
     * 
	 * @access private
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
/*	protected function _add_contents_for_td_id($record)
	{
		$id = $record['id'];
        $actions = $this -> _set_select_actions_for_update_records();
        $view = '';
        
        if (! empty($actions)) {
            $view .= Html_helper :: addInput(
                $type = 'checkbox',
                $name = 'ids[]',
                $value = $id,
                $attr = array('id' => 'record'.$id,'title' => ucfirst($this -> _lang['select_record']))
    		);
            $view .= '&nbsp;';
            $view .= Html_helper :: addLabel(
                $content = $id,
                $attr = array('for' => 'record'.$id)
    		);	
        } else {
            $view .= $id;
        }
        
		return $view;
	}
*/
	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Status" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
/*	protected function _add_contents_for_td_status($record)
	{
		global $admin;
		
        $status = $record['status'];
		
		if ($status == 'a') { // Status activé
			$view = Html_helper :: addImg(
				$path = ADMR_IMG_ACTIVE,
				$alt = $admin[765],
				$attr = array('title' => $alt)
			);
			
  		} elseif ($status == 'i') { // Status désactivé
			$view = Html_helper :: addImg(
				$path = ADMR_IMG_INACTIVE,
				$alt = $admin[766],
				$attr = array('title' => $alt)
			);
            
    	} else {
    		$view = 'ERROR';
  		}
				
		return $view;
	}
*/
	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule intitulée "Type"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_type($record)
	{
		$type = $record['type'];
        $doc_types = $this -> _get_docs_types();
       
        $label_type = $this -> _lang[$doc_types[$type]['name']];

        $view = '&nbsp;'.$label_type;	
		
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "State" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
/*	protected function _add_contents_for_td_state($record)
	{
		$mode = $record['mode'];
        
        if ($mode == 2) { // Mise à jour
            $view = '&nbsp;'.Html_helper :: addImg(
    			$path = ADMR_IMG_UPDATE,
    			$alt = ucfirst($this -> _lang['update']),
    			$attr = array('title' => $alt, 'border' => '0')
    		);		  

		} elseif ($mode == 1) { // Nouveauté   
            $view = '&nbsp;'.Html_helper :: addImg(
    			$path = ADMR_IMG_NEW,
    			$alt = ucfirst($this -> _lang['new']),
    			$attr = array('title' => $alt, 'border' => '0')
    		);
		} else {
            $view = '&nbsp;'.Html_helper :: addImg(
    			$path = ADMR_IMG_APPROVED,
    			$alt = ucfirst($this -> _lang['approved']),
    			$attr = array('title' => $alt, 'border' => '0')
    		);
		}
        
		return $view;
	}*/

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu à la cellule "Description" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_description($record)
	{
        if (!empty($this -> _writer_rights['writers_docs_edit'])) {
            $view = Html_helper :: addA(
    				$href = $this -> _build_href_for_td_description($record),
    				$contents = Html_helper :: addImg(
    					$path = ADMR_IMG_EDIT,
    					$alt = $this -> _lang['edit'],
    					$attr = array('title' => $alt, 'border' => '0')
    				)
    				.'&nbsp;'.$this -> _get_record_description($record),
    				$attr = array('title' => $alt)
    		);	
        } else {
            $view = $this -> _get_record_description($record);
        }
        
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie l'url du lien du document dans la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _build_href_for_td_description($record)
    {
		$params = $this -> _params;
        
        if (ADMR_IS_ADMIN) { // Coté admin
            $base_path = str_replace('/admin', '/edit_writer_doc', ADMR_BASE_HREF_PLUGIN);
            $query = '&writerid='.$params['writerid'].'&type='.$record['type'].'&sort='.$params['sort'].'&form=2&idpg='.$params['idpg'].'&id='.$record['id'];
            
            $href = CHEMIN.'admin/'.$base_path.$query;       
        }
        else { // Coté public
            $doc_infos = Model :: get_doc_infos_by_type($record['type']);      
    
            $href = Url_helper :: build_uri(
                $params = array_merge($this -> _params, array('id' => $record['id'])),
                $basehref = ADMR_BASE_HREF_PLUGIN.'&amp;ctrl=add_writers_'.$doc_infos['name']
            );
            
        }

        return $href;       
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie le contenu de la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
     * @param object Modèle de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
    protected function _get_record_description($record)
    {
        $doctype = $this -> CI -> writer_docs_model -> get_doc_types($record['type']);      

        $this -> CI -> load_model($doctype['name'].'_model'); // Model du type de document    
        
        $params = $this -> CI -> {$doctype['name'].'_model'} -> read($record['id']);
        $description = $this -> CI -> {$doctype['name'].'_model'} -> set_doc_heading($params);
        
        return $description;       
    }

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès au document par le rédacteur
     * 
	 * @access private
     * @return void
	 */
    private function _is_doc_allowed()
    {   
        if (empty($this -> _writer_rights['writers_manage']) || empty($this -> _writer_rights['writers_docs_manage'])) { // Droits de gestion non autorisés
            return FALSE;
        }
        
        if (!empty($this -> _params['writerid']) && !$this -> CI -> writers_managed -> is_writer_managed($this -> _params['writerid'])) { // Rédacteur non géré
            return FALSE;
        }       
        
        return TRUE;    
    }

	// ---------------------------------------------------------------------------- //

} // End of Class