<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Page_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array(); // Données de langue
    private $_page_layout = ''; // Nom du layout de la page
    protected $_infos_page_content = ''; // contenu des informations qui sont affichées dans le bandeau en haut de la page
    protected $_menu_plugin_items = array(); // Tableau contenant les items du menu qui sont affichés dans le bandeau en haut de la page    
    protected $_infos_plugin = array(); // contenu des informations du plugin qui sont affichées en bas de la page
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct()
    {
        $this -> CI =& Controller :: get_instance();

        $this -> _lang = $this -> CI -> get_lang();
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    /**
     * Affiche ou renvoie le contenu de la page
     *
     * @param string Nom du fichier de la vue
     * @param array Données à faire passer à la vue
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    public function render_page($filename, $data = array(), $return = FALSE)
    {
        $this -> CI -> set_layout($this -> _page_layout);
        
        // Déclaration des données de la page
    	$layout_data = array(
            'infos_page' => array(
                'heading' => ucfirst($this -> _lang['heading_infos_page']),
                'content' => $this -> _infos_page_content,
            ),						
            'menu_plugin' => array(
                'heading' => ucfirst($this -> _lang['heading_menu_plugin']),
                'items' => $this -> _menu_plugin_items,
            ),
            'infos_plugin' => $this -> _infos_plugin,
    	);
    	
        $data = array_merge($layout_data, (array) $data);

    	// Affiche la page
    	$this -> CI -> render($filename, $data, $return);
    }

	// --------------------------------------------------------------------

    /**
     * Définit le fichier qui va servir de gabarit à la page
     *
     * @return string Nom du fichier qui va servir de gabarit
     */
    public function set_page_layout($layout)
    {
        return $this -> _page_layout = $layout;
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu des informations qui sont affichés dans le bandeau en haut de la page
     *
     * @return string Contenu html des informations (vide par défaut)
     */
    public function set_infos_page_content($infos_page_content)
    {
        return $this -> _infos_page_content = $infos_page_content;
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items($menu_plugin_items)
    {
        settype($menu_plugin_items, 'array');
        
        return $this -> _menu_plugin_items = $menu_plugin_items;  
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les infos du plugin (vide par défaut)
     */
    public function set_infos_plugin($infos_plugin)
    {
        settype($infos_plugin, 'array');
       
        return $this -> _infos_plugin = array(
                'version' => empty($infos_plugin['version']) ? sprintf($this -> _lang['infos_plugin_version_%s'], ADMR_PLUGIN_VERSION) : $infos_plugin['version'],
                'website' => empty($infos_plugin['website']) ? 'http://lebrikabrak.info/index.php' : $infos_plugin['website'],
                'licence' => empty($infos_plugin['licence']) ? $this -> _lang['infos_plugin_licence'] : $infos_plugin['licence'],        
        ); 
    }

	// --------------------------------------------------------------------

} // End of class