<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Params_rules_helper
{	

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation du paramètre group
     * 
     * @access protected
	 * @param array Tableau contenant les messages d'erreur
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public static function set_params_group_rules($lang)
    {
        return array(
            'group' => array(
                array(
                    'rules' => array(array('Params_rules_helper', 'is_valid_group_name')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['name_must_contain_only_alphanumerics_or_dashes'], ENT_QUOTES, 'UTF-8')
                ),
            ),
        );        
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si le nom du groupe privé est valide ou non
     * 
     * @access protected
	 * @param string Nom du groupe privé
	 * @return boolean
	 */
    public static function is_valid_group_name($name)
    {
        if(empty($name)) {
           return TRUE;
        }

        return Var_helper :: is_alpha_num_dash($name);
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres website1 et website2
     * 
     * @access protected
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public static function set_params_website_rules($lang, $config)
    {
        foreach(array('website1', 'website2') as $website) {
            $rules[$website] = array(       // url
                array(
                    'rules' => array(array('Var_helper', 'is_required')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['url_required'], ENT_QUOTES, 'UTF-8')
                ),
                array(
                    'rules' => array(array('Var_helper', 'is_url')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['url_not_valid'], ENT_QUOTES, 'UTF-8')
                ),
             /*   array(
                    'rules' => array(array('Var_helper', 'is_valid_website_address')),
                    'msg' => 'l\'adresse du site web n\'existe pas.'
                ),*/
            );
        }
        
        return $rules;
     }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation du paramètre icon
     * 
     * @access protected
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public static function set_params_icon_rules($lang, $config)
    {
        return array(
            'icon' => array(
                array(
                    'rules' => array(array('Params_rules_helper', 'is_valid_img_path')),
                    'msg' => sprintf(htmlspecialchars($lang['form_errors_msg']['only_this_image_directories_%s_are_allowed'], ENT_QUOTES, 'UTF-8'), 'img'),
                ),
                array(
                    'rules' => array(array('Params_rules_helper', 'is_image')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['image_not_valid'], ENT_QUOTES, 'UTF-8')
                ),
                array(
                    'rules' => array(array('Params_rules_helper', 'is_allowed_ext['.implode(',', $config['file_manager']['access']['icon']['allowed_ext']).']')),
                    'msg' => sprintf(htmlspecialchars($lang['form_errors_msg']['only_this_image_extensions_%s_are_allowed'], ENT_QUOTES, 'UTF-8'), implode(',', $config['file_manager']['access']['icon']['allowed_ext'])),
                ),
            ),
        );        
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si c'est bien une image ou non
     * 
     * @access protected
	 * @param string chemin du fichier à vérifier
	 * @return boolean
	 */
    public static function is_image($path)
    {
        if (empty($path)) {
            return TRUE;
        }
        
        return Var_helper :: is_image($path);
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si le chemin de l'image est valide ou non
     * 
     * @access protected
	 * @param string chemin de l'image à valider
     * @param string chemin du répertoire contenant l'image
	 * @return boolean
	 */
    public static function is_valid_img_path($path, $dir = 'img')
    {
        if (empty($path)) {
            return TRUE;
        }
        
        return Var_helper :: is_in_directories($path, $dir);
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si l'extension du fichier est autorisée ou non
     * 
     * @access protected
	 * @param string Chemin du fichier
     * @param string Chaine avec les extensions autorisées séparées par une virgule ext1,ext2,...
	 * @return boolean
	 */
    public static function is_allowed_ext($path, $ext)
    {
        if (empty($path)) {
            return TRUE;
        }
        
        return Var_helper :: is_allowed_ext($path, $ext);
    }
     
	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation du paramètre status
     * 
     * @access protected
	 * @param array Tableau contenant les messages d'erreur
     * @param array Tableau contenant les valeurs possibles du status
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public static function set_params_status_rules($lang, $status = array('a', 'i'))
    {
        settype($status, 'array');
        
        return array(
            'status' => array(       // Status
                array(
                    'rules' => array(array('Var_helper', 'is_in_array['.implode(',', $status).']')),
                    'msg' => $lang['form_errors_msg']['status_not_valid']
                )
            ),
        );        
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres de date de publication
     * 
     * @access protected
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */    
    public static function set_params_pubdates_rules($params, $lang)
    {
        return array(
            'pubdate0' => array(       // Date de début de publication
                array(
                    'rules' => array(array('Var_helper', 'is_required')),
                    'msg' => $lang['form_errors_msg']['pubdate_required']
                ),
                array(
                    'rules' => array(array('Params_rules_helper', 'is_valid_format_pubdate')),
                    'msg' => $lang['form_errors_msg']['pubdate_format_not_valid']
                ),
                array(
                    'rules' => array(array('Params_rules_helper', 'is_valid_pubdate')),
                    'msg' => $lang['form_errors_msg']['pubdate_not_exist']
                ),
            ),

            'pubhour0' => array(       // Heure de début de publication
                array(
                    'rules' => array(array('Var_helper', 'is_required')),
                    'msg' => $lang['form_errors_msg']['pubhour_required']
                ),
            ),

            'pubminute0' => array(       // Minutes de début de publication
                array(
                    'rules' => array(array('Var_helper', 'is_required')),
                    'msg' => $lang['form_errors_msg']['pubminutes_required']
                ),
            ),

            'pubdate1' => array(       // Date de fin de publication
                array(
                    'rules' => array(array('Params_rules_helper', 'is_valid_format_pubdate')),
                    'msg' => $lang['form_errors_msg']['pubdate_format_not_valid']
                ),
                array(
                    'rules' => array(array('Params_rules_helper', 'is_valid_pubdate')),
                    'msg' => $lang['form_errors_msg']['pubdate_not_exist']
                ),
                array(
                    'rules' => array(array('Params_rules_helper', 'is_more_recent_pubdate['.$params['pubdate0'].','.$params['pubhour1'].','.$params['pubhour0'].','.$params['pubminute1'].','.$params['pubminute0'].']')),
                    'msg' => $lang['form_errors_msg']['pubdate_end_less_recent_than_begin']
                ),
            )
        );        
    }


	// --------------------------------------------------------------------

	/**
	 * Vérifie la validité du format de la date de publication
	 *
	 * @access	protected
	 * @param	string date à vérifier sous la forme AAAA/MM/JJ
	 * @return	bool
	 */
    public static function is_valid_format_pubdate($str)
    {    
        if ($str == '') {
            return TRUE;    
        }
        
        return Var_helper :: is_valid_format_date($str);
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie si la date de publication existe
	 *
	 * @access	protected
	 * @param	string date écrite sous la forme AAAA/MM/JJ
	 * @return	bool
	 */
    public static function is_valid_pubdate($str)
    {
        if ($str == '') {
            return TRUE;    
        }
        
        return Var_helper :: is_date($str);   
    }
        
	// --------------------------------------------------------------------

    /**
	 * Vérifie que la date de fin de publication est plus récente que
     * la date de début de publication d'un document
     * 
	 * @access protected
     * @param string Date de fin de publication au format AAAA/MM/JJ
     * @param string Paramètres stockés sous la forme "$date0,$hour1,$hour0,$minutes1,$minutes0"
     * @return boolean Résultat de la vérification
	 */
    public static function is_more_recent_pubdate($date1, $params = '')
    {
        if (empty($date1)) {
            return TRUE;
        }

        if (!empty($params) && strpos($params, ',') !== FALSE) {    // Paramètres stockés dans le deuxième argument
            $times = explode(',', $params);
            $nb_params = count($times);
            
            if ($nb_params === 1) {
                list($date0) = $times;   // date0   
            } elseif($nb_params === 3) {
                list($date0, $hour1, $hour0) = $times; // date0,hour1,hour0
            } elseif($nb_params === 5) {
                list($date0, $hour1, $hour0, $minutes1, $minutes0) = $times; // date0,hour1,hour0,minutes1,minutes0
            }
        }

        // Initialisation
        $date0 = empty($date0) ? date('Y/m/d') : $date0;
        $hour1 = empty($hour1) ? '00' : $hour1;
        $hour0 = empty($hour0) ? '00' : $hour0;
        $minutes1 = empty($minutes1) ? '00' : $minutes1;
        $minutes0 = empty($minutes0) ? '00' : $minutes0;
        
        $time1 = str_replace('/', '', $date1).$hour1.$minutes1;
        $time0 = str_replace('/', '', $date0).$hour0.$minutes0;
        //

        return ($time1 > $time0) ? TRUE : FALSE;   
    }  
    
	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres title1 et title2
     * 
     * @access protected
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public static function set_params_title_rules($lang, $config)
    {
        $params = array();
        
        foreach($config['lang'] as $key => $lng) {
            if (!empty($lng)) {
                $params['title'.($key+1)] = array(
                    array(
                        'rules' => array(array('Var_helper', 'is_required')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['title_required'], ENT_QUOTES, 'UTF-8')
                    ),
                );        
            }   
        }
        
        return $params;                
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation du choix du mode d'affichage des boites latérales
     * 
     * @access protected
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public static function set_params_sidebars_mode_display_rules($lang, $config)
    {
        return array(
            'sidebars' => array( // sidebars
                array(
                    'rules' => array(array('Var_helper', 'is_in_array['.implode(',', $config['sidebars_display_options']).']')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['menu_option_not_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
        );        
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation du choix de la mise à jour ou non de la date de modification
     * 
     * @access protected
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public static function set_params_moddate_options_rules($lang, $config)
    {
        return array(
            'update_moddate' => array( // sidebars
                array(
                    'rules' => array(array('Var_helper', 'is_binary')),
                    'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_valid'], ENT_QUOTES, 'UTF-8')
                ),
            ),
        );        
    }

	// ---------------------------------------------------------------------------- //

}