<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.10 (2016/10/21)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Var_helper
{    

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */
    
	/**
	 * Importe et parse une variable
     * 
	 * @access public
	 * @param string $name    Nom de la variable à importer (peut être de la forme name[key1][key2])
	 * @param string $source  Source à partir de laquelle on importe la variable (get, post, cookie, post_get)
	 * @param mixed  $default_value Valeur par défaut de la variable si elle n'est pas définie
	 * @param array  $parser   Fonctions ou méthodes à appliquer
	 *                         Pour une fonction, donner son nom. Exple: $parser = array('trim');
	 *                         Pour une méthode, donner le nom de l'objet et le nom de la méthode dans un tableau
	 *                         exple: $parser = array(
	 *                                                 array('objet', 'methode')
	 *                                             );
	 *                         On peut faire un mélange des deux. Exple :
	 *                         exple: $parser = array(
	 *                                                 'trim',
	 *                                                 array('objet', 'methode')
	 *                                             );
	 *                         Remarque importante : utiliser uniquement des fonctions ou des méthodes qui ont un seul argument	  
     *
	 * @param array  $rules    règles de validation (fonctions ou méthodes) à appliquer sur la valeur de la variable
	 *                         Pour une fonction, donner son nom. Exple: $rules = array('trim');
	 *                         Pour une méthode, donner le nom de l'objet et le nom de la méthode dans un tableau
	 *                         exple: $rules = array(
	 *                                                 array('object', 'method')
	 *                                             );
	 *                         On peut faire un mélange des deux. Exple :
	 *                         exple: $rules = array(
	 *                                                 'trim',
	 *                                                 array('object', 'method')
	 *                                             );
	 *                        Remarque importante : pour passer un paramètre supplémentaire 
     *                                              à la fonction ou la méthode, il faut l'ajouter entre []
	 *                         exple: $rules = array(
	 *                                                 'my_func[param]',
	 *                                                 array('object', 'my_method[param]')
	 *                                             );
     *                         Pour passer un tableau en paramètre, on doit le sérialiser au préalable.
	 * @return mixed	 
	 */
    public static function import($name, $source, $default_value = NULL, $parser = array(), $rules = array())
	{	
        switch (strtolower($source)) {
			case 'get' :
                $var = self :: get_array_value($name, $_GET, $default_value);
				break;
			case 'post' :
                $var = self :: get_array_value($name, $_POST, $default_value);
				break;
			case 'cookie' :
                $var = self :: get_array_value($name, $_COOKIE, $default_value);
				break;	
			default :
                $var = self :: get_array_value($name, $_POST, NULL);
                
                if (!isset($var)) {
                    $var = self :: get_array_value($name, $_GET, NULL);
                    
                    if (!isset($var)) {
                        $var = $default_value;
                    }
                }
		}
			
		/**
         * Traitement de la valeur de la variable
         */
		if (!empty($parser)) {
    		settype($parser, 'array');
    				
    		// Supprime les slashs si la directive magic_quotes_gpc est activé
    		if (get_magic_quotes_gpc()) { // Magic_quotes = On
    			array_unshift($parser, 'stripslashes');
    		}
          
            $var = self :: parse($var, $parser); 
		}
        //

		/**
         * Respect des règles pour la valeur de la variable
         */
		if (!empty($rules)) {
    		settype($rules, 'array');
            
            if ( ! self :: check_value($var, $rules)) {
                $var = $default_value;
            }
            
           // $var = (self :: check_value($var, $rules)) ? $var : $default_value; 
		}
        //
        		
		return $var;
	}

	// --------------------------------------------------------------------

	/**
     * Retourne la valeur d'une variable correspondant à une clé dans un tableau multidimensionnel
     * si la clé n'existe pas, on retourne la valeur par défaut
     * 
     * @param string Nom de la variable à rechercher sous la forme "var" ou encore "var[key][subkey]"
     * @param array  Tableau contenant la clé à rechercher
     * @param string Valeur par défaut si la clé n'existe pas
     * @return string Valeur de la clé recherchée dans le tableau 
     */
    public static function get_array_value($needle, $haystack, $default_value = NULL)
    {        
        $value = $haystack;
        $keys = explode('[', $needle);
       
        foreach($keys as $key) {
            $key = rtrim($key, ']');
                
            if ( ! isset($value[$key])) {
                $value = $default_value;
                break; // Exit   
            }
            
            $value = $value[$key];             
        }
        
        return $value;
    }

	// --------------------------------------------------------------------

	/**
	 * parse la valeur d'une variable avec des fonctions ou des méthodes
     * 
	 * @access public
	 * @param mixed $var       Variable à traiter. Elle peut être un tableau multidimensionnel ou une chaine 
	 * @param array $parser    Fonctions ou méthodes à appliquer
	 *                         Pour une fonction, donner son nom. Exple: $parser = array('trim');
	 *                         Pour une méthode, donner le nom de l'objet et le nom de la méthode dans un tableau
	 *                         exple: $parser = array(
	 *                                                 array('objet', 'methode')
	 *                                             );
	 *                         On peut faire un mélange des deux. Exple :
	 *                         exple: $parser = array(
	 *                                                 'trim',
	 *                                                 array('objet', 'methode')
	 *                                             );
	 *                        Remarque importante : utiliser uniquement des fonctions ou des méthodes qui ont un seul argument	  
	 * @return mixed
	 */
	public static function parse($var, $parser)
	{
		settype($parser, 'array');
		
		if (is_array($var)) {
			foreach ($var as $key => $value) {	
				if(is_array($value))	{
					$var[$key] = self :: parse($var[$key], $parser);
				} else {		
					foreach ($parser as $func) {
						$var[$key] = self :: _call_user_func($func, $var[$key]);
					}
				}	
			}
		} else {
			foreach ($parser as $func) {
				$var = self :: _call_user_func($func, $var);
			}
		}
		
		return $var;
	}

	// --------------------------------------------------------------------

	/**
	 * appelle et applique une fonction ou une méthode
     * 
	 * @param mixed $params Paramètres passés à la fonction ou la méthode sous forme d'un tableau s'il y en a plusieurs array(param1, param2, ...)
	 * @param mixed $func Fonction ( string (nom) ) ou méthode ( array('nom_class', 'nom_method') )
	 * @return mixed
	 * @access private
	 */
	private static function _call_user_func($func, $params)
	{		
		if (is_callable($func)) {
			settype($params, 'array');
            
			return !empty($params)? call_user_func_array($func, $params) : '';
		}
        
        return FALSE;
	}

	// --------------------------------------------------------------------

	/**
	 * vérifie la valeur d'une variable avec des fonctions ou des méthodes
     * 
	 * @access public
	 * @param mixed $value     Valeur de la variable à traiter. Elle peut être une chaine ou un tableau de valeur auquel cas chaque valeur sera véfiriée
	 * @param array  $rules    Fonctions ou méthodes à appliquer
	 *                         Pour une fonction, donner son nom. Exple: $rules = array('trim');
	 *                         Pour une méthode, donner le nom de l'objet et le nom de la méthode dans un tableau
	 *                         exple: $rules = array(
	 *                                                 array('object', 'method')
	 *                                             );
	 *                         On peut faire un mélange des deux. Exple :
	 *                         exple: $rules = array(
	 *                                                 'trim',
	 *                                                 array('object', 'method')
	 *                                             );
	 *                        Remarque importante : pour passer un paramètre supplémentaire 
     *                                              à la fonction ou la méthode, il faut l'ajouter entre []
	 *                         exple: $rules = array(
	 *                                                 'my_func[param]',
	 *                                                 array('object', 'my_method[param]')
	 *                                             );
     *                         Pour passer un tableau en paramètre, on doit le sérialiser au préalable.
	 * @return boolean
	 */
	public static function check_value($value, $rules)
	{
		settype($value, 'array');
        settype($rules, 'array');
		
		if (empty($rules)) {
			return TRUE;
		}
        
        foreach($value as $val) {            
            foreach($rules as $rule) {
    
        		// Extraction du paramètre (s'il existe) de la règle
        		// Une règle peut contenir un paramètre entre []
                // Pour passer un tableau en paramètre à la règle, il faut le serializer
        		$param_rule = NULL;
        		if (is_string($rule) && preg_match("/(.*?)\[(.*?)\]/", $rule, $match)) {
        			$rule	= $match[1];
        			$param_rule	= ($param_rule = @unserialize($match[2]))? $param_rule : $match[2];
                }
                else if(is_array($rule) && preg_match("/(.*?)\[(.*?)\]/", $rule[1], $match)) {
                    $rule = array($rule[0], $match[1]);
        			$param_rule	= ($param_rule = @unserialize($match[2]))? $param_rule : $match[2];
                }
                //
               
                if (! self :: _check_rule($val, $rule, $param_rule)) {
                    return FALSE;
                };
            }
        }
        
        return TRUE;  
    }

/*	public static function check_value($value, $rules)
	{
		settype($rules, 'array');
		
		if (empty($rules)) {
			return TRUE;
		}
        
        foreach($rules as $rule) {

    		// Extraction du paramètre (s'il existe) de la règle
    		// Une règle peut contenir un paramètre entre []
            // Pour passer un tableau en paramètre à la règle, il faut le serializer
    		$param_rule = NULL;
    		if (is_string($rule) && preg_match("/(.*?)\[(.*?)\]/", $rule, $match)) {
    			$rule	= $match[1];
    			$param_rule	= ($param_rule = @unserialize($match[2]))? $param_rule : $match[2];
            }
            else if(is_array($rule) && preg_match("/(.*?)\[(.*?)\]/", $rule[1], $match)) {
                $rule = array($rule[0], $match[1]);
    			$param_rule	= ($param_rule = @unserialize($match[2]))? $param_rule : $match[2];
            }
            //
           
            if (! self :: _check_rule($value, $rule, $param_rule)) {
                return FALSE;
            };
        }
        
        return TRUE;  
    }
*/
	// --------------------------------------------------------------------

	/**
	 * vérifie la validité de la valeur du paramètre 
	 *
	 * @access private
	 * @params string Valeur à vérifiée 
	 * @params string Règle de validation à appliquer
	 * @params string Paramètre supplémentaire à ajouter à la règle  
	 * @return boolean
	 */	
	private static function _check_rule($value, $rule, $params = NULL)
	{		
        if (empty($rule)) {
			return TRUE;
		}
       
        $params = empty($params) ? array($value) : array($value, $params);
        
        return (boolean) call_user_func_array($rule, $params);
	}

	/*******************************************************************************
	 *
     *                  Parser functions for variable
	 *
	 *******************************************************************************/

	/**
	 * protège les données stockées dans la base de donnée
     * 
	 * @param mixed $data Donnée à protéger
	 * @return mixed
	 * @access public
	 */
	public static function protect_data_for_db($data)
	{		
		return self :: add_my_slashes($data);
	}

	// --------------------------------------------------------------------

	/**
	 * Supprime la protection des données stockées dans la base de donnée
     * 
	 * @param mixed $data Donnée à protéger
	 * @return mixed
	 * @access public
	 */
	public static function unprotect_data_for_db($data)
	{		
		return self :: remove_my_slashes($data);
	}

	// --------------------------------------------------------------------

	/**
	 * rajoute des slashs devant les caractères spéciaux
     * 
	 * @param mixed $data Donnée à protéger
	 * @return mixed
	 * @access public
	 */
	public static function add_my_slashes($data)
	{
		if (is_array($data)) {
			$data = array_map('add_my_slashes', $data);
		} else {
			$data = addcslashes($data, '${"\'}\\:|;'."\0\n\r\t");
		}
		
		return $data;
	}

	// --------------------------------------------------------------------

	/**
	 * Supprime les slash d'une chaîne . C'est la fonction inverse de add_my_slashes()
     * 
	 * @param mixed $data Donnée à protéger
	 * @return mixed
	 * @access public
	 */	
	public static function remove_my_slashes($data)
	{
		if (is_array($data)) {
			$data = array_map('remove_my_slashes', $data);
		} else {
			$data = stripcslashes($data);
		}
		
		return $data;
	}

	// --------------------------------------------------------------------

	/**
	 * Supprime tous les espaces blancs \n\r\t\v d'une chaîne
     * 
	 * @param mixed $data Donnée à protéger
	 * @return mixed
	 * @access public
	 */	
	public static function remove_all_blank_spaces($data)
	{
		$in = array(
			"\n",
			"\r",
			"\t",
			"\v",
			' '
		);

		return str_replace($in, '', $data);
		
		//return preg_replace("`\s+`", '', $data);
	}

	// --------------------------------------------------------------------

	/**
	 * Supprime les espaces blancs \n\r\t\v d'une chaîne
     * 
	 * @param mixed $data Donnée à protéger
	 * @return mixed
	 * @access public
	 */	
	public static function remove_special_blank_spaces($data)
	{
		$in = array(
			"\n",
			"\r",
			"\t",
			"\v",
		);

		return str_replace($in, '', $data);
	}

	// --------------------------------------------------------------------

	/**
	 * remplace tous les espaces blancs (\n\r\t\v et ' ') 
     * multiples ou non par un seul espace ' ' dans une chaîne
     * 
	 * @param mixed $data Donnée à protéger
	 * @return mixed
	 * @access public
	 */	
	public static function replace_blank_chars_to_space($data)
	{
		return preg_replace("`\s\s*`", ' ', $data);
	}

	// --------------------------------------------------------------------

	/**
	 * coupe une chaine "intelligemment"
     * 
	 * @param $content string Chaine à couper
	 * @param $nbChar integer Nombre de caractères à partir duquel on coupe la chaine
	 * @param $limit integer Nombre de caractères à ne pas dépasser	 
	 * @access public
	 */
	public static function wrap_string($content, $nbChar = 55, $limit = 100)
	{
		$string = $content;

		if (strlen($string) > $nbChar) {
			if (($posEnd = strpos($string, 32, $nbChar)) !== FALSE && $posEnd < $limit) {
					$string = substr($string, 0, $posEnd);
			} else {
				$string = substr($string, 0, $nbChar);
			}	
		}
		
		return $string;
	}

	// --------------------------------------------------------------------

	/**
	 * convertit les chemins absolus en chemin relatif
     * 
	 * @access public
     * @param string Chaine à traiter
	 * @return string Chaine traitée
	 */
	public static function convert_absolute_path_to_relative($contents)
	{
		$string = $contents;
        
        $string = str_replace('="'.ADMR_SITE_URL, '="', $string);
		
		return $string;
	}

	// --------------------------------------------------------------------

	/**
	 * convertit les chemins absolus en chemin relatif
     * 
	 * @access public
     * @param string Chaine à traiter
     * @param array Tableau contenant les répertoires racines
	 * @return string Chaine traitée
	 */
	public static function convert_relative_path_to_absolute($contents, $root_folders = array('inc', 'img', 'pages', 'photo', 'flash', 'file'))
	{
		$string = $contents;
        $in = array();
        $out = array();
        
        foreach($root_folders as $folder) {
            $in[] = '="'.$folder.'/';
            $out[] = '="'.ADMR_SITE_URL.'/'.$folder.'/';    
        }
        
        $string = str_replace($in, $out, $string);
		
		return $string;
	}
    
	/*******************************************************************************
	 *
     *                  Rules
	 *
	 *******************************************************************************/
	
	/**
	 * Indique si une valeur appartient à un tableau de valeurs ou non
	 *
	 * @access	public
	 * @param	string Valeur à tester
	 * @param	string Chaine de valeurs séparées par une virgule val1,val2,... ou tableau de valeurs array('val1', 'val2')
	 * @return	bool
	 */	
	public static function is_in_array($val, $values)
	{
        if (! is_array($values)) {
            $values = explode(',', $values);    
        }       
	
		return in_array($val, $values) ? TRUE : FALSE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Indique si une valeur est plus grande à
	 *
	 * @access	public
	 * @param	string Valeur à comparer
	 * @param	string Valeur de comparaison
	 * @return	bool
	 */	
	public static function is_gt($val, $ref)
	{
		return ($val > $ref) ? TRUE : FALSE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Indique si une valeur est plus grande ou égale à
	 *
	 * @access	public
	 * @param	string Valeur à comparer
	 * @param	string Valeur de comparaison
	 * @return	bool
	 */	
	public static function is_gte($val, $ref)
	{
		return ($val >= $ref) ? TRUE : FALSE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Indique si une valeur est plus petite à
	 *
	 * @access	public
	 * @param	string Valeur à comparer
	 * @param	string Valeur de comparaison
	 * @return	bool
	 */	
	public static function is_lt($val, $ref)
	{
		return ($val < $ref) ? TRUE : FALSE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Indique si une valeur est plus petite ou égale à
	 *
	 * @access	public
	 * @param	string Valeur à comparer
	 * @param	string Valeur de comparaison
	 * @return	bool
	 */	
	public static function is_lte($val, $ref)
	{
		return ($val <= $ref) ? TRUE : FALSE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Vérifie si une valeur est strictement comprise dans un intervalle
	 *
	 * @access	public
	 * @param	string Valeur
	 * @param	array|string Intervalle sous la forme array(min, max) ou bien string 'min,max'
	 * @return	bool
	 */	
	public static function is_strictly_between($value, $limits)
	{
        if (!is_array($limits)) {
            $limits = explode(',', $limits);    
        }
        	
		return ($value > $limits[0] && $value < $limits[1]) ? TRUE : FALSE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Vérifie si une valeur est comprise dans un intervalle
	 *
	 * @access	public
	 * @param	string Valeur
	 * @param	array|string Intervalle sous la forme array(min, max) ou bien string 'min,max'
	 * @return	bool
	 */	
	public static function is_between($value, $limits)
	{
        if (!is_array($limits)) {
            $limits = explode(',', $limits);    
        }
      
		return ($value >= $limits[0] && $value <= $limits[1]) ? TRUE : FALSE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Indique si une valeur est égale à (pas de comparaison de type)
	 *
	 * @access	public
	 * @param	string Valeur à comparer
	 * @param	string Valeur de comparaison
	 * @return	bool
	 */	
	public static function is_equal($val, $ref)
	{
		return ($val == $ref) ? TRUE : FALSE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Indique si une valeur est égale à (comparaison aussi du type)
	 *
	 * @access	public
	 * @param	string Valeur à comparer
	 * @param	string Valeur de comparaison
	 * @return	bool
	 */	
	public static function is_equal_with_type($val, $ref)
	{
		return ($val == $ref) ? TRUE : FALSE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Required
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */
	public static function is_required($str)
	{
        if ( ! is_array($str))
		{
			return (trim($str) == '') ? FALSE : TRUE;
		}
		else
		{
			return ( ! empty($str));
		}
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Match one field to another
	 *
	 * @access	public
	 * @param	string
	 * @param	field
	 * @return	bool
	 */
	public static function is_matches($str, $field)
	{
        if ( ! isset($_POST[$field]))
		{
			return FALSE;				
		}
		
		$field = $_POST[$field];

		return ($str !== $field) ? FALSE : TRUE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Minimum Length
	 *
	 * @access	public
	 * @param	string Chaine
	 * @param	string Longeur minimum de la chaine
	 * @return	bool
	 */	
	public static function has_min_length($str, $val)
	{
		if (preg_match("/[^0-9]/", $val))
		{
			return FALSE;
		}

		if (function_exists('mb_strlen'))
		{
			return (mb_strlen($str) < $val) ? FALSE : TRUE;		
		}
	
		return (strlen($str) < $val) ? FALSE : TRUE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Max Length
	 *
	 * @access	public
	 * @param	string
	 * @param	value
	 * @return	bool
	 */	
	public static function has_max_length($str, $val)
	{
		if (preg_match("/[^0-9]/", $val))
		{
			return FALSE;
		}

		if (function_exists('mb_strlen'))
		{
			return (mb_strlen($str) > $val) ? FALSE : TRUE;		
		}
	
		return (strlen($str) > $val) ? FALSE : TRUE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Exact Length
	 *
	 * @access	public
	 * @param	string
	 * @param	value
	 * @return	bool
	 */	
	public static function has_exact_length($str, $val)
	{
		if (preg_match("/[^0-9]/", $val))
		{
			return FALSE;
		}

		if (function_exists('mb_strlen'))
		{
			return (mb_strlen($str) != $val) ? FALSE : TRUE;		
		}
	
		return (strlen($str) != $val) ? FALSE : TRUE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Valid Email
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */	
	public static function is_valid_email($str)
	{
		return ( ! preg_match("/^([a-z0-9\+_\-]+)(\.[a-z0-9\+_\-]+)*@([a-z0-9\-]+\.)+[a-z]{2,6}$/ix", $str)) ? FALSE : TRUE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Valid Id
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */	
	public static function is_valid_ids($str)
	{
		return preg_match('`[^0-9-]+`', $str) ? FALSE : TRUE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Valid writer name
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */	
	public static function is_valid_writer_name($name)
	{
		return preg_match('`[^-a-z0-9_]+`i', $name) ? FALSE : TRUE;
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Valid group name
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */	
	public static function is_valid_group_name($name)
	{
		return preg_match('`[^-a-z0-9_]+`i', $name) ? FALSE : TRUE;
	}

	// --------------------------------------------------------------------
	
	/**
	 * Alpha
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */		
	public static function is_alpha($str)
	{
        return (! preg_match('`[^a-z]+`i', $str)) ? TRUE : FALSE;       
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Alpha-numeric
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */	
    public static function is_alpha_num($str)
    {
        if (empty($str)) {
            return TRUE;
        }
        
        return (! preg_match('`[^a-z0-9]+`i', $str)) ? TRUE : FALSE;       
    }
	
	// --------------------------------------------------------------------
	
	/**
	 * Alpha-numeric with underscores and dashes
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */	
	public static function is_alpha_num_dash($str)
	{
        return (! preg_match('`[^a-z0-9_\-]+`i', $str)) ? TRUE : FALSE;       
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * binary
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */	
	public static function is_binary($str)
	{
        if (is_string($str) && ($str === '0' OR $str === '1')) {
            return TRUE;
        }
        
        if (is_int($str) && ($str === 0 OR $str === 1)) {
            return TRUE;
        }
        
        return FALSE;       
	}
	
	// --------------------------------------------------------------------
	
	/**
	 * Numeric
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */	
	public static function is_numeric($str)
	{
		return (bool)preg_match('`^[\-+]?[0-9]*\.?[0-9]+$`', $str);

	}

	// --------------------------------------------------------------------
	
	/**
	 * Integer
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */	
	public static function is_integer($str)
	{
		return (bool)preg_match('`^[\-+]?[0-9]+$`', $str);
	}

	// --------------------------------------------------------------------

	/**
	 * Vérifie qu'une chaîne est un entier
	 *
	 * @access	public
	 * @param	string
	 * @return	bool
	 */	
	public static function is_digit($str)
	{
		if (is_array($str)) $str = implode('', $str);
        
        if (function_exists('ctype_digit')) {
			return (ctype_digit((string) $str)) ? TRUE : FALSE;
		} else {
			return preg_match("`[^0-9]+`", $str) ? FALSE : TRUE;
		}
	}
	
	// --------------------------------------------------------------------

    /**
     * Vérifie qu'une chaîne est un entier non nul  (1,2,3, etc.)
     *
     * @access	public
     * @param	string
     * @return	bool
     */
	public static function is_digit_no_zero($str)
    {
        if (! self :: is_digit($str) || $str == 0)
    	{
    		return FALSE;
    	}
         
   		return TRUE;
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie la validité du format de la date
	 *
	 * @access	public
	 * @param	string date à vérifier sous la forme AAAA/MM/JJ
	 * @return	bool
	 */
    public static function is_valid_format_date($str)
    {    
        return preg_match('`^[0-9]{4}/[0-9]{2}/[0-9]{2}$`', $str) ? TRUE : FALSE;
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie si la date existe
	 *
	 * @access	public
	 * @param	string date écrite sous la forme AAAA/MM/JJ
	 * @return	bool
	 */
    public static function is_date($str)
    {
        $str = explode('/', $str);
        
        if (count($str) != 3) {
            return FALSE;
        }

        list($year, $month, $day) = $str;
        
        return checkdate($month ,$day ,$year);   
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie si c'est un email valide
	 *
	 * @access	public
	 * @param	string email écrit sous la forme aa@aa.a
	 * @return	bool
	 */
    public static function is_email($str)
    {
        return filter_var($str, FILTER_VALIDATE_EMAIL) ? TRUE : FALSE;   
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si un fichier ou un répertoire est présent dans un autre répertoire ou non
     * 
     * @access protected
	 * @param string chemin relatif du fichier ou du répertoire
	 * @param string Chemin relatif des répertoires parent séparés par une virgule (ex : img/icon,file,...)
	 * @return boolean
	 */
    public static function is_in_directories($path, $dirs)
    {           
        $path = str_replace(ADMR_SITE_URL, '', $path);
        
        if ( ! is_array($dirs)) {
            $dirs = explode(',', $dirs);
        }
        
        foreach($dirs as $dir) {
            $dir = rtrim($dir, '/');
            
            if (strpos($path, $dir.'/') === 0) {
                return TRUE;
            }
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si c'est bien une image ou non
     * 
     * @access protected
	 * @param string chemin relatif du fichier à vérifier
	 * @return boolean
	 */
    public static function is_image($path)
    {
        $path = str_replace(ADMR_SITE_URL, '', $path);

        return @getimagesize(CHEMIN.$path);
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si l'extension du fichier est autorisée ou non
     * 
     * @access protected
	 * @param string Chemin du fichier
     * @param string Chaine avec les extensions autorisées séparées par une virgule ext1,ext2,...
	 * @return boolean
	 */
    public static function is_allowed_ext($path, $allowed_ext)
    {
        return self :: is_in_array(strrchr($path, '.'), $allowed_ext);
    }
          
	// --------------------------------------------------------------------

	/**
	 * Vérifie si l'url est valide ou non
     * 
     * @access protected
	 * @param string Url à vérifier
	 * @return boolean
	 */
    public static function is_url($url)
    {       
        return (! filter_var($url, FILTER_VALIDATE_URL))? FALSE : TRUE;
    }
          
	// --------------------------------------------------------------------

	/**
	 * Vérifie si l'adresse du site web est valide ou non
     * 
     * @access protected
	 * @param string Url à vérifier
	 * @return boolean
	 */
    public static function is_valid_website_address($address)
    {
     	return preg_match('`^https?://(?:www\.)?(?:[a-z0-9](?:[a-z0-9\-]*[a-z0-9])?\.)*[a-z0-9](?:[a-z0-9\-]*[a-z0-9])?\.[a-z]{2,6}$`ix', $address) ? TRUE : FALSE; 
    }
          
	// --------------------------------------------------------------------

	/**
	 * Vérifie si le fichier existe ou non
     * 
     * @access protected
	 * @param string Chemin du fichier à vérifier
	 * @return boolean
	 */
    public static function file_exists($file_path)
    {       
    	if (strpos($file_path, 'http://') !== 0) {
    	   $file_path = CHEMIN.$file_path;   
    	}

        return is_file($file_path);
    }
          
	// --------------------------------------------------------------------

	/**
	 * Vérifie si le fichier est un fichier interne ou non
     * 
     * @access protected
	 * @param string Chemin du fichier à vérifier
	 * @return boolean
	 */
    public static function is_internal_file($file_path)
    {       
    	$file_path = str_replace(ADMR_SITE_URL, '', $file_path);
        
        if (strpos($file_path, 'http://') === 0) {
    	   return FALSE;   
    	}

        return is_file(CHEMIN.$file_path);
    }
          
	// --------------------------------------------------------------------

}