<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('CHEMIN') OR exit('No direct script access allowed');

/**
 * data_table Class
 *
 * Permits to generate a data table
 *
 * @package		
 * @subpackage	Libraries
 * @category	Libraries
 * @author		Jerome Croux
 * @link		
 */
 
class Data_table
{
	/**
	 *	Properties
	 */
	private $_headers = array();	// Entêtes du tableau de données
	private $_table_attrs = array();	// Attributs du tableau
    private $_thead_attr = array();	    // Attributs du tag Thead et Tfoot
	private $_tfoot_exists = TRUE;	// Présence d'un pied de tableau ou non
	private $_caption = NULL;
    private $_select_actions = array();   // Options du menu de sélection des actions
    private $_input_submit_attrs = array(); // Attributs du bouton submit
	
	private $_rows = '';	// Mise en cache du code HTML des lignes
	private $_newline = "\n";
		
	/**
	 * Constructor
	 */ 
	public function __construct()
	{

	}
	
	// --------------------------------------------------------------------

	/**
	 * Définit les entêtes du tableau
	 *
	 * @access public
	 * @param array Entêtes du tableau déclarés sous la forme
	 *  				$headers = array(
	 *  					0 => array('contents' => $contents, 'attrs' => array())
	 *  					1 => array('contents' => $contents, 'attrs' => array())
	 *  				)
	 * @return void
	 */
	public function set_headers($headers)
	{
		settype($headers, 'array');
		$this -> _headers = $headers;
		
		foreach($headers as $key => $value) {
			if (empty($this -> _headers[$key]['attrs']['id'])) {
				$this -> _headers[$key]['attrs']['id'] = 'header_'.$key;
			} 
		}
	}

	// --------------------------------------------------------------------

	/**
	 * Définit les attributs du tableau
	 *
	 * @access public
	 * @param array $attr Attributs du tableau déclarés sous la forme
	 * 		$attr = array(
	 *  		name1 => value1,	// Attribut 1
	 *  		name2 => value2		// Attribut 2
	 *  	)
	 * @return void
	 */
	public function set_table_attributes($attrs)
	{
		settype($attrs, 'array');
		$this -> _table_attrs = $this -> _add_tag_attributes($attrs);
	}

	// --------------------------------------------------------------------

	/**
	 * Définit les attributs des entêtes du tableau
	 *
	 * @access public
	 * @param array $attr Attributs du tableau déclarés sous la forme
	 * 		$attr = array(
	 *  		name1 => value1,	// Attribut 1
	 *  		name2 => value2		// Attribut 2
	 *  	)
	 * @return void
	 */
	function set_thead_attributes($attr)
	{
		settype($attr, 'array');
		$this -> _thead_attr = $this -> _add_tag_attributes($attr);
	}

	// --------------------------------------------------------------------
	
	/**
	 * Définit si le tableau possède un pied ou non
	 *
	 * @access public
	 * @param boolean $boolean
	 * @return void
	 */
	public function set_tfoot_exists($bool)
	{
		settype($bool, 'boolean');
		$this -> _tfoot_exists = $bool;
	}

	// --------------------------------------------------------------------

	/**
	 * Construit une ligne du tableau
	 *
	 * @access public
	 * @param array Cellules de la ligne déclarées sous la forme
	 * 		        $cells = array(
	 *  		        0 => array('contents' => $contents, 'attrs' => array()) 	// Cellule 1
	 *  		        1 => array('contents' => $contents, 'attrs' => array())	// Cellule 2
	 *  	        )
	 * @param array Attributs de la ligne du tableau déclarés sous la forme
	 * 		        $attrs = array(
	 *  		        name1 => value1,	// Attribut 1
	 *  		        name2 => value2		// Attribut 2
	 *  	        )
	 * @return void
	 */
	public function add_row($cells, $attrs = array())
	{
		if (! is_array($cells)) {
			return FALSE;
		}

		$html = '<tr'.$this -> _add_tag_attributes($attrs).'>'.$this -> _newline;
		foreach ($cells as $key => $cell) {
			if (isset($this -> _headers[$key]['attrs']['id'])) {
				$cell['attrs']['headers'] = $this -> _headers[$key]['attrs']['id'];
				$html .= '<td'.$this -> _add_tag_attributes($cell['attrs']).'>'.$cell['contents'].'</td>'.$this -> _newline;
			}
		}
		$html .= '</tr>'.$this -> _newline;
				
		$this -> _rows .= $html;
		
		return;
	}

	// --------------------------------------------------------------------

	/**
	 * Add a table caption
	 *
	 * @access	public
	 * @param	string
	 * @return	void
	 */
	public function set_caption($caption)
	{
		$this -> _caption = $caption;
	}	

	// --------------------------------------------------------------------

	/**
	 * Génère le code html du tableau
	 *
	 * @access public
	 * @return string Code html du tableau
	 */
	public function generate()
	{
		$html = '<table'.$this -> _table_attrs.'>'.$this -> _newline
              . $this -> _add_caption()
              . $this -> _add_headers()
    		  . '<tbody>'.$this -> _newline
    		  . $this -> _rows
    		  . '</tbody>'.$this -> _newline
    		  . '</table>'.$this -> _newline;
		
		return $html;		
	}
	
	// --------------------------------------------------------------------

	/**
	 * Clears the table arrays.  Useful if multiple tables are being generated
	 *
	 * @access	public
	 * @return	void
	 */
	public function clear()
	{
		$this -> _rows = array();
	}
	
	// --------------------------------------------------------------------

	/**
	 * Ajoute une légende au tableau
	 *
	 * @access private
	 * @return string Code html définissant la légende du tableau
	 */
	private function _add_caption()
	{
		$caption = $this -> _caption;
		
		if (empty($caption)) {
			return '';
		}

		return '<caption>'.$caption.'</caption>'.$this -> _newline;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute l'entête et le pied du tableau
	 *
	 * @access private
	 * @return string Code html définissant l'entête et le pied du tableau
	 */
	private function _add_headers()
	{
		$cells = $this -> _headers;
		$html = '';
		
		if (! is_array($cells) || empty($cells)) {
			return $html;
		}
		
		// Thead
		$html .= '<thead'.$this -> _thead_attr.'>'.$this -> _newline.'<tr>'.$this -> _newline;
		foreach($cells as $cell) {
			$html .= '<th'.$this -> _add_tag_attributes($cell['attrs']).'>'.$cell['contents'].'</th>'.$this -> _newline;
		}
		$html .= '</tr>'.$this -> _newline.'</thead>'.$this -> _newline;
		//
		
		// Tfoot
		if ($this -> _tfoot_exists) {
			$html .= '<tfoot'.$this -> _thead_attr.'>'.$this -> _newline.'<tr>'.$this -> _newline;
			foreach($cells as $cell) {
				$html .= '<th>'.$cell['contents'].'</th>'.$this -> _newline;
			}
			$html .= '</tr>'.$this -> _newline.'</tfoot>'.$this -> _newline;
		}
		//
		
		return $html;
	}

	// --------------------------------------------------------------------

	/**
	 * Construit et retourne les attributs d'une balise html
	 *
	 * @access private
	 * @param array $attr Attributs d'une balise déclarés sous la forme
	 * 		$attr = array(
	 *  		name1 => value1,	// Attribut 1
	 *  		name2 => value2,	// Attribut 2
	 *  		... 
	 *  	)
	 * @return string Code html définissant les attributs de la balise html
	 */
	private function _add_tag_attributes($attr)
	{
		$html = '';
		
		if ( ! empty($attr) && is_array($attr) ) {
			foreach($attr as $name => $value) {
				$html .= ' '.$name.'="'.$value.'"';
			}
		}
        
		return $html;
	}

}