<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Writer_authentification
{
	private $_CI;
    private $error = array();
    private $_writer_rights = array();

	function __construct()
	{
        $this -> _CI =& Controller :: get_instance();

        $this -> _CI -> load_model('writer_model');
        $this -> _CI -> load_model('rights_model', 'writer', 'rights_writer_model');
        $this -> _CI -> load_model('rights_model', 'group', 'rights_group_model');
        $this -> _CI -> load_model('writers_online_model');
	}

	// --------------------------------------------------------------------

	/**
	 * Login user on the site. Return TRUE if login is successful
	 * (user exists and activated, password is correct), otherwise FALSE.
	 *
	 * @param	string (username or email or both depending on settings in config file)
	 * @param	string password
	 * @param	bool
	 * @return	bool
	 */
	public function login($login, $pass)
	{
        if (!empty($login) && !empty($pass)) {
            
            $writer = $this -> _CI -> writer_model -> get_by_name($login);
       
            if (!empty($writer) && $writer['status'] == 'a') {
                $writer_rights = $this -> _CI -> rights_writer_model -> read($writer['id']);
                
                if ($writer_rights['pass'] === Security_helper :: encrypt_password($login.$pass)) {
                    $_SESSION['admr']['writerid'] = $writer['id']; // Enregistrement du rédacteur dans une session
                    $this -> _CI -> writers_online_model -> add($writer['id']); // Ajout du rédacteur en ligne
                    return TRUE;
                }
            }
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------

	/**
	 * Logout user from the site
	 *
	 * @return	void
	 */
	public function logout()
	{
        if (!empty($_SESSION['admr']['writerid'])) {
            $this -> _CI -> writers_online_model -> delete($_SESSION['admr']['writerid']); // Suppression du rédacteur en ligne
    
            /**
             *  Suppression de la session
             */
            unset($_SESSION['admr']);

            if (empty($_SESSION['connect_pseudo'])) { // Pas de connexion en tant que membre
                if (ini_get("session.use_cookies")) { // Destruction du cookie de session
                    $params = session_get_cookie_params();
                    setcookie(session_name(), '', time() - 42000, $params["path"], $params["domain"], $params["secure"], $params["httponly"]);
                }
                
                session_destroy(); // Destruction des données de session                
            }
            //
        }
	}

	// --------------------------------------------------------------------

	/**
	 * Check if user logged in. Also test if user is activated or not.
	 *
	 * @param	bool
	 * @return	bool
	 */
	public function is_logged_in()
	{
        if (!empty($_SESSION['admr']['writerid'])) {
            $writer = $this -> _CI -> writer_model -> get_by_id($_SESSION['admr']['writerid']);
            
            if (!empty($writer) && $writer['status'] == 'a') {
                return TRUE;
            }    
        }
        
        return FALSE;
	}

	// --------------------------------------------------------------------

	/**
	 * Get writer rights
	 *
	 * @return	string
	 */
	public function get_writer_rights()
	{
        $rights = array();
        
        if (!empty($_SESSION['admr']['writerid'])) {
            $writer = $this -> _CI -> writer_model -> get_by_id($_SESSION['admr']['writerid']);
            
            if (!empty($writer) && $writer['status'] == 'a') {
                $rights = array_merge($this -> _CI -> rights_writer_model -> read($writer['id']), $writer);
     //           unset($rights['pass']);
                
                // Appartenance à un groupe
                if (!empty($writer['groupid'])) {
                    $rights_group = $this -> _CI -> rights_group_model -> read($writer['groupid']);
                    $rights_group['group_name'] = $rights_group['name'];
                    unset($rights_group['id'], $rights_group['name']); // important pour éviter l'écrasement des identifiants du rédacteur
                    
                    $rights = array_merge($rights, $rights_group);
                }
            }
        }
       
        return $this -> _writer_rights = $rights;
	}

	// --------------------------------------------------------------------

	/**
	 * Get writer name
	 *
	 * @return	string
	 */
    public function get_writer_name()
    {
        if (empty($this -> _writer_rights['name'])) {
            $this -> _writer_rights = $this -> get_writer_rights();
        }

        return $this -> _writer_rights['name']; 
    }

	// --------------------------------------------------------------------

	/**
	 * Get writer id
	 *
	 * @return	integer
	 */
    public function get_writer_id()
    {
        if (empty($this -> _writer_rights['id'])) {
            $this -> _writer_rights = $this -> get_writer_rights();
        }
        
        return $this -> _writer_rights['id']; 
    }

} // End Class