<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_MODELS_PATH.'/docs_index_model.php';

class Agenda_index_model extends Docs_index_model
{    
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_doc_type = TYP_AGENDA;

    private $_params = array(
        'evdate'    => '', // Date de l'évènement (AAAAMMJJ0000)
        'evtime'    => '', // Horaires de l'évènement (hh:mm-hh:mm)
        'evperiod'  => '', // Période mensuelle de l'évènement (MMAAAA)
        'id'        => '', // Identifiant du document
        'creadate'  => '', // Date de création 
        'group'     => '', // Groupe privé
        'type'      => '', // Type du document
    );

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
	{
        parent :: __construct($this -> _doc_type);              
	}

	// --------------------------------------------------------------------
 
	/**
	 * Lit et renvoie dans un tableau les données enregistrées du rédacteur
     * 
     * @access public 
	 * @param integer Identifiant du rédacteur
	 * @return array Tableau contenant les valeurs des droits du rédacteur (par défaut $this -> _rights)
	 */
    public function read()
    {
        $data = array();
        $db = parent :: read();    // Récupérer données enregistrés dans le fichier d'index.dtb        
            
        foreach($db as $row) {
            $data[$row[4]] = array(
                'evdate'    => $row[0], // Date de l'évènement (AAAAMMJJ0000)
                'evtime'    => $row[1], // Horaires de l'évènement (hh:mm-hh:mm)
                'evperiod'  => $row[2], // Période mensuelle de l'évènement (MMAAAA)
//                'title2'    => $row[3], // Titre pour la langue 2
                'id'        => $row[4], // Identifiant du document
                'creadate'  => $row[5], // Choix du menu
                'group'     => $row[6], // Groupe privé
                'type'      => $row[7], // Type du document
            );    
        }
        
        return $data;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Ajoute un nouvel enregistrement dans la base de donnée de l'index
     * 
     * @access public 
	 * @param array Tableau contenant les données du document à ajouter
	 * @return integer Identifiant du document rajouté
	 */    
    public function insert($params)
    {
        settype($params, 'array');
        $params = array_merge($this -> _params, $params);
        
        $data[0]  = $this -> _format_event_date_for_recording($params['evdate']);
        $data[1]  = $params['evtime'];
        $data[2]  = $params['evperiod'];
        $data[3]  = '';
        $data[4]  = $params['id'];
        $data[5]  = $params['creadate'];
        $data[6]  = $params['group'];
        $data[7]  = $this -> _doc_type;        

        // Suppression des connecteurs
        $data = parent :: clean($data);
        
        // Rajout des données du document
        parent :: append($data);        
        
        return $params['id'];            
    }    
    
	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour un enregistrement dans la base de donnée de guppy
     *
     * @access public 
	 * @param array Tableau contenant les données du document à ajouter
	 * @return integer Identifiant du document rajouté
	 */    
    public function update($params)
    {
        settype($params, 'array');
        
        $data = parent :: read();
        $id = $params['id'];

        if (!empty($data[$id])) { // Mise à jour
            $data[$id][0] = $this -> _format_event_date_for_recording($params['evdate']);
            $data[$id][1] = $params['evtime'];
            $data[$id][2] = $params['evperiod'];
            $data[$id][3] = '';
            $data[$id][4] = $params['id'];
            $data[$id][5] = $params['creadate'];
            $data[$id][6] = $params['group'];
            $data[$id][7] = $this -> _doc_type;
            
            $data[$id] = parent :: clean($data[$id]);
            
            parent :: write($data);            
        }
        
        return $params['id']; 
    }
    
	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour un enregistrement dans la base de donnée de guppy
     *
     * @access public 
	 * @param array Tableau contenant les identifiants des documents à supprimer
	 * @return void
	 */    
    public function delete($ids)
    {
        settype($ids, 'array');
        
        $data = parent :: read();

        foreach($ids as $id) {
            if (!empty($data[$id])) {
                unset($data[$id]);
            }            
        }
        
        parent :: write($data);
    }

	// --------------------------------------------------------------------
 
	/**
	 * Formatte la date pour être enregistrée dans la base de donnée
     * 
     * @access public 
	 * @param string Date récupérée via le formulaire
	 * @return string Date prête à être enregistrée dans la base de donnée
	 */
    private function _format_event_date_for_recording($date)
    {
        if (strpos($date, '/') !== FALSE) {
            $date = str_replace('/', '', $date).'0000';    
        }
        
        return $date;            
    }

	// --------------------------------------------------------------------

} // End of Class