<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_MODELS_PATH.'/docs_model.php';

class Agenda_model extends Docs_model
{       
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_doc_type = TYP_AGENDA;

    private $_params = array(
        'type'      => '',     // Type du document
        'id'        => '',     // Identifiant du document
        'status'    => '',     // Status
        'creadate'  => '',     // Date de crétaion
        'moddate'   => '',     // Date de modification
        'author'    => '',     // Nom de l'auteur
        'email'     => '',     // Email de l'auteur
        'evdate'    => '',     // Date de l'évènement (AAAAMMJJ0000)
        'evtime'    => '',     // Horaires de l'évènement (hh:mm-hh:mm)
        'evperiod'  => '',     // Période mensuelle de l'évènement (MMAAAA)
        'content1'  => '',     // Contenu pour la langue 1
        'content2'  => '',     // Contenu pour la langue 2
        'group'     => '',     // Groupe privé

        'pubdate0'   => '',    // Date début de publication programmée
        'pubhour0'   => '',    // Heure de début de publication programmée
        'pubminute0' => '',    // Minute de début de publication programmée
        'pubdate1'   => '',    // Date de fin de publication programmée
        'pubhour1'   => '',    // Heure de fin de publication programmée
        'pubminute1' => '',    // Minute de fin de publication programmée
        
        'evhour0'   => '',     // Heure de début de l'évènement
        'evminute0' => '',     // Minute de début de l'évènement
        'evhour1'   => '',     // Heure de fin de l'évènement
        'evminute1' => '',     // Minute de fin de l'évènement
    );

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
	{
        parent :: __construct($this -> _doc_type);
	}

	// --------------------------------------------------------------------
 
	/**
	 * Lit et renvoie dans un tableau les données du document
     * 
     * @access public 
	 * @param integer Identifiant du rédacteur
	 * @return array Tableau contenant les valeurs des droits du rédacteur (par défaut $this -> _rights)
	 */
    public function read($doc_id = '')
    {       
        if (empty($doc_id)) { // Nouveau document
            $params = array_merge(
                $this -> _params,
                array(
                    'type'       => $this -> _doc_type, // Type du document
                    'status'     => 'i', // Status par defaut
                    'pubdate0'   => Date_helper :: get_current_date(),   // Date début de publication programmée
                    'pubhour0'   => Date_helper :: get_current_hour(),    // Heure de début de publication programmée
                    'pubminute0' => Date_helper :: get_current_minutes(), // Minute de début de publication programmée
                )
            );
        }
        else {  // Document existant
            
            $data = parent :: read($doc_id);    // Récupérer données enregistrés dans docxxx.dtb
    
            list($data['pubdate0'], $data['pubhour0'], $data['pubminute0'], $data['pubdate1'], $data['pubhour1'], $data['pubminute1']) = Date_helper :: convert_createdate_to_pubdates($data['creadate']); // Récupérer dates et horaires de publication
            list($data['evhour0'], $data['evhour1'], $data['evminute0'], $data['evminute1']) = $this -> _convert_event_time_to_hours_minutes($data['fielda2']); // Récupérer horaires de l'évènement
           
            $params = array_merge(
                $this -> _params,
                array(
                    'type'       => $data['type'],      // Type du document
                    'id'         => $data['fileid'],    // Identifiant du document
                    'status'     => $data['status'],    // Status
                    'creadate'   => $data['creadate'],  // Date de création                 
                    'author'     => $data['author'],    // Nom de l'auteur
                    'email'      => $data['email'],     // Email de l'auteur
                    'evdate'     => $this -> _format_event_date_for_reading($data['fielda1']),   // Date de l'évènement (AAAAMMJJ0000)
                    'evtime'     => $data['fielda2'],   // Horaires de l'évènement (hh:mm-hh:mm)
                    'evperiod'   => $data['fieldb1'],   // Période mensuelle de l'évènement (MMAAAA)
                    'content1'   => $data['fieldc1'],   // Contenu pour la langue 1
                    'content2'   => $data['fieldc2'],   // Contenu pour la langue 2
                    'group'      => $data['fieldmod'],  // Groupe privé
                    
                    'pubdate0'   => $data['pubdate0'],   // Date début de publication programmée
                    'pubhour0'   => $data['pubhour0'],   // Heure de début de publication programmée
                    'pubminute0' => $data['pubminute0'], // Minute de début de publication programmée
                    'pubdate1'   => $data['pubdate1'],   // Date de fin de publication programmée
                    'pubhour1'   => $data['pubhour1'],   // Heure de fin de publication programmée
                    'pubminute1' => $data['pubminute1'], // Minute de fin de publication programmée
    
                    'evhour0'    => $data['evhour0'],   // Heure de début de l'évènement
                    'evminute0'  => $data['evminute0'], // Minute de début de l'évènement
                    'evhour1'    => $data['evhour1'],   // Heure de fin de l'évènement
                    'evminute1'  => $data['evminute1'], // Minute de fin de l'évènement
                )
            ); 
        }
        //

        return $params;
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Ajoute un nouvel enregistrement dans la base de donnée de guppy
     * 
     * @access public 
	 * @param integer Le nom du rédacteur
	 * @return array
	 */    
    public function insert($params)
    {
        $data[0]  = $this -> _doc_type;
        $data[1]  = '';
        $data[2]  = $params['status'];
        $data[3]  = Date_helper :: convert_pubdates_to_createdate(array($params['pubdate0'], $params['pubdate1']), array($params['pubhour0'], $params['pubhour1']),array($params['pubminute0'], $params['pubminute1']));
        $data[4]  = '';
        $data[5]  = $params['author'];
        $data[6]  = $params['email'];
        $data[7]  = $this -> _format_event_date_for_recording($params['evdate']);
        $data[8]  = $this -> _convert_hours_minutes_to_event_time(array($params['evhour0'], $params['evhour1']), array($params['evminute0'], $params['evminute1']));
        $data[9]  = $this -> _convert_event_date_to_event_period($params['evdate']);
        $data[10] = '';
        $data[11] = parent :: _clean_param_content($params['content1']);
        $data[12] = parent :: _clean_param_content($params['content2']);
        $data[13] = '';
        $data[14] = '';
        $data[15] = '';
        $data[16] = '';
        $data[17] = $params['group'];

        // Création du document
        $id = ActionOnFields('add', $data);
        
        return $id;
    }    
    
	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour un enregistrement dans la base de donnée de guppy
     * 
     * @access public 
	 * @param integer Identifiant du document
     * @param array Données du document
	 * @return array
	 */    
    public function update($params)
    {
        $data[0]  = $this -> _doc_type;
        $data[1]  = $params['id'];
        $data[2]  = '';
        $data[3]  = Date_helper :: convert_pubdates_to_createdate(array($params['pubdate0'], $params['pubdate1']), array($params['pubhour0'], $params['pubhour1']), array($params['pubminute0'], $params['pubminute1']));
        $data[4]  = GetCurrentDateTime();
        $data[5]  = $params['author'];
        $data[6]  = $params['email'];
        $data[7]  = $this -> _format_event_date_for_recording($params['evdate']);
        $data[8]  = $this -> _convert_hours_minutes_to_event_time(array($params['evhour0'], $params['evhour1']), array($params['evminute0'], $params['evminute1']));
        $data[9]  = $params['evperiod'];
        $data[10] = '';
        $data[11] = parent :: _clean_param_content($params['content1']);
        $data[12] = parent :: _clean_param_content($params['content2']);
        $data[13] = '';
        $data[14] = '';
        $data[15] = '';
        $data[16] = '';
        $data[17] = $params['group'];

        // Mise à jour du document
        ActionOnFields('mod', $data);
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie l'intitulé du document
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres du document
	 * @return string Intitulé descriptif du document
	 */
    public function set_doc_heading($params)
    {        
        global $lng, $lang;

		$field1 = str_replace('/', '', $params['evdate']);       
        $field1 = substr(FormatDate($field1."00000"), 0, 10).' - ';
        
        if ($params['evtime'] != '' && $params['evtime'] != '-') {
            $field1 .= $params['evtime'].' - ';
        }
        
        $field2 = ($lng == $lang[1]) ? $params['content2'] : $params['content1'];
        $field2 = strip_tags($field2);
        if (strlen($field2) > 142) {
            $field2 = CutLongWord($field2, 142).' .../...';
        }
        
        return '<strong>'.$field1.'</strong>'.$field2; 
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public function set_params_rules($params, $lang, $config)
    {        
        return array_merge(
            Params_rules_helper :: set_params_status_rules($lang),  // Status
            Params_rules_helper :: set_params_pubdates_rules($params, $lang),   // Dates de publication
            Params_rules_helper :: set_params_group_rules($lang),             // Group
            array(
                'evdate' => array(       // date de l'évènement
                    array(
                        'rules' => array(array('Var_helper', 'is_required')),
                        'msg' => $lang['form_errors_msg']['eventdate_required']
                    ),
                    array(
                        'rules' => array(array('Var_helper', 'is_valid_format_date')),
                        'msg' => $lang['form_errors_msg']['eventdate_format_not_valid']
                    ),
                    array(
                        'rules' => array(array('Var_helper', 'is_date')),
                        'msg' => $lang['form_errors_msg']['eventdate_not_exist']
                    ),
                    array(
                        'rules' => array(array($this, '_is_more_recent_event_date['.$params['pubdate0'].']')),
                        'msg' => $lang['form_errors_msg']['eventdate_less_recent_than_pubdate']
                    ),
                ),            
                'evhour0' => array(       // heure de début de l'évènement
                    array(
                        'rules' => array(array($this, '_is_valid_hour')),
                        'msg' => $lang['form_errors_msg']['hour_not_valid']
                    ),
                ),
                'evhour1' => array(       // heure de fin de l'évènement
                    array(
                        'rules' => array(array($this, '_is_valid_hour')),
                        'msg' => $lang['form_errors_msg']['hour_not_valid']
                    ),
    
                    array(
                        'rules' => array(array($this, '_is_more_recent_time['.$params['evhour0'].','.$params['evminute0'].','.$params['evminute1'].']')),
                        'msg' => $lang['form_errors_msg']['eventtime_end_less_recent_than_begin']
                    ),
                ),
                'evminute0' => array(       // minutes de début de l'évènement
                    array(
                        'rules' => array(array($this, '_is_valid_minutes')),
                        'msg' => $lang['form_errors_msg']['minutes_not_valid']
                    ),
    
                ),
                'evminute1' => array(       // minutes de fin de l'évènement
                    array(
                        'rules' => array(array($this, '_is_valid_minutes')),
                        'msg' => $lang['form_errors_msg']['minutes_not_valid']
                    ),
    
                ),
            )
        );
    }
    
	// --------------------------------------------------------------------

    /**
     * récupère les horaires de l'évènement à partir du temps enregistré dans la base de donnée
     *
     * @access private
     * @param string Horaires de l'évènement
     * @return array
     */
    private function _convert_event_time_to_hours_minutes($evtime)
    {	
        $hours = array('', '');
        $minutes = array('', '');
        
        $schedules  = explode('-', $evtime);
        
        foreach($schedules as $key => $value) {
            if (!empty($value)) {
                $time = explode(':', $value);
                
                $hours[$key] = isset($time[0]) ? $time[0] : '';
        		$minutes[$key] = isset($time[1]) ? $time[1] : '';                     
    		}
        }
        
        return array_merge($hours, $minutes);
    }

	// --------------------------------------------------------------------

    /**
     * construit le temps à enregistrer dans la base de donnée à partir des horaires enregistrées dans le formulaire
     *
     * @access private
     * @param string Date de création du document
     * @return array
     */
    private function _convert_hours_minutes_to_event_time($hours = array('', ''), $minutes = array('', ''))
    {
        global $site;
        
        // Validation des minutes
        foreach($minutes as $key => $value) {
            if ($value < 0 || $value > 60) {
                $minutes[$key] = 0;    
            }   
        }
        
        // Validation des heures
        if ($site[22] == 'H3') {
            foreach($hours as $key => $value) {
                if ($value < 0 || $value > 12) {
                    $hours[$key] = 0;    
                }   
            }
        } else {
            foreach($hours as $key => $value) {
                if ($value < 0 || $value > 24) {
                    $hours[$key] = 0;    
                }   
            }
        }
        //
        
        // Conversion
        $d = array();
        
        for($i = 0; $i < 2; $i++) {
            $d[] = ($hours[$i] == 0 && $minutes[$i] == 0) ? '' : sprintf('%02d:%02d', $hours[$i], $minutes[$i]);        
        }

        return implode('-', $d);
    }

	// --------------------------------------------------------------------

    /**
     * construit la période de l'évènement à partir de la date de l'évènement
     *
     * @access private
     * @param string Date de création du document
     * @return array
     */
    private function _convert_event_date_to_event_period($evdate)
    {
        $tmp = explode('/', $evdate);
        array_pop($tmp);
        
        return implode('', array_reverse($tmp));
    }

	// --------------------------------------------------------------------
 
	/**
	 * Formatte la date enregistrée dans la base de donnée pour être affichée correctement dans la page
     * 
     * @access public 
	 * @param string Date enregistrée dans la base de donnée
	 * @return string Date prête à être à afficher
	 */
    private function _format_event_date_for_reading($date)
    {
        $year = substr($date, 0, 4);
        $month = substr($date, 4, 2);
        $day = substr($date, 6, 2);
        
        return implode('/', array($year, $month, $day));   
    }

	// --------------------------------------------------------------------
 
	/**
	 * Formatte la date pour être enregistrée dans la base de donnée
     * 
     * @access public 
	 * @param string Date récupéré via le formulaire
	 * @return string Date prête à être enregistrée dans la base de donnée
	 */
    private function _format_event_date_for_recording($date)
    {
        return str_replace('/', '', $date).'0000';            
    }
           
	// --------------------------------------------------------------------

    /**
	 * Vérifie que la date de l'évènement est plus récente que la date de publication
     * 
	 * @access protected
     * @param string Date de l'évènement
     * @param string Date de début de publication
     * @return array Données d'erreur
	 */	
    function _is_more_recent_event_date($event_date, $pub_date = '')
    {
        if (empty($event_date)) {
            return TRUE;
        }
        
        $event_date = str_replace('/', '', $event_date);
        $pub_date = str_replace('/', '', $pub_date);
        
        if (empty($pub_date)) {
            $pub_date = date('Ymd');        
        }

        return ($event_date >= $pub_date) ? TRUE : FALSE;   
    }
        
	// --------------------------------------------------------------------

    /**
	 * Vérifie que l'horaire de fin de l'évènement est plus récent que l'horaire de début
     * 
	 * @access protected
     * @param string Heure de début de l'évènement
     * @param string Horaire de début et de fin de l'évènement
     * @return boolean
	 */
    function _is_more_recent_time($hour1, $times)
    {
        $times = explode(',', $times);
        
        if ($hour1 == '' || $times[0] == '') {
            return TRUE;    
        }
        
        $hour0 = $times[0];
        $min0 = empty($times[1])? '00' : $times[1];
        $min1 = empty($times[2])? '00' : $times[2];
        
        return (mktime($hour1, $min1) > mktime($hour0, $min0)) ? TRUE : FALSE;       
    }
        
	// --------------------------------------------------------------------

    /**
	 * Vérifie que l'heure est valide
     * 
	 * @access protected
     * @param string Heure à vérifier
     * @return boolean
	 */    
    function _is_valid_hour($hour)
    {
        if ($hour == '') {
            return TRUE;
        }
        
        return Var_helper :: is_between($hour, array('0','23'));      
    }
        
	// --------------------------------------------------------------------

    /**
	 * Vérifie que les minutes sont valides
     * 
	 * @access protected
     * @param string Minutes à vérifier
     * @return boolean
	 */
    function _is_valid_minutes($minutes)
    {
        if ($minutes == '') {
            return TRUE;
        }
        
        return Var_helper :: is_between($minutes, array('0','59'));      
    }
        
	// --------------------------------------------------------------------


} // End of Class