<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_MODELS_PATH.'/docs_model.php';

class Faq_model extends Docs_model
{       
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_doc_type = TYP_FAQ;

    private $_params = array(
        'type'      => '',  // Type du document
        'id'        => '',  // Identifiant du document
        'status'    => '',  // Status
        'creadate'  => '',  // Date de crétaion
        'moddate'   => '',  // Date de modification
        'author'    => '',  // Nom de l'auteur
        'email'     => '',  // Email de l'auteur
        'cat1'      => '',  // Catégorie pour la langue 1
        'cat2'      => '',  // Catégorie pour la langue 2
        'title1'    => '',  // Titre pour la langue 1
        'title2'    => '',  // Titre pour la langue 2
        'content1'  => '',  // Contenu pour la langue 1
        'content2'  => '',  // Contenu pour la langue 2
        'group'     => '',  // Groupe privé

        'pubdate0'   => '', // Date début de publication programmée
        'pubhour0'   => '', // Heure de début de publication programmée
        'pubminute0' => '', // Minute de début de publication programmée
        'pubdate1'   => '', // Date de fin de publication programmée
        'pubhour1'   => '', // Heure de fin de publication programmée
        'pubminute1' => '', // Minute de fin de publication programmée        
    );

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
	{
        parent :: __construct($this -> _doc_type);
	}

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * Lit et renvoie dans un tableau les données enregistrées du rédacteur
     * 
     * @access public 
	 * @param integer Identifiant du rédacteur
	 * @return array Tableau contenant les valeurs des droits du rédacteur (par défaut $this -> _rights)
	 */
    public function read($doc_id = '')
    {
        if (empty($doc_id)) { // Nouveau document
            $params = array_merge(
                $this -> _params,
                array(
                    'type'       => $this -> _doc_type, // Type du document
                    'status'     => 'i', // Status par defaut
                    'pubdate0'   => Date_helper :: get_current_date(),   // Date début de publication programmée
                    'pubhour0'   => Date_helper :: get_current_hour(),    // Heure de début de publication programmée
                    'pubminute0' => Date_helper :: get_current_minutes(), // Minute de début de publication programmée
                )
            );
        }
        else {  // Document existant
            
            $data = parent :: read($doc_id);    // Récupérer données enregistrés dans docxxx.dtb

            list($data['pubdate0'], $data['pubhour0'], $data['pubminute0'], $data['pubdate1'], $data['pubhour1'], $data['pubminute1']) = Date_helper :: convert_createdate_to_pubdates($data['creadate']); // Récupérer dates et horaires de publication
       
            $params = array_merge(
                $this -> _params,
                array(
                    'type'      => $data['type'],      // Type du document
                    'id'        => $data['fileid'],    // Identifiant du document
                    'status'    => $data['status'],    // Status
                    'creadate'  => $data['creadate'],  // Date de création                 
                    'author'    => $data['author'],    // Nom de l'auteur
                    'email'     => $data['email'],     // Email de l'auteur
                    'cat1'      => $data['fielda1'],   // Catégorie pour la langue 1
                    'cat2'      => $data['fielda2'],   // Catégorie pour la langue 2
                    'title1'    => $data['fieldb1'],   // Titre pour la langue 1
                    'title2'    => $data['fieldb2'],   // Titre pour la langue 2
                    'content1'  => $data['fieldc1'],   // Contenu pour la langue 1
                    'content2'  => $data['fieldc2'],   // Contenu pour la langue 2
                    'group'     => $data['fieldmod'],  // Groupe privé
                    
                    'pubdate0'   => $data['pubdate0'],   // Date début de publication programmée
                    'pubhour0'   => $data['pubhour0'],   // Heure de début de publication programmée
                    'pubminute0' => $data['pubminute0'], // Minute de début de publication programmée
                    'pubdate1'   => $data['pubdate1'],   // Date de fin de publication programmée
                    'pubhour1'   => $data['pubhour1'],   // Heure de fin de publication programmée
                    'pubminute1' => $data['pubminute1'], // Minute de fin de publication programmée
                )
            ); 
        }
        
        return $params;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Ajoute un nouvel enregistrement dans la base de donnée de guppy
     * 
     * @access public 
	 * @param integer Le nom du rédacteur
	 * @return array
	 */    
    public function insert($params)
    {
        $data[0]  = $this -> _doc_type;
        $data[1]  = '';
        $data[2]  = $params['status'];
        $data[3]  = Date_helper :: convert_pubdates_to_createdate(array($params['pubdate0'], $params['pubdate1']), array($params['pubhour0'], $params['pubhour1']),array($params['pubminute0'], $params['pubminute1']));
        $data[4]  = '';
        $data[5]  = $params['author'];
        $data[6]  = $params['email'];
        $data[7]  = $params['cat1'];
        $data[8]  = $params['cat2'];
        $data[9]  = $params['title1'];
        $data[10] = $params['title2'];
        $data[11] = parent :: _clean_param_content($params['content1']);
        $data[12] = parent :: _clean_param_content($params['content2']);
        $data[13] = '';
        $data[14] = '';
        $data[15] = '';
        $data[16] = '';
        $data[17] = $params['group'];

        // Création du document
        $id = ActionOnFields('add', $data);
        
        return $id;
    }    
    
	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour un enregistrement dans la base de donnée de guppy
     * 
     * @access public 
	 * @param integer Identifiant du document
     * @param array Données du document
	 * @return array
	 */    
    public function update($params)
    {
        $data[0]  = $this -> _doc_type;
        $data[1]  = $params['id'];
        $data[2]  = '';
        $data[3]  = Date_helper :: convert_pubdates_to_createdate(array($params['pubdate0'], $params['pubdate1']), array($params['pubhour0'], $params['pubhour1']),array($params['pubminute0'], $params['pubminute1']));
        $data[4]  = GetCurrentDateTime();
        $data[5]  = $params['author'];
        $data[6]  = $params['email'];
        $data[7]  = $params['cat1'];
        $data[8]  = $params['cat2'];
        $data[9]  = $params['title1'];
        $data[10] = $params['title2'];
        $data[11] = parent :: _clean_param_content($params['content1']);
        $data[12] = parent :: _clean_param_content($params['content2']);
        $data[13] = '';
        $data[14] = '';
        $data[15] = '';
        $data[16] = '';
        $data[17] = $params['group'];

        // Mise à jour du document
        ActionOnFields('mod', $data);
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie l'intitulé du document
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres du document
	 * @return string Intitulé descriptif du document
	 */
    public function set_doc_heading($params)
    {        
        global $lng, $lang, $admin;
        
        $field1 = (($lng == $lang[1]) ? $params['cat2'] : $params['cat1']).' - ';
        $field2 = (($lng == $lang[1]) ? $params['title2'] : $params['title1']);

        $field1 = htmlspecialchars($field1, ENT_COMPAT | ENT_HTML5, 'UTF-8');
        $field2 = htmlspecialchars($field2, ENT_COMPAT | ENT_HTML5, 'UTF-8');   
        
        return '<strong>'.$field1.'</strong>'.$field2; 
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public function set_params_rules($params, $lang, $config)
    {        
        return array_merge(
            Params_rules_helper :: set_params_status_rules($lang),  // Status
            Params_rules_helper :: set_params_pubdates_rules($params, $lang), // Dates de publication
            Params_rules_helper :: set_params_group_rules($lang),             // Group
            Params_rules_helper :: set_params_title_rules($lang, $config),    // Titre de la boite de menu
            array()
        );
    }

} // End of Class