<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Group_model extends Model
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_DB_file_path = ADMR_TABLE_GROUP_DB;
    private $_DB_counter_path = ADMR_COUNTER_GROUP_DB;
    private $_data_DB = array();    // Tableau de données de la base de données
   
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
    {
        $this -> _data_DB = $this -> read();
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * récupére les données des groupes rédacteurs enregistrés (tous par défaut)
     * 
	 * @access public
     * @param  array Tableau de filtres (optionnel) sous la forme array($key1 => mixed $values1, $key2 => mixed $values2, ...)
     * @param string Option de tri (optionnel)
	 * @return array tableau contenant les données des rédacteurs enregistrés
	 */
	public function get($filters = array(), $sort_by = '')
	{
        settype($filters, 'array');
        
        $data = array();
        
        if (!empty($filters) ) {
            $data = $this -> get_many_by_keys($filters);
        }
        else {
            $data = $this -> get_all();
        }
        
        if (!empty($sort_by)) {
            $data = $this -> sort_by_key($data, $sort_by);
        }
        
        return $data;
	}

	// --------------------------------------------------------------------

    /**
     * récupérer les groupes rédacteurs enregistrés
     * 
     * @access public
     * @return array
     */
    public function get_all()
    {  
        return $this -> _data_DB;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données des documents identifiés par les critères de sélection
     * 
     * @param array Tableau contenant les critères de sélection sous la forme array( key => values)
     * @return array
     */
    public function get_many_by_keys($keys)
    {
        settype($keys, 'array');

        return $this -> select_many_by_many_keys($this -> _data_DB, $keys);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer le nombre total des groupes rédacteurs enregistrés
     * 
     * @access public
     * @return integer
     */
    public function count_all()
    {
        return count($this -> _data_DB);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa valeur
     * 
     * @param string Pseudo du rédacteur
     * @return array
     */
    public function select_by_key($data_DB = array(), $key = '', $value = '')
    {
        settype($data_DB, 'array');
        settype($value, 'string');
        
        foreach($data_DB as $row) {
            if (isset($row[$key]) && $row[$key] == $value) {
                return $row;
            }
        }    
        
        return array();
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa ou ses valeurs
     * 
     * @param string Pseudo du rédacteur
     * @return array
     */
    public function select_many_by_key($data_DB = array(), $key = '', $value = array())
    {
        settype($data_DB, 'array');
        settype($value, 'array');
        $data = array();
        
        foreach($data_DB as $row) {
            if (isset($row[$key]) && in_array($row[$key], $value)) {
                $data[$row['id']] = $row;
            }
        }    
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa ou ses valeurs
     * 
     * @param array Données de la base
     * @param array Tableau contenant les critères de sélection sous la forme array($key1 => mixed $values1, $key2 => mixed $values2,...)
     * @return array
     */
    public function select_many_by_many_keys($data_DB = array(), $keys = array())
    {
        settype($data_DB, 'array');
        settype($keys, 'array');

        
        $data = $data_DB;

        foreach($keys as $key => $values) {
            
            if (empty($values)) {
                continue;    
            }
            
            settype($values, 'array');
            
            foreach($data as $id => $row) {
                if (!isset($row[$key]) || !in_array($row[$key], $values)) {
                    unset($data[$id]);
                }
            }           
        }        
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données du groupe rédacteur identifié par son pseudo
     * 
     * @param string Pseudo du groupe rédacteur
     * @return array
     */
    public function get_by_name($name)
    {
        return $this -> select_by_key($this -> _data_DB, 'name', $name);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données du groupe rédacteur identifié par id
     * 
     * @param integer Id du groupe rédacteur
     * @return array Données du groupe rédacteur
     */
    public function get_by_id($id)
    {
        return $this -> select_by_key($this -> _data_DB, 'id', $id);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données des groupes rédacteurs identifiés par leur identifiant
     * 
     * @param integer|array Id du ou des groupes rédacteurs
     * @return array Données des rédacteurs retourné sous la forme
     *                     array( 
     *                          $id => array('name' => , 'id' => ),
     *                          $id => array('name' => , 'id' => ), 
     *                      )
     */
    public function get_many_by_id($ids)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'id', $ids);
    }

	// --------------------------------------------------------------------

    /**
     * Tri les enregistrements
     * 
     * @param string Option de tri
     * @return array Données triées
     */
    public function sort_by_key($data, $sort_option)
    {
        if(empty($data)) {
            return $data;
        }
        
        // Tableau en colonne
        foreach ($data as $key => $row) {
            $name[$key] = $row['name'];
            $id[$key]   = $row['id'];
        }
        //
        
        switch ($sort_option) {
			case 'id_desc' :
				array_multisort($id, SORT_NUMERIC, SORT_DESC, $data);
				break;
			case 'id_asc' :
				array_multisort($id, SORT_NUMERIC, SORT_ASC, $data);
				break;
			case 'ch_asc' :
				array_multisort(array_map('strtolower', $name), SORT_STRING, SORT_ASC, $data);
				break;
			case 'ch_desc' :
				array_multisort(array_map('strtolower', $name), SORT_STRING, SORT_DESC, $data);
				break;
			default :
				array_multisort($id, SORT_NUMERIC, SORT_DESC, $data);
		}	
	
		return $data;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour l'enregistrement dans la table indexée des groupes rédacteurs (name||id)
     * 
     * @param array Données de l'enregistrement du groupe rédacteur dans la table
     * @return array
     */
    public function update($data)
    {
        if (!empty($data['id']) && isset($this -> _data_DB[$data['id']])) {  
            $this -> _data_DB[$data['id']] = array(
                'name' => $data['name'],
                'id'   => $data['id'],
            );            
            
            $this -> write();
            
            return TRUE;
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour l'enregistrement identifié par le paramètre id 
     * dans la table indexée des rédacteurs (pseudo||id||status||groupid)
     * 
     * @param array Données de l'enregistrement du rédacteur dans la table
     * @return array
     */
    public function update_by_id($id, $data)
    {
        if (isset($this -> _data_DB[$id]) && !empty($data)) {  
            $this -> _data_DB[$id] = array(
                'name' => $data['name'],
                'id'   => $id,
            );            
            
            $this -> write();
            
            return TRUE;
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données de la table indexée des groupes rédacteurs (id||name)
     * 
     * @param string Status différent de celui du rédacteur
     * @return array
     */
    public function read()
    {
        $data_DB = array();
        $records = array();
        
        if (is_file($this -> _DB_file_path)) {
            $data_DB = file($this -> _DB_file_path);
    		
            foreach($data_DB as $data) {
                list($name, $id) = explode(CONNECTOR, trim($data));
    			
                $records[$id] = array(
                    'name'    => $name,
                    'id'      => $id,
                );
            }
        }
        
        return $records;
    }

	// --------------------------------------------------------------------

    /**
     * écrire les données de la table indexée des groupes rédacteurs (id||name)
     * 
     * @param array Données de l'enregistrement du groupe rédacteur dans la table
     * @return void
     */
    public function write()
    {   
        $data = $this -> _data_DB;
        $file_path = $this -> _DB_file_path;
        $data_out = '';
        
        foreach($data as $row) {     
            $data_out .= implode(CONNECTOR, array_values($row))."\n";
        }

        $fhandle = fopen($file_path, 'w');
        fputs($fhandle, $data_out);
        fclose($fhandle);
    }

	// --------------------------------------------------------------------

    /**
     * Ajoute un enregistrement dans la table indexée des groupes (name||id)
     * 
     * @param array Données de l'enregistrement du rédacteur dans la table
     * @return array
     */
    public function insert($data)
    {
        if (empty($data)) {
            return FALSE;
        }

        $data['id'] = $this -> update_counter_id();  // Mise à jour du compteur id

        $this -> _data_DB[$data['id']] = array(
            'name' => $data['name'],
            'id'   => $data['id'],
        );
        
        $this -> write();

        return $data['id'];
    }

	// --------------------------------------------------------------------

    /**
     * Ajoute plusieurs enregistrements dans la table indexée des groupes (name||id)
     * 
     * @param array Tableau de données des enregistrements des groupes dans la table 
     *              sous la forme array(
     *                                array('name0'),
     *                                array('name1'),
     *                            )
     * @return integer Id du compteur
     */
    public function insert_many($groups)
    {
        if (empty($groups)) {
            return FALSE;
        }

        $counter = $this -> get_counter_id();  // id du compteur

        foreach($groups as $group) {
            $counter++;
            
            $this -> _data_DB[$counter] = array(
                'name'    => $group['name'],
                'id'      => $counter, 
            );      
        }
       
        $this -> write();
        
        $this -> write_counter_id($counter);  // compteur

        return $counter;
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie le compteur de l'id des enregistrements
     *
     * @return integer Identifiant du compteur
     */
    public function get_counter_id()
    {
        $counter = $this -> _DB_counter_path;
        
        $id = ReadCounter($counter);
        
        return $id;
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie le compteur de l'id des enregistrements
     *
     * @return integer Identifiant du compteur
     */
    public function write_counter_id($id)
    {
        $counter = $this -> _DB_counter_path;
        
        WriteCounter($counter, $id);
        
        return $id;

    }
        
	// --------------------------------------------------------------------

    /**
     * Met à jour le compteur de l'id des enregistrements et renvoie le nouvel identifiant
     *
     * @return array Données triées
     */
    public function update_counter_id()
    {
        $counter = $this -> _DB_counter_path;
        
        $id = ReadCounter($counter);
        $id++;
        WriteCounter($counter, $id);
        
        return $id;
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie l'id enregistré dans le compteur
     *
     * @return integer id
     */
    public function get_last_insert_id()
    {
        $counter = $this -> _DB_counter_path;
        
        return ReadCounter($counter);
    }

	// --------------------------------------------------------------------

    /**
     * supprime les données de la table indexée des groupes rédacteurs (id||name)
     * 
     * @param integer|array Identifiants des groupes rédacteur dans la table
     * @return array
     */
    public function delete_by_id($ids)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
        
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                unset($db[$key]);   
                $this -> delete_files_by_id($row['id']); // Suppression des fichiers du groupe rédacteur
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * supprime les fichiers des groupes identifiés par leur identifiants dans la table
     * 
     * @param integer|array Identifiants des groupes dans la table
     * @return array
     */
    public function delete_files_by_id($ids)
    {
        settype($ids, 'array');
        
        foreach($ids as $id){
            @unlink(ADMR_GROUP_RIGHTS_PATH.'/'.ADMR_GROUP_RIGHTS_FILE_PREFIX.$id.INCEXT);  //Fichier rights
        }

        return TRUE;
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public function set_params_rules($params, $lang, $config)
    {        
        return array(
            'name' => array(       // name
                array(
                    'rules' => array(array($this, '_is_valid_name['.$params['id'].']')),
                    'msg' => $lang['form_errors_msg']['name_must_contain_only_alphanumerics_or_dashes']
                ),
                array(
                    'rules' => array(array($this, '_is_unique_name['.$params['id'].']')),
                    'msg' => $lang['form_errors_msg']['name_exists']
                )               
            )
        );
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie la validité du nom du groupe redacteur
	 *
	 * @access	protected
	 * @param	string Nom du groupe rédacteur à valider
	 * @param	integer Identifiant du groupe rédacteur (optionnel)
	 * @return	bool
	 */
    public function _is_valid_name($groupname, $groupid = 0)
    {
        if (!empty($groupid)) // Modification du nom du rédacteur
        {
            $group = $this -> get_by_id($groupid);  // Récupération des données du groupe rédacteur

            if (!empty($group) && $groupname != $group['name']) { // modification du nom
                return (boolean) (Var_helper :: is_required($groupname) && Var_helper :: is_valid_group_name($groupname));
            } else {
                return TRUE;
            }               
        }
        else // Nouveau rédacteur
        {
            return (boolean) (Var_helper :: is_required($groupname) && Var_helper :: is_valid_group_name($groupname));
        }
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie si le nom du groupe rédacteur est unique
	 *
	 * @access	protected
	 * @param	string Nom du groupe rédacteur à valider
	 * @param	integer Identifiant du groupe rédacteur (optionnel)
	 * @return	bool
	 */
    public function _is_unique_name($groupname, $groupid = 0)
    {
        if (!empty($groupid))
        {
            $group = $this -> get_by_id($groupid);  // Récupération des données du rédacteur

            if (!empty($group) && $groupname != $group['name']) { // modification du nom
                $group = $this -> get_by_name($groupname);
                return empty($group) ? TRUE : FALSE;
            } else {
                return TRUE;
            }               
        }
        else
        {
            $group = $this -> get_by_name($groupname);
            return empty($group) ? TRUE : FALSE;
        }
    }

} // End Class