<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Guppy_docid_model extends Model
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_DB_file_path = DOCID;
    private $_DB_counter_path = NEXTID;
    private $_data_DB = array();    //Données de la base de données
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
    { 
        $this -> _data_DB = $this -> read();   
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * récupére les données des rédacteurs enregistrés (tous par défaut)
     * 
	 * @access public
     * @param  array Tableau de filtres (optionnel) sous la forme array($key1 => mixed $values1, $key2 => mixed $values2, ...)
     * @param  string Option de tri (optionnel)
	 * @return array tableau contenant les données des rédacteurs enregistrés
	 */
	public function get($filters = array(), $sort_by = '')
	{
        settype($filters, 'array');
        
        $data = array();
      
        if (!empty($filters) ) {
            $data = $this -> get_many_by_keys($filters);
        }
        else {
            $data = $this -> get_all();
        }
        
        if (!empty($sort_by)) {
            $data = $this -> sort_by_key($data, $sort_by);
        }
        
        return $data;
	}

	// --------------------------------------------------------------------

    /**
     * récupérer les documents enregistrés
     * 
     * @access public
     * @return array
     */
    public function get_all()
    {  
        return $this -> _data_DB;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données des documents identifiés par les critères de sélection
     * 
     * @param array Tableau contenant les critères de sélection sous la forme array( key => values)
     * @return array
     */
    public function get_many_by_keys($keys)
    {
        settype($keys, 'array');

        return $this -> select_many_by_many_keys($this -> _data_DB, $keys);
    }

	// --------------------------------------------------------------------
    
    /**
     * récupérer le nombre de documents enregistrés
     * 
     * @access public
     * @param  string Type du document (optionnel)
     * @return integer
     */
	public function count($doc_type = NULL)
	{
        return empty($doc_type) ? $this -> count_all() : $this -> count_by_type($doc_type);
 	}

	// --------------------------------------------------------------------

    /**
     * récupérer le nombre total de documents enregistrés
     * 
     * @access public
     * @return integer
     */
    public function count_all()
    {
        return count($this -> _data_DB);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer le nombre total de documents enregistrés par type
     * 
     * @access public
     * @param  string Type du document
     * @return integer
     */
	public function count_by_type($doc_type)
	{
        return count($this -> get_many_by_type($doc_type));
 	}

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa valeur
     * 
     * @param 
     * @return array
     */
    public function select_by_key($data_DB = array(), $key = '', $value = '')
    {
        settype($data_DB, 'array');
        settype($value, 'string');
        
        foreach($data_DB as $row) {
            if (isset($row[$key]) && $row[$key] == $value) {
                return $row;
            }
        }    
        
        return array();
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa ou ses valeurs
     * 
     * @param 
     * @return array
     */
    public function select_many_by_key($data_DB = array(), $key = '', $value = array())
    {
        settype($data_DB, 'array');
        settype($value, 'array');
        $data = array();
        
        foreach($data_DB as $row) {
            if (isset($row[$key]) && in_array($row[$key], $value)) {
                $data[$row['id']] = $row;
            }
        }    
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa ou ses valeurs
     * 
     * @param array Données de la base
     * @param array Tableau contenant les critères de sélection sous la forme array($key1 => mixed $values1, $key2 => mixed $values2,...)
     * @return array
     */
    public function select_many_by_many_keys($data_DB = array(), $keys = array())
    {
        settype($data_DB, 'array');
        settype($keys, 'array');

        
        $data = $data_DB;

        foreach($keys as $key => $values) {
            
            if (empty($values)) {
                continue;    
            }
            
            settype($values, 'array');
            
            foreach($data as $id => $row) {
                if (!isset($row[$key]) || !in_array($row[$key], $values)) {
                    unset($data[$id]);
                }
            }           
        }        
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par leur type
     * 
     * @param string|array Type du document
     * @return array
     */
    public function get_many_by_type($type)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'type', $type);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données du document identifié par id
     * 
     * @param integer Id du rédacteur
     * @return array Données du rédacteur
     */
    public function get_by_id($id)
    {
        return $this -> select_by_key($this -> _data_DB, 'id', $id);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données des documents identifiés par leur identifiants
     * 
     * @param array Ids des documents
     * @return array Données des documents
     */
    public function get_many_by_id($id)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'id', $id);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par son status
     * 
     * @param string Status du rédacteur
     * @return array
     */
    public function get_many_by_status($status)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'status', $status);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par le status différent du sien
     * 
     * @param string Status différent de celui du rédacteur
     * @return array
     */
    public function get_many_by_not_status($status)
    {
        return array_diff_key($this -> _data_DB, $this -> select_many_by_key($this -> _data_DB, 'status', $status));
    }

	// --------------------------------------------------------------------

    /**
     * récupére les données brutes de la table indexée des rédacteurs (pseudo||id||status)
     *
     * @return array
     */
    public function read()
    {
        $data_DB = array();
        $records = array();
        
        if (!empty($this -> _DB_file_path) && is_file($this -> _DB_file_path)) {
            $data_DB = file($this -> _DB_file_path);
    		
            foreach($data_DB as $data) {
                list($type, $id, $status) = explode(CONNECTOR, trim($data));
    			
                $records[$id] = array(
                    'type'   => $type,
                    'id'     => $id,
                    'status' => $status,
                );
            }
        }
        
        return $records;
    }

	// --------------------------------------------------------------------

    /**
     * Efface le contenu de la table et le remplace avec les données passées en paramètre
     * 
     * @param array Données à écrire
     * @return array
     */
    public function write()
    {
        $data = $this -> _data_DB;
        $file_path = $this -> _DB_file_path;
        $data_out = '';
        
        if (empty($file_path)) {
            return FALSE;    
        }
        
        foreach($data as $row) {     
            $data_out .= implode(CONNECTOR, array_values($row))."\n";
        }

        $fhandle = fopen($file_path, 'w');
        fputs($fhandle, $data_out);
        fclose($fhandle);
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * Ajoute un enregistrement dans la table indexée 
     * des documents des rédacteurs (type||id||status)
     * 
     * @param array Données de l'enregistrement du document dans la table
     * @return array
     */
    public function insert($data)
    {
        if (empty($data)) {
            return FALSE;
        }

        $data['id'] = $this -> update_counter_id();  // Mise à jour du compteur id

      //  $this -> _data_DB[$data['id']] = $data;

        $this -> _data_DB[$data['id']] = array(
            'type'   => $data['type'],
            'id'     => $data['id'],
            'status' => $data['status'],
        );
        
        $this -> write();

        return $data['id'];
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour le compteur de l'id des enregistrements et renvoie le nouvel identifiant
     *
     * @return array Données triées
     */
    public function update_counter_id()
    {
/*        $counter = $this -> _DB_counter_path;
        
        $id = ReadCounter($counter);
        $id++;
        WriteCounter($counter, $id);
        
        return $id;*/
        
        return IncrNextID();
    }

	// --------------------------------------------------------------------

    /**
     * Tri les enregistrements
     * 
     * @param string Option de tri
     * @return array Données triées
     */
    public function sort_by_key($data, $sort_option)
    {       
        if(empty($data)) {
            return $data;
        }

        // Tableau en colonne
        foreach ($data as $key => $row) {
            $id[$key]     = $row['id'];
            $type[$key]   = $row['type'];
            $status[$key] = $row['status'];
        }
        //
        
        switch ($sort_option) {
			case 'id_desc' :
				array_multisort($id, SORT_NUMERIC, SORT_DESC, $data);
				break;
			case 'id_asc' :
				array_multisort($id, SORT_NUMERIC, SORT_ASC, $data);
				break;
			case 'type_asc' :
				array_multisort(array_map('strtolower', $type), SORT_STRING, SORT_ASC, $mode, SORT_NUMERIC, SORT_DESC, $data);
				break;
			case 'type_desc' :
				array_multisort(array_map('strtolower', $type), SORT_STRING, SORT_DESC, $mode, SORT_NUMERIC, SORT_DESC, $data);
				break;
			case 'status_desc' :
				array_multisort($status, SORT_DESC, $data);
				break;
			case 'status_asc' :
				array_multisort($status, SORT_ASC, $data);
				break;
			default :
				array_multisort($id, SORT_NUMERIC, SORT_DESC, $data);
		}	
	
		return $data;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour les status des documents dans la table 
     * 
     * @param array Enregistrements des rédacteurs dans la table
     *              sous la forme array(id => status)
     * @param string Status à affecter
     * @return array
     */
    public function update_status_by_id($ids, $status)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
                
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                $db[$key]['status'] = $status;   
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * supprime les documents identifiés par leur identifiants dans la table
     * 
     * @param integer|array Identifiants des rédacteurs dans la table
     * @return array
     */
    public function delete_by_id($ids)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
        
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                unset($db[$key]);
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------
    
} // End Class