<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_MODELS_PATH.'/docs_model.php';

class Menuitems_model extends Docs_model
{    
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_doc_type = TYP_OPTMENU;
        
    private $_params = array(
        'type'      => '',  // Type du document
        'id'        => '',  // Identifiant du document
        'status'    => '',  // Status
        'creadate'  => '',  // Date de crétaion
        'moddate'   => '',  // Date de modification
        'author'    => '',  // Nom de l'auteur
        'email'     => '',  // Email de l'auteur
        'cat1'      => '',  // Catégorie pour la langue 1
        'cat2'      => '',  // Catégorie pour la langue 2
        'title1'    => '',  // Titre pour la langue 1
        'title2'    => '',  // Titre pour la langue 2
        'urltarget' => '',  // Choix de l'ouverture de la page du lien (_SELF, _BLANK, _POPUP)
        'sidebars'  => '',  // Mode d'affichage des boîtes latérales (S, W, L, R)
        'url1'      => '',  // Url de la page pour la langue 1
        'url2'      => '',  // Url de la page pour la langue 2
        'menuid'    => '',  // Id de la boite de menu
        'template'  => '',  // Configuration de page (gabarit)
        'group'     => '',  // Groupe privé

        'pubdate0'   => '', // Date début de publication programmée
        'pubhour0'   => '', // Heure de début de publication programmée
        'pubminute0' => '', // Minute de début de publication programmée
        'pubdate1'   => '', // Date de fin de publication programmée
        'pubhour1'   => '', // Heure de fin de publication programmée
        'pubminute1' => '', // Minute de fin de publication programmée
        
        'link_type' => '',      // Type de lien (interne ou externe)
        'internal_link' => '',  // Lien interne
        'external_link1' => '', // Lien externe pour la langue 1
        'external_link2' => '', // Lien externe pour la langue 2      
    );

    /**
     * Définit les types de documents internes pris en compte pour pouvoir être liés à un item de menu 
     */ 
    private $_internal_doc_paths = array(
        TYP_ART    => 'articles.php', // Articles
        TYP_DNLOAD => 'download.php', // téléchargements
        TYP_LINKS  => 'links.php',    // Liens
        TYP_FAQ    => 'faq.php',      // Faq
        TYP_BLOG   => 'blog.php'      // Billets du blog
    );

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
	{
        parent :: __construct($this -> _doc_type);
	}

	// --------------------------------------------------------------------
 
	/**
	 * Lit et renvoie dans un tableau les données enregistrées du document
     * 
     * @access public 
	 * @param integer Identifiant du document
	 * @return array Tableau contenant les valeurs des droits du rédacteur (par défaut $this -> _rights)
	 */
    public function read($doc_id = '')
    {
        if (empty($doc_id)) { // Nouveau document
            $params = array_merge(
                $this -> _params,
                array(
                    'type'       => $this -> _doc_type, // Type du document
                    'status'     => 'i', // Status par defaut
                    'pubdate0'   => Date_helper :: get_current_date(),   // Date début de publication programmée
                    'pubhour0'   => Date_helper :: get_current_hour(),    // Heure de début de publication programmée
                    'pubminute0' => Date_helper :: get_current_minutes(), // Minute de début de publication programmée
                    'link_type'  => 'internal', // Type de lien pour l'item
                    'sidebars'   => 'S',      // Mode d'affichage des boîtes latérales
                    'template'   => '0',      // Configuration de page
                    'urltarget'  => '_SELF',  // Choix de l'ouverture de la page du lien (_SELF, _BLANK, _POPUP)
                )
            );
        }
        else {  // Document existant            
            $data = parent :: read($doc_id);    // Récupérer données enregistrés dans docxxx.dtb

            list($data['pubdate0'], $data['pubhour0'], $data['pubminute0'], $data['pubdate1'], $data['pubhour1'], $data['pubminute1']) = Date_helper :: convert_createdate_to_pubdates($data['creadate']); // Récupérer dates et horaires de publication

            // Récupération des paramètres des liens de l'item à partir des urls enregistrées dans la base de données
            $data['link'] = $this -> _convert_urls_to_link(array($data['fieldd1'], $data['fieldd2']), $data['fieldmail']);
            //
                
            $params = array_merge(
                $this -> _params,
                array(
                    'type'      => $data['type'],      // Type
                    'id'        => $data['fileid'],    // Id
                    'status'    => $data['status'],    // Status
                    'creadate'  => $data['creadate'],  // Date de création                 
                    'author'    => $data['author'],    // Auteur
                    'email'     => $data['email'],     // Email de l'auteur
                    'cat1'      => $data['fielda1'],   // Catégorie pour la langue 1
                    'cat2'      => $data['fielda2'],   // Catégorie pour la langue 2
                    'title1'    => $data['fieldb1'],   // Titre pour la langue 1
                    'title2'    => $data['fieldb2'],   // Titre pour la langue 2
                    'urltarget' => $data['fieldc1'],   // Choix de l'ouverture de la page du lien (_SELF, _BLANK, _POPUP)
                    'sidebars'  => $data['fieldc2'],   // Mode d'affichage des boîtes latérales (S, W, L, R)
                    'url1'      => $data['fieldd1'],   // Url de la page pour la langue 1
                    'url2'      => $data['fieldd2'],   // Url de la page pour la langue 2
                    'menuid'    => $data['fieldweb'],  // Id de la boite de menu
                    'template'  => $data['fieldmail'], // Configuration de page
                    'group'     => $data['fieldmod'],  // Groupe privé
                    
                    'pubdate0'   => $data['pubdate0'],   // Date début de publication programmée
                    'pubhour0'   => $data['pubhour0'],   // Heure de début de publication programmée
                    'pubminute0' => $data['pubminute0'], // Minute de début de publication programmée
                    'pubdate1'   => $data['pubdate1'],   // Date de fin de publication programmée
                    'pubhour1'   => $data['pubhour1'],   // Heure de fin de publication programmée
                    'pubminute1' => $data['pubminute1'], // Minute de fin de publication programmée
       
                    'link_type'      => $data['link']['type'], // Type de lien (interne ou externe)
                    'internal_link'  => $data['link']['url_int'],  // Lien interne
                    'external_link1' => $data['link']['url_ext1'], // Lien externe pour la langue 1
                    'external_link2' => $data['link']['url_ext2'], // Lien externe pour la langue 2
                )
            ); 
        }
// print_r($params);       
        return $params;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Ajoute un nouvel enregistrement dans la base de donnée de guppy
     * 
     * @access public 
	 * @param integer Le nom du rédacteur
	 * @return array
	 */    
    public function insert($params)
    {
        // Récupération des urls des liens de l'item
        list($params['url1'], $params['url2']) = $this -> _convert_link_to_urls(
            array(
                'type' => $params['link_type'],
                'url_int' => $params['internal_link'],
                'url_ext1' => $params['external_link1'],
                'url_ext2' => $params['external_link2'],
            ),
            $params['template']
        );
        //

        $data[0]  = $this -> _doc_type;
        $data[1]  = '';
        $data[2]  = $params['status'];
        $data[3]  = Date_helper :: convert_pubdates_to_createdate(array($params['pubdate0'], $params['pubdate1']), array($params['pubhour0'], $params['pubhour1']),array($params['pubminute0'], $params['pubminute1']));
        $data[4]  = '';
        $data[5]  = $params['author'];
        $data[6]  = $params['email'];
        $data[7]  = $params['cat1'];
        $data[8]  = $params['cat2'];
        $data[9]  = $params['title1'];
        $data[10] = $params['title2'];
        $data[11] = $params['urltarget'];
        $data[12] = $params['sidebars'];
        $data[13] = $params['url1'];
        $data[14] = $params['url2'];
        $data[15] = $params['menuid'];
        $data[16] = $params['template'];
        $data[17] = $params['group'];

        // Création du document
        $params['id'] = ActionOnFields('add', $data);

        // Enregistrement dans le fichier index arom.dtb du document
        $this -> _update_articles_menuitems_index($params, TRUE);

        return $params['id'];
    }  
    
	// --------------------------------------------------------------------
 
 	/**
	 * Met à jour un enregistrement dans la base de donnée de guppy
     * 
     * @access public 
	 * @param integer Identifiant du document
     * @param array Données du document
	 * @return array
	 */    
    public function update($params)
    {
        // Récupération des urls des liens de l'item
        list($params['url1'], $params['url2']) = $this -> _convert_link_to_urls(
            array(
                'type' => $params['link_type'],
                'url_int' => $params['internal_link'],
                'url_ext1' => $params['external_link1'],
                'url_ext2' => $params['external_link2'],
            ),
            $params['template']
        );
        //
         
        $data[0]  = $this -> _doc_type;
        $data[1]  = $params['id'];
        $data[2]  = '';
        $data[3]  = Date_helper :: convert_pubdates_to_createdate(array($params['pubdate0'], $params['pubdate1']), array($params['pubhour0'], $params['pubhour1']),array($params['pubminute0'], $params['pubminute1']));
        $data[4]  = GetCurrentDateTime();
        $data[5]  = $params['author'];
        $data[6]  = $params['email'];
        $data[7]  = $params['cat1'];
        $data[8]  = $params['cat2'];
        $data[9]  = $params['title1'];
        $data[10] = $params['title2'];
        $data[11] = $params['urltarget'];
        $data[12] = $params['sidebars'];
        $data[13] = $params['url1'];
        $data[14] = $params['url2'];
        $data[15] = $params['menuid'];
        $data[16] = $params['template'];
        $data[17] = $params['group'];

        // Mise à jour du document
        ActionOnFields('mod', $data);    

        // Mise à jour du document dans le fichier index arom.dtb
        $this -> _update_articles_menuitems_index($params);
    }
    
	// --------------------------------------------------------------------

    /**
     * Met à jour la table indexée arom.dtb contenant les ids des articles associés aux items de menu 
     *
     * @access private
	 * @param array Tableau contenant les paramètres de l'item
     * @param boolean Nouveau document ou non
     * @return void
     */
    private function _update_articles_menuitems_index($params, $new_doc = FALSE)
    {      
        if (strpos($params['url1'], 'articles.php?') === FALSE) { // Si ce n'est pas un article associé à l'item on sort
            return FALSE;    
        }
              
        /**
         * Récupération des paramètres de la boite de menu
         */
        require_once ADMR_MODELS_PATH.'/boxmenus_model.php';
        $boxmenus_model = new Boxmenus_model();
        $params['boxmenu'] = $boxmenus_model -> read($params['menuid']);
        //

        /**
         * Enregistrement des données dans le fichier index arom.dtb
         */        
        require_once ADMR_MODELS_PATH.'/articles_menuitems_index_model.php';       
        $arom_index_model = new Articles_menuitems_index_model();

        $data = array(
            'id_art'      => $this -> _get_doc_id_linked_to_item($params['id']), // Id de l'article
            'id_item'     => $params['id'],     // Id de l'item de menu
            'id_menu'     => $params['menuid'], // Id du menu
            'menu_title1' => $params['boxmenu']['title1'],        // Titre du menu pour la langue 1
            'menu_title2' => $params['boxmenu']['title2'],        // Titre du menu pour la langue 2
            'item_cat1'   => empty($params['cat1'])? 'Hors Catégorie' : $params['cat1'], // Catégorie de l'item de menu pour la langue 1
            'item_cat2'   => empty($params['cat2'])? 'Hors Catégorie' : $params['cat2'], // Catégorie de l'item de menu pour la langue 2
        );
             
        if ($new_doc) {
            $arom_index_model -> insert($data);    
        } else {
            $arom_index_model -> update($data);    
        }
        //
        
        return TRUE;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie l'intitulé du document
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres du document
	 * @return string Intitulé descriptif du document
	 */
    public function set_doc_heading($params)
    {        
        global $lng, $lang;

        $field1 = ($lng == $lang[1]) ? $params['cat2'] : $params['cat1'];
        $field2 = ($lng == $lang[1]) ? $params['title2'] : $params['title1'];

        $field1 = htmlspecialchars($field1, ENT_COMPAT | ENT_HTML5, 'UTF-8');
        $field2 = htmlspecialchars($field2, ENT_COMPAT | ENT_HTML5, 'UTF-8');   
       
        return empty($field1) ? $field2 : '<strong>'.$field1.' - </strong>'.$field2; 
    }

	// --------------------------------------------------------------------
    
	/**
	 * Récupère l'identifiant du document interne (article, download) lié à l'item de menu
     * 
     * @access public
	 * @param integer Identifiant de l'item de menu
	 * @return integer Identifiant du document interne associé à l'item de menu
	 */    
    public function _get_doc_id_linked_to_item($item_id)
    {
        $item = $this -> read($item_id);
        $doc_id = 0;

        if ($this -> _is_internal_link($item['url1'])) {
            $doc_id = $this -> extract_doc_id_from_item_url($item['url1']);    
        }
/*
        $pos = strpos($item['url1'], '?lng');
        
        if ($pos !== FALSE && in_array(substr($item['url1'], 0, $pos), $doc_paths_allowed)) {
            $doc_id = $this -> extract_doc_id_from_item_url($item['url1']);
        }*/
        
        return $doc_id;    
    }
    
	// --------------------------------------------------------------------

	/**
	 * Retourne les chemins des fichiers qui permmettent l'affichage des document interne de guppy (articles, downloads, ...)
     *  
     * @access public
	 * @return array Tableau contenant l'ensemble deschemins des documents de guppy
	 */
    public function get_internal_doc_paths()
    {
        return $this -> _internal_doc_paths;
    }
    
	// --------------------------------------------------------------------

	/**
	 * Définit et retourne les chemins des fichiers qui permmettent l'affichage des document interne de guppy (articles, downloads, ...)
     *  
     * @access public
     * @param array Tableau contenant l'ensemble des chemins des documents de guppy sous la forme array(type => path)
	 * @return array Tableau contenant l'ensemble des chemins des documents de guppy sous la forme array(type => path)
	 */
    public function set_internal_doc_paths($doc_paths)
    {
        if (is_array($doc_paths)) {
            return $this -> _internal_doc_paths = $doc_paths;    
        }
    }
    
	// --------------------------------------------------------------------

	/**
	 * Vérifie que le lien associé à l'item de menu correspond à un document interne de guppy (articles, downloads, ...)
     *  
     * @access public
	 * @param string Url de l'item de menu
	 * @return boolean Résultat de la vérification
	 */
    private function _is_internal_link($url)
    {
        $doc_paths = array_values($this -> get_internal_doc_paths());

        $pos = strpos($url, '?lng');
        
        if ($pos !== FALSE && in_array(substr($url, 0, $pos), $doc_paths)) {
            return TRUE;
        }

        return FALSE;                
    }
    
	// --------------------------------------------------------------------

    /**
     * Extrait et retourne le nom du fichier du document lié à l'item 
     * à partir de l'url de l'item enregistré dans la base de donnée
     * 
     * @param string Url de l'item enregistrée dans la base de donnée
     * @return integer Id du document lié à l'item
     */
/*    private function _extract_doc_path_from_item_url($url)
    {
        $url = $this -> _clean_item_url($url);
        $doc_path = '';        
        
        $pos = strpos($url, '?');
        
        if ($pos !== FALSE) {            
            $doc_path = substr($item['url1'], 0, $pos);
        }
        
        return $doc_path;        
    }
*/
	// --------------------------------------------------------------------

    /**
     * Récupère les données du lien de l'item affiché dans le formulaire
     * à partir des urls enregistrées dans la base de donnée
     * 
     * @param array Tableau contenant les urls enregistrées dans la base de donnée (tableau sous la forme array('url1', 'url2') )
     * @return array Tableau contenant les données du lien sous la forme array('type' => '', 'url_int' => '', 'url_ext1' => '', 'url_ext2' => '')
     */ 
/*    private function _convert_urls_to_link($urls = array())
    {
        settype($urls, 'array');
        $link = array('type' => 'external', 'url_int' => '', 'url_ext1' => '', 'url_ext2' => '');
        
        if (!empty($urls[0])) {
            $pos = strpos($urls[0], '.php');
            $docs_allowed = array('articles', 'download');        
            
            if ($pos !== FALSE && in_array(substr($urls[0], 0, $pos), $docs_allowed)) {
                $link['type'] = 'internal';
                $link['url_int'] = $this -> _clean_item_url($urls[0]);
            } else {
                $link['type'] = 'external';
                $link['url_ext1'] = $this -> _clean_item_url($urls[0]); 
                $link['url_ext2'] = !empty($urls[1]) ? $this -> _clean_item_url($urls[1]) : '';           
            }
        }
        
        return $link;     
    } */

	// --------------------------------------------------------------------

    /**
     * Récupère les données du lien de l'item affiché dans le formulaire
     * à partir des urls enregistrées dans la base de donnée
     * 
     * @param array Tableau contenant les urls enregistrées dans la base de donnée (tableau sous la forme array('url1', 'url2') )
     * @param integer Identifiant du template sélectionné (tconfig)
     * @return array Tableau contenant les données du lien sous la forme array('type' => '', 'url_int' => '', 'url_ext1' => '', 'url_ext2' => '')
     */ 
    private function _convert_urls_to_link($urls = array(), $template_id = 0)
    {
        settype($urls, 'array');
        $link = array('type' => 'external', 'url_int' => '', 'url_ext1' => '', 'url_ext2' => '');
        
        if (!empty($urls[0])) {
            
            if ($this -> _is_internal_link($urls[0])) {
                $link['type'] = 'internal';
                $link['url_int'] = str_replace('&tconfig='.$template_id, '', $this -> _clean_item_url($urls[0]));
            } else {
                $link['type'] = 'external';
                $link['url_ext1'] = $this -> _clean_item_url($urls[0]); 
                $link['url_ext2'] = !empty($urls[1]) ? $this -> _clean_item_url($urls[1]) : '';           
            }
        }
        
        return $link;     
    } 

	// --------------------------------------------------------------------
    
    /**
     * Récupère les urls à enregistrer dans la base de donnée 
     * à partir des données du lien de l'item enregistrées dans le formulaire
     * 
     * @param array Tableau contenant les données du lien enregistrées dans le formulaire (tableau sous la forme array('type' => '', 'url_int' => '', 'url_ext1' => '', 'url_ext2' => '') )
     * @param integer Identifiant du template sélectionné (tconfig)
     * @return array Tableau contenant les urls du lien sous la forme array('url1', 'url2')
     */    
    private function _convert_link_to_urls($link = array(), $template_id = 0)
    {
        global $lang;
        
        $urls = array('', '');
     
        // Lien interne
        if ($link['type'] == 'internal') {
            $link['url_int'] .= '&tconfig='.$template_id; 
            
            $urls[0] = $link['url_int']; // Url pour langue 1
            $urls[1] = !empty($lang[1]) ? str_replace('lng='.$lang[0], 'lng='.$lang[1], $link['url_int']) : ''; // Url pour langue 2
        }
        
        // lien Externe
        else if ($link['type'] == 'external') {
            $urls[0] = $link['url_ext1']; // Url pour langue 1
            $urls[1] = $link['url_ext2']; // Url pour langue 2
        }

        return $urls ;   
    } 

	// --------------------------------------------------------------------

    /**
     * Extrait et retourne l'id du document lié à l'item 
     * à partir de l'url de l'item enregistré dans la base de donnée
     * 
     * @param string Url de l'item enregistrée dans la base de donnée
     * @return integer Id du document lié à l'item
     */
    public function extract_doc_id_from_item_url($url)
    {
        $url = $this -> _clean_item_url($url);
        $doc_id = 0;        
        
        parse_str($url, $output);
       
        if (!empty($output['pg']) && ctype_digit($output['pg'])) {
            $doc_id = $output['pg'];
        }
        
        return $doc_id;        
    }

	// --------------------------------------------------------------------

    /**
     * Nettoie et retourne l'url de l'item enregistré dans la base de donnée
     * 
     * @param string Url enregistrée dans la base de donnée
     * @return string Url nettoyée
     */
    private function _clean_item_url($url)
    {
        $url = explode(CONNECTOR, $url);
        
        return $url[0];        
    }
    
	// --------------------------------------------------------------------
     
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public function set_params_rules($params, $lang, $config)
    {        
        return array_merge(
            Params_rules_helper :: set_params_status_rules($lang),  // Status
            Params_rules_helper :: set_params_pubdates_rules($params, $lang), // Dates de publication
            Params_rules_helper :: set_params_group_rules($lang),             // Group
            Params_rules_helper :: set_params_title_rules($lang, $config),    // Titre de la boite de menu
            Params_rules_helper :: set_params_sidebars_mode_display_rules($lang, $config),    // Mode d'affichage des boites latérales

            array(
                'menuid' => array( // id du menu
                    array(
                        'rules' => array(array('Var_helper', 'is_required')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['menu_required'], ENT_QUOTES, 'UTF-8')
                    ),
                    array(
                        'rules' => array(array('Var_helper', 'is_digit')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['menu_id_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
                'link_type' => array( // Type de lien
                    array(
                        'rules' => array(array('Var_helper', 'is_in_array[internal,external]')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['menuitem_link_type_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
                'internal_link' => array( // Lien interne
                    array(
                        'rules' => array(array($this, '_is_valid_internal_link['.$params['link_type'].']')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['menuitem_link_internal_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
                'external_link1' => array( // Lien externe pour la langue 1
                    array(
                        'rules' => array(array($this, '_is_valid_external_link['.$params['link_type'].']')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['menuitem_link_external_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),            
                'external_link2' => array( // Lien externe pour la langue 2
                    array(
                        'rules' => array(array($this, '_is_valid_external_link['.$params['link_type'].']')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['menuitem_link_external_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),            
                'template' => array( // gabarit
                    array(
                        'rules' => array(array('Var_helper', 'is_digit')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['template_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
            )
        );
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si le lien interne est valide ou non
     * 
     * @access protected
	 * @param string Lien à valider
	 * @return boolean
	 */
    function _is_valid_internal_link($url, $type)
    {
        if ($type != 'internal') {
            return TRUE;    
        }
        
        return $this -> _is_internal_link($url);        
    }

    
	// --------------------------------------------------------------------
 
	/**
	 * Vérifie si le lien externe est valide ou non
     * 
     * @access protected
	 * @param string Lien à valider
	 * @return boolean
	 */
    function _is_valid_external_link($url, $type)
    {
        if ($type != 'external') {
            return TRUE;    
        }
        
        return Var_helper :: is_required($url);        
    }
    
	// --------------------------------------------------------------------

} // End of Class