<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Photoramas_diapos_model extends Model
{
    private $_file_basepath = PHOTOREP;
    private $_file_ext = DBEXT; // Extension du fichier contenant les données du photorama
    private $_file_id = 0; // Identifiant du photorama
    private $_file_prefix = 'gal_'; // Prefixe du fichier contenant les données du photorama
    private $_dir_thumbs = 'vgnt'; // Nom du répertoire contenant les miniatures
    private $_DB_file_path = '';  // Chemin du fichier contenant la base de donnée
    private $_DB_dir_path = '';   // Chemin du répertoire contenant le fichier de la base de donnée
    private $_data_DB = array();    //Données de la base de données

    private $_params = array(
        'id'  => 0, // Id de la diapo
        'status' => 'i', // Status de la diapo
        'filename' => '', // Nom du fichier de la diapo
        'thumb_width' => '100', // Largeur de la miniature de la diapo
        'thumb_height' => '75', // Hauteur de la miniature de la diapo
        'comment1' => '',  // Commentaire de la diapo pour la langue 1
        'comment2' => '',  // Commentaire de la diapo pour la langue 2
        'width' => '400',     // Largeur de la diapo
        'height' => '300',    // Hauteur de la diapo
    );
  
    private $_sort_items = array('id_asc', 'id_desc', 'status_asc', 'status_desc');	// Options de tri

    /**
     * constructeur
     * 
     * @param array Tableau contenant l'identifiant du photorama photo qui est associé au fichier contenant la table des documents
     * @return void
     */ 
    function __construct($params = array())
    {   
        if (!empty($params['id'])) {
            $this -> load_data($params['id']);
            
       //     $this -> _DB_file_path = $this -> set_file_path($params['id']);
            
       //     $this -> _data_DB = $this -> read();
            
           //print_r($this -> _data_DB);   
       }
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Charge les données des diapos enregistrées dana le photorama
     * 
     * @access public 
	 * @param integer Identifiant du photorama
	 * @return array Tableau contenant la base de données des diapos enregistrées dana le photorama (vide par défaut)
	 */    
    function load_data($file_id)
    {
        $this -> _DB_file_path = $this -> set_file_path($file_id);
        $this -> _data_DB = $this -> read();
        
        return $this -> _data_DB;       
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie le chemin du fichier qui contient la base de données des diapos enregistrées dana le photorama
     * 
     * @access public 
	 * @param integer Identifiant du photorama
	 * @return string chemin du fichier qui contient la base de données des diapos enregistrées dana le photorama
	 */
    public function set_file_path($file_id)
	{
        if (!empty($file_id) && ctype_digit((string) $file_id)) {
            $dir_file_path = $this -> _file_basepath.$this -> _file_prefix.$file_id;
            
            if (is_dir($dir_file_path)) {
                $this -> _DB_dir_path = $dir_file_path;
                $this -> _DB_file_path = $dir_file_path.'/'.$this -> _file_prefix.$file_id.$this -> _file_ext;
                $this -> _file_id = $file_id;               
            }
        }
        
        return $this -> _DB_file_path;
	}
    
	// --------------------------------------------------------------------

	/**
	 * récupére le chemin du répertoire contenant les données du photorama
     * 
	 * @access public
	 * @return string chemin du répertoire contenant les données du photorama
	 */
    public function get_dir_path()
    {
        return $this -> _DB_dir_path;
    }
    
	// --------------------------------------------------------------------

	/**
	 * récupére le chemin du répertoire contenant les images du photorama
     * 
	 * @access public
	 * @return string chemin du répertoire contenant les images du photorama
	 */
    public function get_dir_path_for_images()
    {
        return $this -> get_dir_path();
    }
    
	// --------------------------------------------------------------------

	/**
	 * récupére le chemin du répertoire contenant les miniatures du photorama
     * 
	 * @access public
	 * @return string chemin du répertoire contenant les miniatures du photorama
	 */
    public function get_dir_path_for_thumbs()
    {
        return !empty($this -> _DB_dir_path) ? $this -> _DB_dir_path.'/'.$this -> _dir_thumbs : '';
    }
    
	// --------------------------------------------------------------------

	/**
	 * récupére les données des rédacteurs enregistrés (tous par défaut)
     * 
	 * @access public
     * @param  array Tableau de filtres (optionnel) sous la forme array($key1 => mixed $values1, $key2 => mixed $values2, ...)
     * @param  string Option de tri (optionnel)
	 * @return array tableau contenant les données des rédacteurs enregistrés
	 */
	function get($filters = array(), $sort_by = '')
	{
        settype($filters, 'array');
        
        $data = array();
      
        if (!empty($filters) ) {
            $data = $this -> get_many_by_keys($filters);
        }
        else {
            $data = $this -> get_all();
        }
        
        if (!empty($sort_by)) {
            $data = $this -> sort_by_key($data, $sort_by);
        }
        
        return $data;
	}

	// --------------------------------------------------------------------

    /**
     * récupérer les documents enregistrés
     * 
     * @access public
     * @return array
     */
    function get_all()
    {  
        return $this -> _data_DB;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données des documents identifiés par les critères de sélection
     * 
     * @param array Tableau contenant les critères de sélection sous la forme array( key => values)
     * @return array
     */
    function get_many_by_keys($keys)
    {
        settype($keys, 'array');

        return $this -> select_many_by_many_keys($this -> _data_DB, $keys);
    }

	// --------------------------------------------------------------------
    
    /**
     * récupérer le nombre de documents enregistrés dans la base de donnée
     * 
     * @access public
     * @param  array Tableau de filtres (optionnel) sous la forme array($key1 => mixed $values1, $key2 => mixed $values2, ...)
     * @return integer
     */
	function count($filters = array())
	{
        return count($this -> get($filters));
 	}

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa valeur
     * 
     * @param 
     * @return array
     */
    function select_by_key($data_DB = array(), $key = '', $value = '')
    {
        settype($data_DB, 'array');
        settype($value, 'string');
        $data = array();
        
        foreach($data_DB as $row) {
            if (isset($row[$key]) && $row[$key] == $value) {
                return $row;
            }
        }    
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa ou ses valeurs
     * 
     * @param array Données des documents
     * @return array
     */
    function select_many_by_key($data_DB = array(), $key = '', $value = array())
    {
        settype($data_DB, 'array');
        settype($value, 'array');
        $data = array();
        
        foreach($data_DB as $row) {
            if (isset($row[$key]) && in_array($row[$key], $value)) {
                $data[$row['id']] = $row;
            }
        }    
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa ou ses valeurs
     * 
     * @param array Données de la base
     * @param array Tableau contenant les critères de sélection sous la forme array($key1 => mixed $values1, $key2 => mixed $values2,...)
     * @return array
     */
    function select_many_by_many_keys($data_DB = array(), $keys = array())
    {
        settype($data_DB, 'array');
        settype($keys, 'array');

        
        $data = $data_DB;

        foreach($keys as $key => $values) {
            
            if (empty($values)) {
                continue;    
            }
            
            settype($values, 'array');
            
            foreach($data as $id => $row) {
                if (!isset($row[$key]) || !in_array($row[$key], $values)) {
                    unset($data[$id]);
                }
            }           
        }        
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par id
     * 
     * @param integer Id du rédacteur
     * @return array Données du rédacteur
     */
    function get_by_id($id)
    {
        return $this -> select_by_key($this -> _data_DB, 'id', $id);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par les ids
     * 
     * @param array Tableau contenant les valeurs des identifiants des documents à récupérer
     * @return array Données du rédacteur
     */
    function get_many_by_id($id)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'id', $id);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par son status
     * 
     * @param string Status du rédacteur
     * @return array
     */
    function get_many_by_status($status)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'status', $status);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les documents identifiés par le status différent du sien
     * 
     * @param string Status différent de celui du rédacteur
     * @return array
     */
    function get_many_by_not_status($status)
    {
        return array_diff_key($this -> _data_DB, $this -> select_many_by_key($this -> _data_DB, 'status', $status));
    }

	// --------------------------------------------------------------------

    /**
     * récupére les données brutes de la table indexée des rédacteurs (pseudo||id||status)
     *
     * @return array
     */
    function read()
    {
        $data_DB = array();
        $records = array();
       
        if (!empty($this -> _DB_file_path) && is_file($this -> _DB_file_path)) {
            $data_DB = file($this -> _DB_file_path, FILE_IGNORE_NEW_LINES+FILE_SKIP_EMPTY_LINES);
  		
            foreach($data_DB as $data) {
                $row = explode(CONNECTOR, trim($data));

                foreach(array_keys($this -> _params) as $key => $value) {
                    $records[$row[0]][$value] = $row[$key];    
                }
            }
        }
        
        return $records;
    }

	// --------------------------------------------------------------------

    /**
     * Efface le contenu de la table et le remplace avec les données passées en paramètre
     * 
     * @param array Données à écrire
     * @return array
     */
    private function _write()
    {
        $data = $this -> _data_DB;
        $file_path = $this -> _DB_file_path;
        $data_out = '';
        
        if (empty($file_path)) { // Si pas de fichier, on a rien à faire ici !
            return FALSE;    
        }
        
        foreach($data as $row) {     
            $data_out .= implode(CONNECTOR, array_values($row))."\n";
        }

        $fhandle = fopen($file_path, 'w');
        fputs($fhandle, $data_out);
        fclose($fhandle);
        
        return TRUE;
    }
     
	// --------------------------------------------------------------------
 
 	/**
	 * Crée le fichier contenant les données des diapos du photorama
     *
     * @access public 
	 * @param integer Identifiant du photorama (optionnel)
	 * @return void
	 */    
    public function create($file_id = 0)
    {
        $this -> set_file_path($file_id);    
        
        if (!is_file($this -> _DB_file_path)) {
            $this -> _data_DB = array();
            $this -> _write();
            return TRUE;
        }
        
        return FALSE;            
    }
     
	// --------------------------------------------------------------------
 
 	/**
	 * Crée une miniature des photos du photorama
     *
     * @access public 
	 * @param array Tableau contenant les noms des photos correspondant aux miniatures à créer (si vide => toutes les photos)
	 * @return void
	 */    
    public function create_thumnails($photos = array(), $max_width = '100', $max_height = '75')
    {
        settype($photos, 'array');
        $photos = array_map('basename', $photos);
        $dir_img_path = $this -> _DB_dir_path;
        $dir_thumb_path = $dir_img_path.'/'.$this -> _dir_thumbs;
        
        if (empty($photos)) {
            $photos = $this -> scan_photos();
        }        

        foreach($photos as $img_name) {            
            if (!is_file($dir_img_path.'/'.$img_name)) { // Fichier non valide
                continue;
            }
                       
            list($img_width, $img_height, $img_type) = @getimagesize($dir_img_path.'/'.$img_name);

            /**
             * Définition de la taille de la vignette en respectant les paramètres de configuration (largeur et hauteur max)
             */
            if ($img_width > $img_height) { // largeur image > hauteur image
                $thumb_width = $max_width;                
                $thumb_height = ceil($img_height * $max_width / $img_width);
                
                if ($thumb_height > $max_height) {  // hauteur vignette > valeur max                 
                    $thumb_width = ceil($thumb_width * $max_height / $thumb_height);
                    $thumb_height = $max_height;
                }
            } else { // Hauteur image > largeur image
                $thumb_height = $max_height;                      
                $thumb_width = ceil($img_width * $max_height / $img_height);
                
                if ($thumb_width > $max_width) { // largeur vignette > valeur max
                    $thumb_height = ceil($thumb_height * $max_width / $thumb_width);
                    $thumb_width = $max_width;
                }
            }
            //
            
            /**
             * Création de la vignette selon son type
             */
			$ImageCreateFromType = 'imagecreatefrom'.image_type_to_extension($img_type, false); // Fonction ImageCreateFromXXX
            $ImageType = 'image'.image_type_to_extension($img_type, false); // Fonction ImageXXX
  			             
            $img = $ImageCreateFromType($dir_img_path.'/'.$img_name);
  			$thumb = @imagecreatetruecolor($thumb_width, $thumb_height);
            
            // Without this the image png or gif will have a black background instead of being transparent. 
            if ($img_type == IMAGETYPE_PNG || $img_type == IMAGETYPE_GIF) {
                @imagecolortransparent($thumb, imagecolorallocatealpha($thumb, 0, 0, 0, 127));
                @imagealphablending($thumb, false);
                @imagesavealpha($thumb, true);               
            }
            
  			if (@imagecopyresampled($thumb, $img, 0, 0, 0, 0, $thumb_width, $thumb_height, $img_width, $img_height) 
                && @$ImageType($thumb, $dir_thumb_path.'/'.$img_name)) {
                    SetChmod($dir_thumb_path.'/'.$img_name);    
            }
  			@imagedestroy($img);
            @imagedestroy($thumb);
            //
        }

        return TRUE;            
    }

	// --------------------------------------------------------------------

	/**
	 * Liste et renvoie toutes les photos présentes(enregistrées ou non) dans le répertoire du photorama
     * 
     * @access protected
	 * @return array Tableau contenant toutes les photos présentes dans le répertoire du photorama
	 */	
    public function scan_photos()
    {
        require_once ADMR_HELPERS_PATH.'/dir_helper.php';
        
        $photos = array();
        
        if (!empty($this -> _file_id)) {
            $photos = Dir_helper :: scan_dir(
                $dir = $this -> _file_basepath.$this -> _file_prefix.$this -> _file_id,
                $only_files = TRUE,
                $except_files = array('index.php', $this -> _file_prefix.$this -> _file_id.$this -> _file_ext, 'params_'.$this -> _file_id.INCEXT)
            );
        }
       
        return $photos;               
    }

	// --------------------------------------------------------------------

    /**
     * Reconstruit la table de donnée avec les enregistrements passés en paramètre 
     * des documents du photoramas
     * 
     * @param array Données des enregistrements du document dans la table sous la forme 
     *              array(
     *                  0 => array('filename' => '', status => '', ...),
     *                  1 => array('filename' => '', status => '', ...),
     *                  ...
     *              )
     * @return boolean
     */
    function rebuild($records)
    {
        if (empty($records)) { // Si pas de données, on a rien à faire ici !
            return FALSE;
        }

        $this -> _data_DB = array();
        $key = 1;

        foreach($records as $record) {
            
            $record = $this -> _clean($record);
            
            if (!empty($record)) {
                $record['id'] = $key;               
                $this -> _data_DB[$record['id']] = array_merge($this -> _params, $record);
                $key++;
            }
        }
      
        $this -> _write();

        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * Nettoie les commentaires 
     * 
     * @param string Chemin de l'image
     * @return array Tableau contenant les dimensions (width, height) en pixel de l'image
     */
    private function _get_image_size($image_path)
    {
        $image_size = array('width' => '', 'height' => '');
        
        if (is_file($image_path)) {
            list($image_size['width'], $image_size['height']) = @getimagesize($image_path);
        }
        
        return array($image_size['width'], $image_size['height']);       
    }
     
	// --------------------------------------------------------------------

    /**
     * Nettoie les commentaires 
     * 
     * @param string Commentaire
     * @return string Commentaire nettoyé
     */
    private function _clean_comment($comment)
    {
        $comment = Var_helper :: remove_special_blank_spaces($comment);
        
        $in = array(
    		'\\',
    		'="'.ADMR_SITE_URL,
            '"'
    	);
    	$out = array(
    		'&#92;',
    		'="',
            "'"
    	);
        
        $comment = str_replace($in, $out, $comment);
 //       $comment = str_replace('"', "'", $comment);
        
        return $comment;       
    }
     
	// --------------------------------------------------------------------

    /**
     * Ajoute des enregistrements dans la table indexée 
     * des documents du photorama
     * 
     * @param array Données des enregistrements du document dans la table sous la forme 
     *              array(
     *                  0 => array('filename' => '', status => '', ...),
     *                  1 => array('filename' => '', status => '', ...),
     *                  ...
     *              )
     * @return boolean
     */
    function insert($records)
    {
        if (empty($records)) { // Si pas de données, on a rien à faire ici !
            return FALSE;
        }

        foreach($records as $record) {
            
            $record = $this -> _clean($record);
            
            if (!empty($record)) {
                $record['id'] = $this -> get_next_id();               
                $this -> _data_DB[$record['id']] = array_merge($this -> _params, $record);
            }
        }
        
        $this -> _write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour le compteur de l'id des enregistrements et renvoie le nouvel identifiant
     *
     * @return array Données triées
     */
    public function get_next_id()
    {
        $id_max = !empty($this -> _data_DB) ? max(array_keys($this -> _data_DB)) : 0;

        return $id_max + 1;
    }
    
	// --------------------------------------------------------------------

    /**
     * Met à jour un enregistrement dans la table indexée 
     * des diapos du photorama
     * 
     * @param array Données de l'enregistrement du document dans la table
     * @return array
     */
    public function update($data)
    {
        $data = $this -> _clean($data);

        if (!empty($data) && !empty($this -> _data_DB[$data['id']])) {
           
            $this -> _data_DB[$data['id']] = array_merge($this -> _data_DB[$data['id']], $data);
            
            $this -> _write();
            
            return TRUE;    
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Nettoie les données du rédacteur
     * 
     * @access private 
	 * @param array Données du rédacteur à nettoyer
	 * @return array
	 */        
    private function _clean($data)
    {
        settype($data, 'array');
        
        $data = array_merge($this -> _params, $data);
        $dir_img_path = $this -> _DB_dir_path;
        $dir_thumb_path = $dir_img_path.'/'.$this -> _dir_thumbs;
        
        if (empty($data['filename']) || !is_file($dir_img_path.'/'.$data['filename'])) {
            return array();    
        }            

        list($data['width'], $data['height']) = $this -> _get_image_size($dir_img_path.'/'.$data['filename']);
        list($data['thumb_width'], $data['thumb_height']) = $this -> _get_image_size($dir_thumb_path.'/'.$data['filename']);

        $data['comment1'] = $this -> _clean_comment($data['comment1']);
        $data['comment2'] = $this -> _clean_comment($data['comment2']);               
        
        return array_map('RemoveConnector', array_intersect_key($data, $this -> _params));
    }
    
	// --------------------------------------------------------------------

    /**
     * remise à zéro de la table indexée 
     * des documents
     * 
     * @return void
     */
    function reset()
    {       
        $this -> _data_DB = array();
        
        $this -> _write();

        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * Tri les enregistrements
     * 
     * @param string Option de tri
     * @return array Données triées
     */
    function sort_by_key($data, $sort_option)
    {       
        if(empty($data)) {
            return $data;
        }

        // Tableau en colonne
        foreach ($data as $key => $row) {
            $id[$key]     = $row['id'];
            $status[$key] = $row['status'];
            $filename[$key] = $row['filename'];
        }
        //
        
        switch ($sort_option) {
			case 'id_desc' :
				array_multisort($id, SORT_NUMERIC, SORT_DESC, $data);
				break;
			case 'id_asc' :
				array_multisort($id, SORT_NUMERIC, SORT_ASC, $data);
				break;
			case 'ch_desc' :
				array_multisort($filename, SORT_DESC, $data);
				break;
			case 'ch_asc' :
				array_multisort($filename, SORT_ASC, $data);
				break;
			case 'status_desc' :
				array_multisort($status, SORT_DESC, $data);
				break;
			case 'status_asc' :
				array_multisort($status, SORT_ASC, $data);
				break;
			default :
				array_multisort($id, SORT_NUMERIC, SORT_DESC, $data);
		}	
	
		return $data;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour les status des documents dans la table 
     * 
     * @param array Enregistrements des rédacteurs dans la table
     *              sous la forme array(id => status)
     * @param string Status à affecter
     * @return array
     */
    function update_status_by_id($ids, $status)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
                
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                $db[$key]['status'] = $status;   
            }            
        }
            
        $this -> _write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * supprime les documents identifiés par leur identifiants dans la table (alias)
     * 
     * @param integer|array Identifiants des documents dans la table
     * @return array
     */
    function delete_many_by_id($ids)
    {
        return $this -> delete_by_id($ids);
    }

	// --------------------------------------------------------------------

    /**
     * supprime les documents identifiés par leur identifiants dans la table
     * 
     * @param integer|array Identifiants des documents dans la table
     * @return array
     */
    function delete_by_id($ids)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
        
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                unset($db[$key]);
            }            
        }
            
        $this -> _write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public function set_params_rules($params, $lang, $config)
    {        
        return array();
    }

	// --------------------------------------------------------------------
    
} // End Class