<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Writer_model extends Model
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_DB_file_path = ADMR_TABLE_WRITER_DB;
    private $_DB_counter_path = ADMR_COUNTER_WRITER_DB;
    private $_data_DB = array();    //Données de la base de données
   
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    function __construct()
    {
        $this -> _data_DB = $this -> read();
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * récupére les données des rédacteurs enregistrés (tous par défaut)
     * 
	 * @access public
     * @param  array Tableau de filtres (optionnel) sous la forme array($key1 => mixed $values1, $key2 => mixed $values2, ...)
     * @param string Option de tri (optionnel)
	 * @return array tableau contenant les données des rédacteurs enregistrés
	 */
	function get($filters = array(), $sort_by = '')
	{
        settype($filters, 'array');
        
        $data = array();
        
        if (!empty($filters) ) {
            $data = $this -> get_many_by_keys($filters);
        }
        else {
            $data = $this -> get_all();
        }
        
        if (!empty($sort_by)) {
            $data = $this -> sort_by_key($data, $sort_by);
        }
        
        return $data;
	}

	// --------------------------------------------------------------------

    /**
     * récupére tous les rédacteurs enregistrés
     * 
     * @access public
     * @return array
     */
    function get_all()
    {  
        return $this -> _data_DB;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données des documents identifiés par les critères de sélection
     * 
     * @param array Tableau contenant les critères de sélection sous la forme array( key => values)
     * @return array
     */
    function get_many_by_keys($keys)
    {
        settype($keys, 'array');

        return $this -> select_many_by_many_keys($this -> _data_DB, $keys);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer le nombre de rédacteurs enregistrés
     * 
     * @access public
     * @param  integer Id du groupe rédacteur (optionnel)
     * @return integer
     */
	function count($group_id = NULL)
	{
        return empty($group_id) ? $this -> count_all() : $this -> count_by_groupid($group_id);
 	}

	// --------------------------------------------------------------------

    /**
     * récupérer le nombre total de rédacteurs enregistrés
     * 
     * @access public
     * @return integer
     */
    function count_all()
    {
        return count($this -> _data_DB);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer le nombre total de rédacteurs enregistrés dans un groupe
     * 
     * @access public
     * @param  integer Id du groupe rédacteur
     * @return integer
     */
	function count_by_groupid($group_id)
	{
        return count($this -> get_many_by_groupid($group_id));
 	}

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa valeur
     * 
     * @param string Pseudo du rédacteur
     * @return array
     */
    function select_by_key($data_DB = array(), $key = '', $value = '')
    {
        settype($data_DB, 'array');
        settype($value, 'string');
        
        foreach($data_DB as $row) {
            if (isset($row[$key]) && $row[$key] == $value) {
                return $row;
            }
        }    
        
        return array();
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa ou ses valeurs
     * 
     * @param string Pseudo du rédacteur
     * @return array
     */
    function select_many_by_key($data_DB = array(), $key = '', $value = array())
    {
        settype($data_DB, 'array');
        settype($value, 'array');
        $data = array();
        
        foreach($data_DB as $row) {
            if (isset($row[$key]) && in_array($row[$key], $value)) {
                $data[$row['id']] = $row;
            }
        }    
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données identifié par la clé et sa ou ses valeurs
     * 
     * @param array Données de la base
     * @param array Tableau contenant les critères de sélection sous la forme array($key1 => mixed $values1, $key2 => mixed $values2,...)
     * @return array
     */
    function select_many_by_many_keys($data_DB = array(), $keys = array())
    {
        settype($data_DB, 'array');
        settype($keys, 'array');

        
        $data = $data_DB;

        foreach($keys as $key => $values) {
            
            if (empty($values)) {
                continue;    
            }
            
            settype($values, 'array');
            
            foreach($data as $id => $row) {
                if (!isset($row[$key]) || !in_array($row[$key], $values)) {
                    unset($data[$id]);
                }
            }           
        }        
        
        return $data;
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données du ou des rédacteur(s) identifié(s) par le nom
     * 
     * @param string|array Pseudo du ou des rédacteur(s))
     * @return array
     */
    function get_by_name($name)
    {
        return $this -> select_by_key($this -> _data_DB, 'name', $name);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données du ou des rédacteur(s) identifié(s) par id
     * 
     * @param integer|array Id du ou des rédacteur(s))
     * @return array Données du rédacteur retourné sous la forme array('name' => , 'id' => , 'status' => , 'groupid' => )
     */
    function get_by_id($id)
    {
        return $this -> select_by_key($this -> _data_DB, 'id', $id);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données des rédacteur(s) identifié(s) par leur identifiant
     * 
     * @param integer|array Id du ou des rédacteur(s))
     * @return array Données des rédacteurs retourné sous la forme
     *                     array( 
     *                          $id => array('name' => , 'id' => , 'status' => , 'groupid' => ),
     *                          $id => array('name' => , 'id' => , 'status' => , 'groupid' => ), 
     *                      )
     */
    function get_many_by_id($ids)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'id', $ids);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données des rédacteur(s) identifié(s) par leur identifiant de groupe
     * 
     * @param integer|array Id du ou des groupes rédacteur(s))
     * @return array Données des rédacteurs retourné sous la forme
     *                     array( 
     *                          $id => array('name' => , 'id' => , 'status' => , 'groupid' => ),
     *                          $id => array('name' => , 'id' => , 'status' => , 'groupid' => ), 
     *                      )
     */
    function get_many_by_groupid($group_ids)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'groupid', $group_ids);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données des rédacteurs identifiés par le status
     * 
     * @param string Status du rédacteur
     * @return array
     */
    function get_many_by_status($status)
    {
        return $this -> select_many_by_key($this -> _data_DB, 'status', $status);
    }

	// --------------------------------------------------------------------

    /**
     * récupérer les données du rédacteur identifié par le status différent du sien
     * 
     * @param string Status différent de celui du rédacteur
     * @return array
     */
    function get_many_by_not_status($status)
    {
        return array_diff_key($this -> _data_DB, $this -> select_many_by_key($this -> _data_DB, 'status', $status));
    }

	// --------------------------------------------------------------------

    /**
     * récupére les données brutes de la table indexée des rédacteurs (pseudo||id||status)
     *
     * @return array
     */
    function read()
    {
        $data_DB = array();
        $records = array();
      
        if (is_file($this -> _DB_file_path)) {
            $data_DB = file($this -> _DB_file_path);
    		
            foreach($data_DB as $data) {
                list($name, $id, $status, $groupid) = explode(CONNECTOR, trim($data));
    			
                $records[$id] = array(
                    'name'    => $name,
                    'id'      => $id,
                    'status'  => $status,
                    'groupid' => $groupid, 
                );
            }
        }
        
        return $records;
    }

	// --------------------------------------------------------------------

    /**
     * Efface le contenu de la table et le remplace avec les données passées en paramètre
     * 
     * @param array Données à écrire
     * @return array
     */
    function write()
    {   
        $data = $this -> _data_DB;
        $file_path = $this -> _DB_file_path;
        $data_out = '';
        
        foreach($data as $row) {     
            $data_out .= implode(CONNECTOR, array_values($row))."\n";
        }

        $fhandle = fopen($file_path, 'w');
        fputs($fhandle, $data_out);
        fclose($fhandle);
    }

	// --------------------------------------------------------------------

    /**
     * Ajoute un enregistrement dans la table indexée des rédacteurs (name||id||status||groupid)
     * 
     * @param array Données de l'enregistrement du rédacteur dans la table
     * @return integer Id du compteur
     */
    function insert($data)
    {
        if (empty($data)) {
            return FALSE;
        }

        $data['id'] = $this -> update_counter_id();  // Mise à jour du compteur id

        $this -> _data_DB[$data['id']] = array(
            'name'    => $data['name'],
            'id'      => $data['id'],
            'status'  => $data['status'],
            'groupid' => $data['groupid'], 
        );
        
        $this -> write();

        return $data['id'];
    }

	// --------------------------------------------------------------------

    /**
     * Ajoute plusieurs enregistrements dans la table indexée des rédacteurs (name||id||status||groupid)
     * 
     * @param array Tableau de données des enregistrements des rédacteurs dans la table 
     *              sous la forme array(
     *                                array('name0','status0','groupid0'),
     *                                array('name1','status1','groupid1'),
     *                            )
     * @return integer Id du compteur
     */
    function insert_many($writers)
    {
        if (empty($writers)) {
            return FALSE;
        }

        $counter = $this -> get_counter_id();  // id du compteur

        foreach($writers as $writer) {
            $counter++;
            
            $this -> _data_DB[$counter] = array(
                'name'    => $writer['name'],
                'id'      => $counter,
                'status'  => $writer['status'],
                'groupid' => $writer['groupid'], 
            );      
        }
       
        $this -> write();
        
        $this -> write_counter_id($counter);  // compteur

        return $counter;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour l'enregistrement dans la table indexée des rédacteurs (pseudo||id||status||groupid)
     * 
     * @param array Données de l'enregistrement du rédacteur dans la table
     * @return array
     */
    function update($data)
    {
        if (!empty($data['id']) && isset($this -> _data_DB[$data['id']])) {
            $this -> _data_DB[$data['id']] = array(
                'name'    => $data['name'],
                'id'      => $data['id'],
                'status'  => $data['status'],
                'groupid' => $data['groupid'],
            );            
            
            $this -> write();
            
            return TRUE;
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour l'enregistrement identifié par le paramètre id 
     * dans la table indexée des rédacteurs (pseudo||id||status||groupid)
     * 
     * @param array Données de l'enregistrement du rédacteur dans la table
     * @return array
     */
    function update_by_id($id, $data)
    {
        if (isset($this -> _data_DB[$id]) && !empty($data)) {  
            $this -> _data_DB[$id] = array(
                'name'    => $data['name'],
                'id'      => $id,
                'status'  => $data['status'],
                'groupid' => $data['groupid'],
            );            
            
            $this -> write();
            
            return TRUE;
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie le compteur de l'id des enregistrements
     *
     * @return integer Identifiant du compteur
     */
    function get_counter_id()
    {
        $counter = $this -> _DB_counter_path;
        
        $id = ReadCounter($counter);
        
        return $id;
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie le compteur de l'id des enregistrements
     *
     * @return integer Identifiant du compteur
     */
    function write_counter_id($id)
    {
        $counter = $this -> _DB_counter_path;
        
        WriteCounter($counter, $id);
        
        return $id;

    }

	// --------------------------------------------------------------------

    /**
     * Met à jour le compteur de l'id des enregistrements et renvoie le nouvel identifiant
     *
     * @return integer Identifiant du compteur
     */
    function update_counter_id()
    {
        $counter = $this -> _DB_counter_path;
        
        $id = ReadCounter($counter);
        $id++;
        WriteCounter($counter, $id);
        
        return $id;
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie l'id enregistré dans le compteur
     *
     * @return integer id
     */
    function get_last_insert_id()
    {
        $counter = $this -> _DB_counter_path;
        
        return ReadCounter($counter);
    }

	// --------------------------------------------------------------------

    /**
     * Tri les enregistrements
     * 
     * @param string Option de tri
     * @return array Données triées
     */
    function sort_by_key($data, $sort_option)
    {       
        if(empty($data)) {
            return $data;
        }

        // Tableau en colonne
        foreach ($data as $key => $row) {
            $id[$key]     = $row['id'];
            $name[$key]   = $row['name'];
            $status[$key] = $row['status'];
        }
        //
        
        switch ($sort_option) {
			case 'id_desc' :
				array_multisort($id, SORT_NUMERIC, SORT_DESC, $data);
				break;
			case 'id_asc' :
				array_multisort($id, SORT_NUMERIC, SORT_ASC, $data);
				break;
			case 'ch_asc' :
				array_multisort(array_map('strtolower', $name), SORT_STRING, SORT_ASC, $data);
				break;
			case 'ch_desc' :
				array_multisort(array_map('strtolower', $name), SORT_STRING, SORT_DESC, $data);
				break;
			case 'status_asc' :
				array_multisort($status, SORT_ASC, $data);
				break;
			case 'status_desc' :
				array_multisort($status, SORT_DESC, $data);
				break;
			default :
				array_multisort($id, SORT_NUMERIC, SORT_DESC, $data);
		}	
	
		return $data;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour les status des enregistrement dans la table 
     * 
     * @param array Enregistrements des rédacteurs dans la table
     *              sous la forme array(id => status)
     * @param string Status à affecter
     * @return array
     */
    function update_status_by_id($ids, $status)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
                
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                $db[$key]['status'] = $status;   
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour les status des enregistrement dans la table 
     * 
     * @param array Identifiants des groupes rédacteurs
     * @param string Status à affecter
     * @return array
     */
    function update_status_by_groupid($group_ids, $status)
    {
        settype($group_ids, 'array');
        $db =& $this -> _data_DB;
                
        foreach($db as $key => $row){
            if (in_array($row['groupid'], $group_ids)) {
                $db[$key]['status'] = $status;   
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * Supprime le groupe des enregistrement dans la table 
     * 
     * @param array Id des rédacteurs dans la table
     * @return boolean
     */
    function reset_group_by_id($ids)
    {
        return $this -> update_groupid_by_id($ids, 0);
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour le groupe des enregistrement dans la table 
     * 
     * @param array Id des rédacteurs dans la table
     * @param string Id du groupe rédacteur à affecter
     * @return array
     */
    function update_groupid_by_id($ids, $groupid)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
                
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                $db[$key]['groupid'] = $groupid;   
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * Supprime le groupe des enregistrement dans la table 
     * 
     * @param array Id des groupes rédacteurs dans la table
     * @return boolean
     */
    function reset_group_by_groupid($ids)
    {
        return $this -> update_groupid_by_groupid($ids, 0);
    }

	// --------------------------------------------------------------------

    /**
     * Met à jour le groupe des enregistrement dans la table 
     * 
     * @param array Identifiants des groupes rédacteurs
     * @param string Id du groupe rédacteur à affecter
     * @return array
     */
    function update_groupid_by_groupid($group_ids, $groupid)
    {
        settype($group_ids, 'array');
        $db =& $this -> _data_DB;
                
        foreach($db as $key => $row){
            if (in_array($row['groupid'], $group_ids)) {
                $db[$key]['groupid'] = $groupid;   
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * supprime les rédacteurs identifiés par leur identifiants dans la table
     * 
     * @param integer|array Identifiants des rédacteurs dans la table
     * @return array
     */
    function delete_by_id($ids)
    {
        settype($ids, 'array');
        $db =& $this -> _data_DB;
        
        foreach($db as $key => $row){
            if (in_array($row['id'], $ids)) {
                unset($db[$key]);
                $this -> delete_files_by_id($row['id']); // Suppression des fichiers du rédacteur
            }            
        }
                    
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * supprime les rédacteurs identifiés par les identifiants de leur groupe
     * 
     * @param integer|array Identifiants des groupes rédacteur dans la table
     * @return array
     */
    function delete_by_groupid($group_ids)
    {
        settype($group_ids, 'array');
        $db =& $this -> _data_DB;
        
        foreach($db as $key => $row){
            if (in_array($row['groupid'], $group_ids)) {
                unset($db[$key]);
                $this -> delete_files_by_id($row['id']);  // Suppression des fichiers du rédacteur
            }            
        }
            
        $this -> write();
        
        return TRUE;
    }

	// --------------------------------------------------------------------

    /**
     * supprime les fichiers des rédacteurs identifiés par leur identifiants dans la table
     * 
     * @param integer|array Identifiants des rédacteurs dans la table
     * @return array
     */
    function delete_files_by_id($ids)
    {
        settype($ids, 'array');
        
        foreach($ids as $id){
            @unlink(ADMR_WRITER_RIGHTS_PATH.'/'.ADMR_WRITER_RIGHTS_FILE_PREFIX.$id.INCEXT);  // Fichier rights
            @unlink(ADMR_WRITER_DOCS_PATH.'/'.ADMR_WRITER_DOCS_FILE_PREFIX.$id.DBEXT);       // Fichier docs
            @unlink(ADMR_WRITER_MSG_PATH.'/'.ADMR_WRITER_MSG_TIME_FILE_PREFIX.$id.DBEXT);    // Fichier time
            @unlink(ADMR_WRITER_MSG_PATH.'/'.ADMR_WRITER_MSG_ONLINE_FILE_PREFIX.$id.DBEXT);  // Fichier online
        }

        return TRUE;
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public function set_params_rules($params, $lang, $config)
    {        
        return array(
            'name' => array(       // nom du redacteur
                array(
                    'rules' => array(array($this, '_is_valid_name['.$params['id'].']')),
                    'msg' => $lang['form_errors_msg']['name_must_contain_only_alphanumerics_or_dashes']
                ),
                array(
                    'rules' => array(array($this, '_is_unique_name['.$params['id'].']')),
                    'msg' => $lang['form_errors_msg']['name_exists']
                )
            ),
            'pass' => array(       // Mot de passe
                array(
                    'rules' => array(array($this, '_is_valid_pass['.$params['id'].','.$params['name'].']')),
                    'msg' => $lang['form_errors_msg']['password_length_must_greater_than_6_chars']
                )
            ),
            'conf_pass' => array(  // Confirmation du mot de passe
                array(
                    'rules' => array(array($this, '_is_valid_conf_pass['.$params['id'].','.$params['pass'].']')),
                    'msg' => $lang['form_errors_msg']['confirmation_password_not_equal_to_password']
                )
            ),
            'email' => array(       // Email
                array(
                    'rules' => array(array($this, '_is_valid_email')),
                    'msg' => $lang['form_errors_msg']['email_not_valid']
                )
            )
        );
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie la validité du nom du redacteur
	 *
	 * @access	protected
	 * @param	string Nom du rédacteur à valider
	 * @param	integer Identifiant du rédacteur (optionnel)
	 * @return	bool
	 */
    function _is_valid_name($writername, $writerid = 0)
    {
        if (!empty($writerid)) // Modification du nom du rédacteur
        {
            $writer = $this -> get_by_id($writerid);  // Récupération des données du rédacteur

            if (!empty($writer) && $writername != $writer['name']) { // modification du nom
                return (boolean) (Var_helper :: is_required($writername) && Var_helper :: is_valid_writer_name($writername));
            } else {
                return TRUE;
            }               
        }
        else // Nouveau rédacteur
        {
            return (boolean) (Var_helper :: is_required($writername) && Var_helper :: is_valid_writer_name($writername));
        }
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie si le nom du rédacteur est unique
	 *
	 * @access	protected
	 * @param	string Nom du rédacteur à valider
	 * @param	integer Identifiant du rédacteur (optionnel)
	 * @return	bool
	 */
    function _is_unique_name($writername, $writerid = 0)
    {
        if (!empty($writerid))
        {
            $writer = $this -> get_by_id($writerid);  // Récupération des données du rédacteur

            if (!empty($writer) && $writername != $writer['name']) { // modification du nom
                $writer = $this -> get_by_name($writername);
                return empty($writer) ? TRUE : FALSE;
            } else {
                return TRUE;
            }               
        }
        else
        {
            $writer = $this -> get_by_name($writername);
            return empty($writer) ? TRUE : FALSE;
        }
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie la validité du mot de passe
	 *
	 * @access	public
	 * @param	string mot de passe
	 * @param	integer Identifiant du rédacteur (optionnel)
	 * @return	bool
	 */
    function _is_valid_pass($pass, $writerdata = 0)
    {
        list($writerid, $writername) = explode(',', $writerdata);
        
        if (empty($writerid)) // Add
        {
            return (boolean) (Var_helper :: is_required($pass) && Var_helper :: has_min_length($pass, 6));         
        }
        else {  // Edit
            $writer = $this -> get_by_id($writerid);  // Récupération des données du rédacteur            
          
            if (!empty($pass) || $writername != $writer['name']) { // Password rempli ou nom du rédacteur modifié
                return (boolean) (Var_helper :: is_required($pass) && Var_helper :: has_min_length($pass, 6));         
            } else {
                return TRUE;
            }
        }
        
        return FALSE;
    }

	// --------------------------------------------------------------------

	/**
	 * Vérifie la validité de la confirmation du mot de passe
	 *
	 * @access	public
	 * @param	string mot de passe de confirmation
	 * @return	bool
	 */
    function _is_valid_conf_pass($str, $writerdata)
    {
        list($writerid, $writerpass) = explode(',', $writerdata);
        
        if (empty($writerid)) // Add
        {
            return (boolean) ($str === $writerpass);
               
        }
        else {  // Edit
            if (!empty($writerpass)) {
                return (boolean) ($str === $writerpass);
            } else {
                return TRUE;
            }
        }
        
        return FALSE;
    } 

	// --------------------------------------------------------------------

	/**
	 * Vérifie la validité de l'email du redacteur
	 *
	 * @access	protected
	 * @param	string Email du rédacteur à valider
	 * @return	bool
	 */
    function _is_valid_email($email)
    {
        if (!empty($email))
        {
            return Var_helper :: is_email($email);
        }
        
        return TRUE;
    }

	// --------------------------------------------------------------------

} // End of Class