<?php
/**
 * Plugin Adm_redacteurs
 * Version  : 6.12 (2018/02/25)
 * Compatibility : Guppy v5.0+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Writers_online_model extends Model
{
    private $_file_path = ADMR_WRITER_ONLINE_PATH;
    private $_file_prefix = ADMR_WRITER_ONLINE_FILE_PREFIX;
    private $_file_ext = DBEXT;
    private $_expiration_time = 600; // Délai d'expiration de la connexion en seconde
    
    private $_DB = array();
    
    /**
     * constructeur
     * 
     * @return void
     */ 
    function __construct()
    {

    }

	// --------------------------------------------------------------------

    /**
     * récupère les rédacteur en ligne
     *
     * @return array tableau contenant les identifiants des rédacteurs en ligne
     */
    public function get()
    {
        $dir = $this -> _file_path;
        $writers = array();
        
        $dh  = opendir($dir);
        while (false !== ($filename = readdir($dh))) {
            if (is_file($dir.'/'.$filename) && strpos($filename, $this -> _file_prefix) === 0) {
                $time = file_get_contents($dir.'/'.$filename);
                
                if (!empty($time) && time() - $time < $this -> _expiration_time) {
                    $id = $this -> _extract_id_from_filename($filename); 
                    $writers[$id] = $id;    
                } else {
                    @unlink($dir.'/'.$filename);
                } 
            }
        }

        return $writers;        
    }

	// --------------------------------------------------------------------

    /**
     * extrait l'identifiants du rédacteur en ligne du nom du ficher passé en paramètre
     *
     * @param tring Nom du fichier correspondant au rédacteur
     * @return integer identifiant du rédacteur
     */
    private function _extract_id_from_filename($filename)
    {
        $id = substr($filename, strlen($this -> _file_prefix), -4);
        
        return $id;  
    }
    
	// --------------------------------------------------------------------

    /**
     * ajoute un rédacteur en ligne
     * 
     * @param integer identifiant du rédacteur
     * @return void
     */
    public function add($writer_id)
    {
        $file = $this -> _file_path.'/'.$this -> _file_prefix.$writer_id.$this -> _file_ext;

        file_put_contents($file, time());
        
        setcookie('admr', $writer_id, 0, '/');       // Enregistrement du rédacteur dans un cookie        
    }

	// --------------------------------------------------------------------

    /**
     * met à jour un rédacteur en ligne
     * 
     * @param integer identifiant du rédacteur
     * @return void
     */
    public function update($writer_id)
    {
        $file = $this -> _file_path.'/'.$this -> _file_prefix.$writer_id.$this -> _file_ext;

//        if (is_file($file)) {
            file_put_contents($file, time());    
//        } 
    }

	// --------------------------------------------------------------------

    /**
     * supprime un rédacteur en ligne
     * 
     * @param integer identifiant du rédacteur
     * @return void
     */
    public function delete($writer_id)
    {
        $file = $this -> _file_path.'/'.$this -> _file_prefix.$writer_id.$this -> _file_ext;
        
        if (is_file($file)) {
            @unlink($file);
        }
           
        @setcookie ('admr', '', time() - 3600, '/'); // Suppression du cookie
        unset($_COOKIE['admr']);
    }

	// --------------------------------------------------------------------
    
} // End Class